@@ -29,6 +29,7 @@ import java.util.List;
 
 import net.yacy.cora.protocol.ClientIdentification;
 import net.yacy.cora.protocol.RequestHeader;
+import net.yacy.cora.util.Html2Image;
 import net.yacy.crawler.data.CrawlProfile;
 import net.yacy.search.Switchboard;
 import net.yacy.search.schema.CollectionSchema;
@@ -511,6 +512,19 @@ public class CrawlStartExpert {
                 ClientIdentification.yacyInternetCrawlerAgentName);
 
 
+        // ---------- Snapshot generation
+        boolean wkhtmltopdfAvailable = Html2Image.wkhtmltopdfAvailable();
+        boolean convertAvailable = Html2Image.convertAvailable();
+        prop.put("snapshotsMaxDepth", post == null ? "-1" : post.get("snapshotsMaxDepth", "-1"));
+        if (sb.getConfigBool("isTransparentProxy", false) &&
+            sb.getConfigBool("proxyAlwaysFresh", false) &&
+             wkhtmltopdfAvailable && convertAvailable) {
+            prop.put("snapshotEnableImages", 1);
+            prop.put("snapshotEnableImages_snapshotsLoadImageChecked", post == null ? 0 : post.getBoolean("snapshotsLoadImage") ? 1 : 0);
+        } else {
+            prop.put("snapshotEnableImages", 0);
+        }
+
         // ---------- Index Administration
         // Do Local Indexing
         if (post == null) {
@@ -548,7 +562,7 @@ public class CrawlStartExpert {
                 prop.put("collection", collectionEnabled ? defaultCollection : "");
             }
         }
-
+        
         // return rewrite properties
         return prop;
     }
