@@ -36,6 +36,7 @@ import java.util.regex.PatternSyntaxException;
 import net.yacy.cora.document.encoding.ASCII;
 import net.yacy.cora.document.id.AnchorURL;
 import net.yacy.cora.document.id.DigestURL;
+import net.yacy.cora.document.id.MultiProtocolURL;
 import net.yacy.cora.federate.solr.FailCategory;
 import net.yacy.cora.federate.yacy.CacheStrategy;
 import net.yacy.cora.protocol.ClientIdentification;
@@ -126,6 +127,7 @@ public class Crawler_p {
 
         if (post != null && post.containsKey("queues_terminate_all")) {
             // terminate crawls individually
+            sb.crawlQueues.noticeURL.clear();
             for (final byte[] h: sb.crawler.getActive()) {
                 CrawlProfile p = sb.crawler.getActive(h);
                 if (CrawlSwitchboard.DEFAULT_PROFILES.contains(p.name())) continue;
@@ -311,9 +313,6 @@ public class Crawler_p {
                 final int crawlingDomMaxPages = (crawlingDomMaxCheck) ? post.getInt("crawlingDomMaxPages", -1) : -1;
                 env.setConfig("crawlingDomMaxPages", Integer.toString(crawlingDomMaxPages));
 
-                boolean crawlingQ = "on".equals(post.get("crawlingQ", "off")); // on unchecked checkbox "crawlingQ" not contained in post
-                env.setConfig("crawlingQ", crawlingQ);
-                
                 boolean followFrames = "on".equals(post.get("followFrames", "false"));
                 env.setConfig("followFrames", followFrames);
                 
@@ -351,7 +350,6 @@ public class Crawler_p {
                     newcrawlingMustNotMatch = CrawlProfile.MATCH_NEVER_STRING;
                     newcrawlingdepth = 0;
                     directDocByURL = false;
-                    crawlingQ = true;
                 }
                 
                 if ("sitelist".equals(crawlingMode)) {
@@ -378,13 +376,18 @@ public class Crawler_p {
                 // delete all error urls for that domain
                 // and all urls for that host from the crawl queue
                 Set<String> hosthashes = new HashSet<String>();
+                boolean anysmbftporpdf = false;
                 for (DigestURL u : rootURLs) {
                     sb.index.fulltext().remove(u.hash());
                     hosthashes.add(u.hosthash());
+                    if ("smb.ftp".indexOf(u.getProtocol()) >= 0 || "pdf".equals(MultiProtocolURL.getFileExtension(u.getFileName()))) anysmbftporpdf = true;
                 }
                 sb.crawlQueues.removeHosts(hosthashes);
                 sb.index.fulltext().commit(true);
                 
+                boolean crawlingQ = anysmbftporpdf || "on".equals(post.get("crawlingQ", "off")) || "sitemap".equals(crawlingMode);
+                env.setConfig("crawlingQ", crawlingQ);
+                
                 // compute mustmatch filter according to rootURLs
                 if ((fullDomain || subPath) && newcrawlingdepth > 0) {
                     String siteFilter = ".*";
@@ -436,6 +439,12 @@ public class Crawler_p {
                     // check crawlurl was given in sitecrawl
                     if ("url".equals(crawlingMode) && rootURLs.size() == 0) hasCrawlstartDataOK = false;
                 }
+               
+                String snapshotsMaxDepthString = post.get("snapshotsMaxDepth", "-1");
+                int snapshotsMaxDepth = Integer.parseInt(snapshotsMaxDepthString);
+                boolean snapshotsLoadImage = post.getBoolean("snapshotsLoadImage");
+                boolean snapshotsReplaceOld = post.getBoolean("snapshotsReplaceOld");
+                
                 // prepare a new crawling profile
                 final CrawlProfile profile;
                 byte[] handle;
@@ -462,6 +471,9 @@ public class Crawler_p {
                             indexMedia,
                             storeHTCache,
                             crawlOrder,
+                            snapshotsMaxDepth,
+                            snapshotsLoadImage,
+                            snapshotsReplaceOld,
                             cachePolicy,
                             collection,
                             agentName);
@@ -662,7 +674,8 @@ public class Crawler_p {
         prop.put("crawlProfilesShow", count == 0 ? 0 : 1);
 
         prop.put("crawlProfilesShow_linkstructure", 0);
-        if (count > 0) {
+        
+        if (count > 0 && sb.getConfigBool(SwitchboardConstants.DECORATION_GRAFICS_LINKSTRUCTURE, true)) {
             // collect the host names for 'wide' crawls which can be visualized
             boolean showLinkstructure = hosts.length() > 0 && !hosts.contains("file:");
             if (showLinkstructure) {
