@@ -29,6 +29,7 @@ import java.util.Iterator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
 import java.util.TreeMap;
 import java.util.concurrent.BlockingQueue;
@@ -41,6 +42,7 @@ import net.yacy.cora.document.encoding.UTF8;
 import net.yacy.cora.document.id.DigestURL;
 import net.yacy.cora.document.id.MultiProtocolURL;
 import net.yacy.cora.federate.solr.FailType;
+import net.yacy.cora.federate.solr.SolrType;
 import net.yacy.cora.federate.solr.connector.AbstractSolrConnector;
 import net.yacy.cora.protocol.RequestHeader;
 import net.yacy.cora.sorting.ClusteredScoreMap;
@@ -89,6 +91,7 @@ public class HostBrowser {
         prop.put("result", "");
         prop.put("hosts", 0);
         prop.put("files", 0);
+        prop.put("hostanalysis", 0);
         
         prop.put("admin", "false");
         boolean admin = false;
@@ -158,7 +161,7 @@ public class HostBrowser {
                         sb.peers.mySeed().hash.getBytes(),
                         url, null, load, new Date(),
                         sb.crawler.defaultProxyProfile.handle(),
-                        0, 0, 0
+                        0
                     ));
                 prop.putHTML("result", reasonString == null ? ("added url to indexer: " + load) : ("not indexed url '" + load + "': " + reasonString));
                 if (wait) waitloop: for (int i = 0; i < 30; i++) {
@@ -248,37 +251,82 @@ public class HostBrowser {
         }
         
         if (path.length() > 0) {
-            boolean delete = false;
-            boolean reload404 = false;
-            if (authorized && post.containsKey("delete")) {
-                // delete the complete path!! That includes everything that matches with this prefix.
-                delete = true;
-            }
-            if (authorized && post.containsKey("reload404")) {
-                // try to re-load all urls that have load errors and matches with this prefix.
-                reload404 = true;
-            }
-            int facetcount=post.getInt("facetcount", 0);
-            boolean complete = post.getBoolean("complete");
-            if (complete) { // we want only root paths for complete lists
-                p = path.indexOf('/', 10);
-                if (p > 0) path = path.substring(0, p + 1);
-            }
-            prop.put("files_complete", complete ? 1 : 0);
-            prop.put("files_complete_admin", admin ? "true" : "false");
-            prop.putHTML("files_complete_path", path);
-            p = path.substring(0, path.length() - 1).lastIndexOf('/');
-            if (p < 8) {
-                prop.put("files_root", 1);
-            } else {
-                prop.put("files_root", 0);
-                prop.putHTML("files_root_path", path.substring(0, p + 1));
-                prop.put("files_root_admin", admin ? "true" : "false");
-            }
             try {
-                // generate file list from path
                 DigestURL uri = new DigestURL(path);
                 String host = uri.getHost();
+                
+                // write host analysis if path after host is empty
+                if (uri.getPath().length() <= 1 && host != null && host.length() > 0 && sb.getConfigBool("decoration.hostanalysis", false)) {
+                    //how many documents per crawldepth_i; get crawldepth_i facet for host
+                    ArrayList<String> ff = new ArrayList<>();
+                    for (CollectionSchema csf: CollectionSchema.values()) {
+                        if ((csf.getType() != SolrType.num_integer && csf.getType() != SolrType.num_long) || csf.isMultiValued()) continue;
+                        String facetfield = csf.getSolrFieldName();
+                        if (!fulltext.getDefaultConfiguration().contains(facetfield)) continue;
+                        ff.add(csf.getSolrFieldName());
+                    }
+                    // add also vocabulary counters
+                    Map<String, ReversibleScoreMap<String>> vocabularyFacet = sb.index.fulltext().getDefaultConnector().getFacets(CollectionSchema.vocabularies_sxt.getSolrFieldName() + ":[* TO *]", 100, CollectionSchema.vocabularies_sxt.getSolrFieldName());
+                    if (vocabularyFacet.size() > 0) {
+                        Collection<String> vocnames = vocabularyFacet.values().iterator().next().keyList(true);
+                        for (String vocname: vocnames) {
+                            ff.add(CollectionSchema.VOCABULARY_PREFIX + vocname + CollectionSchema.VOCABULARY_LOGCOUNT_SUFFIX);
+                            ff.add(CollectionSchema.VOCABULARY_PREFIX + vocname + CollectionSchema.VOCABULARY_LOGCOUNTS_SUFFIX);
+                        }
+                    }
+                    // list the facets
+                    String[] facetfields = ff.toArray(new String[ff.size()]);
+                    Map<String, ReversibleScoreMap<String>> facets = fulltext.getDefaultConnector().getFacets(CollectionSchema.host_s.getSolrFieldName() + ":\"" + host + "\"", 100, facetfields);
+                    int fc = 0;
+                    for (Map.Entry<String, ReversibleScoreMap<String>> facetentry: facets.entrySet()) {
+                        ReversibleScoreMap<String> facetfieldmap = facetentry.getValue();
+                        if (facetfieldmap.size() == 0) continue;
+                        TreeMap<Long, Integer> statMap = new TreeMap<>();
+                        for (String k: facetfieldmap) statMap.put(Long.parseLong(k), facetfieldmap.get(k));
+                        prop.put("hostanalysis_facets_" + fc + "_facetname", facetentry.getKey());
+                        int c = 0; for (Entry<Long, Integer> entry: statMap.entrySet()) {
+                            prop.put("hostanalysis_facets_" + fc + "_facet_" + c + "_key", entry.getKey());
+                            prop.put("hostanalysis_facets_" + fc + "_facet_" + c + "_count", entry.getValue());
+                            prop.put("hostanalysis_facets_" + fc + "_facet_" + c + "_a", "http://localhost:" + sb.getConfigInt("port", 8090) + "/solr/collection1/select?q=host_s:" + host + " AND " + facetentry.getKey() + ":" + entry.getKey() + "&defType=edismax&start=0&rows=1000&fl=sku,crawldepth_i");
+                            c++;
+                        }
+                        prop.put("hostanalysis_facets_" + fc + "_facet", c);
+                        fc++;
+                    }
+                    prop.put("hostanalysis_facets", fc);
+                    prop.put("hostanalysis", 1);
+                }
+            
+            
+                // write file list for subpath
+                boolean delete = false;
+                boolean reload404 = false;
+                if (authorized && post.containsKey("delete")) {
+                    // delete the complete path!! That includes everything that matches with this prefix.
+                    delete = true;
+                }
+                if (authorized && post.containsKey("reload404")) {
+                    // try to re-load all urls that have load errors and matches with this prefix.
+                    reload404 = true;
+                }
+                int facetcount=post.getInt("facetcount", 0);
+                boolean complete = post.getBoolean("complete");
+                if (complete) { // we want only root paths for complete lists
+                    p = path.indexOf('/', 10);
+                    if (p > 0) path = path.substring(0, p + 1);
+                }
+                prop.put("files_complete", complete ? 1 : 0);
+                prop.put("files_complete_admin", admin ? "true" : "false");
+                prop.putHTML("files_complete_path", path);
+                p = path.substring(0, path.length() - 1).lastIndexOf('/');
+                if (p < 8) {
+                    prop.put("files_root", 1);
+                } else {
+                    prop.put("files_root", 0);
+                    prop.putHTML("files_root_path", path.substring(0, p + 1));
+                    prop.put("files_root_admin", admin ? "true" : "false");
+                }
+                // generate file list from path
                 prop.putHTML("outbound_host", host);
                 if (authorized) prop.putHTML("outbound_admin_host", host); //used for WebStructurePicture_p link
                 prop.putHTML("inbound_host", host);
@@ -287,7 +335,13 @@ public class HostBrowser {
                 
                 // get all files for a specific host from the index
                 StringBuilder q = new StringBuilder();
-                if (host != null) q.append(CollectionSchema.host_s.getSolrFieldName()).append(':').append(host);
+                if (host == null) {
+                    if (path.startsWith("file://")) {
+                        q.append(CollectionSchema.url_protocol_s.getSolrFieldName()).append(":file");
+                    }
+                } else {
+                    q.append(CollectionSchema.host_s.getSolrFieldName()).append(":\"").append(host).append("\"");
+                }
                 if (pathparts.length > 0 && pathparts[0].length() > 0) {
                     for (String pe: pathparts) {
                         if (pe.length() > 0) q.append(" AND ").append(CollectionSchema.url_paths_sxt.getSolrFieldName()).append(":\"").append(pe).append('\"');
@@ -297,7 +351,7 @@ public class HostBrowser {
                         q.append(" AND ").append(CollectionSchema.url_paths_sxt.getSolrFieldName()).append(AbstractSolrConnector.CATCHALL_DTERM);
                     }
                 }
-                BlockingQueue<SolrDocument> docs = fulltext.getDefaultConnector().concurrentDocumentsByQuery(q.toString(), CollectionSchema.url_chars_i.getSolrFieldName() + " asc", 0, 100000, TIMEOUT, 100, 1,
+                BlockingQueue<SolrDocument> docs = fulltext.getDefaultConnector().concurrentDocumentsByQuery(q.toString(), CollectionSchema.url_chars_i.getSolrFieldName() + " asc", 0, 100000, TIMEOUT, 100, 1, false,
                         CollectionSchema.id.getSolrFieldName(),
                         CollectionSchema.sku.getSolrFieldName(),
                         CollectionSchema.failreason_s.getSolrFieldName(),
@@ -514,7 +568,7 @@ public class HostBrowser {
                 prop.put("files_subpathdetectedsize", filecounter - storedDocs.size());
                 prop.put("files", 1);
                 uri = new DigestURL(path);
-                prop.put("files_linkgraph", uri.getPath().length() <= 1 && hostsize > 0);
+                prop.put("files_linkgraph", uri.getPath().length() <= 1 && hostsize > 0 && sb.getConfigBool(SwitchboardConstants.DECORATION_GRAFICS_LINKSTRUCTURE, true));
                 prop.put("files_linkgraph_host", uri.getHost());
 
                 // generate inbound-links table
