@@ -32,6 +32,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.regex.Matcher;
@@ -109,21 +110,33 @@ public class Network {
                 prop.putHTML("table_my-name", seed.get(Seed.NAME, "-") );
                 prop.put("table_my-hash", seed.hash );
                 prop.put("table_my-ssl", sb.peers.mySeed().getFlagSSLAvailable() ? 1 : 0);
-                if (sb.peers.mySeed().isVirgin()) {
+                if (seed.isVirgin()) {
                     prop.put("table_my-info", 0);
-                } else if(sb.peers.mySeed().isJunior()) {
+                } else if (seed.isJunior()) {
                     prop.put("table_my-info", 1);
                     accPotLinks += LCount;
                     accPotWords += ICount;
-                } else if(sb.peers.mySeed().isSenior()) {
+                } else if (seed.isSenior()) {
                     prop.put("table_my-info", 2);
                     accActLinks += LCount;
                     accActWords += ICount;
-                } else if(sb.peers.mySeed().isPrincipal()) {
+                } else if (seed.isPrincipal()) {
                     prop.put("table_my-info", 3);
                     accActLinks += LCount;
                     accActWords += ICount;
                 }
+                String port = seed.get(Seed.PORT, "-");
+                Set<String> ips = seed.getIPs();
+                int ipsc = 0;
+                for (String s: ips) {
+                    prop.put("table_ips_" + ipsc + "_nodestate", seed.getFlagRootNode() ? 1 : 0);
+                    prop.put("table_ips_" + ipsc + "_c", 0);
+                    prop.putHTML("table_ips_" + ipsc + "_c_hash", seed.hash);
+                    prop.putHTML("table_ips_" + ipsc + "_c_ip", s);
+                    prop.putHTML("table_ips_" + ipsc + "_c_port", port);
+                    prop.put("table_ips_" + ipsc++ + "_c_ipv6", s.indexOf(':') >= 0 ? 1 : 0);
+                }
+                prop.put("table_ips", ipsc);
                 prop.put("table_my-acceptcrawl", seed.getFlagAcceptRemoteCrawl() ? 1 : 0);
                 prop.put("table_my-dhtreceive", seed.getFlagAcceptRemoteIndex() ? 1 : 0);
                 prop.put("table_my-nodestate", seed.getFlagRootNode() ? 1 : 0);
@@ -186,12 +199,12 @@ public class Network {
             prop.put("table", 2); // triggers overview
             prop.put("page", 0);
         } else if (post != null && post.getInt("page", 1) == 4) {
-            prop.put("table", 4); // triggers overview
+            prop.put("table", 4); // triggers "Manually contacting Peer"
             prop.put("page", 4);
 
             if (sb.peers.mySeed() != null) {
 	            prop.put("table_my-hash", sb.peers.mySeed().hash );
-	            prop.put("table_my-ip", sb.peers.mySeed().getIP() );
+	            prop.put("table_my-ip", sb.peers.mySeed().getIPs().toString());
 	            prop.put("table_my-port", sb.peers.mySeed().getPort() );
             }
 
@@ -205,24 +218,32 @@ public class Network {
                 }
 
                 final ConcurrentMap<String, String> map = new ConcurrentHashMap<String, String>();
-                map.put(Seed.IP, post.get("peerIP"));
-                map.put(Seed.PORT, post.get("peerPort"));
-                Seed peer = new Seed(post.get("peerHash"), map);
-
+                String challengeIP = post.get("peerIP");
+                String challengePort = post.get("peerPort");
+                map.put(Seed.IP, challengeIP);
+                map.put(Seed.PORT, challengePort);
+                Seed peer = post.get("peerHash") == null ? null : new Seed(post.get("peerHash"), map);
+                String challengeAddress = peer.getPublicAddress(challengeIP);
                 sb.updateMySeed();
-                final int added = Protocol.hello(sb.peers.mySeed(), sb.peers.peerActions, peer.getPublicAddress(), peer.hash, peer.getName());
+                Seed mySeed = sb.peers.mySeed();
+                final Map<String, String> response = Protocol.hello(mySeed, sb.peers.peerActions, challengeAddress, peer.hash);
 
-                if (added <= 0) {
+                if (response == null) {
+                    Seed peerd = sb.peers.get(peer.hash);
+                    if (peerd != null) peer = peerd;
+                    sb.peers.peerActions.interfaceDeparture(peer, challengeIP);
                     prop.put("table_comment",1);
-                    prop.putHTML("table_comment_status","publish: disconnected peer '" + peer.getName() + "/" + post.get("peerHash") + "' from " + peer.getPublicAddress());
+                    prop.put("table_comment_status", "publish: no response from peer '" + peer.getName() + "/" + post.get("peerHash") + "' from <a href=\"http://" + challengeAddress + "\" target=\"_blank\">" + challengeAddress + "</a>");
                 } else {
+                    String yourtype = response.get("yourtype");
+                    String yourip = response.get("yourip");
                     peer = sb.peers.getConnected(peer.hash);
                     if (peer == null) {
                         prop.put("table_comment",1);
-                        prop.putHTML("table_comment_status","publish: disconnected peer 'UNKNOWN/" + post.get("peerHash") + "' from UNKNOWN");
+                        prop.put("table_comment_status","publish: disconnected peer 'UNKNOWN/" + post.get("peerHash") + "' from <a href=\"http://" + challengeAddress + "\" target=\"_blank\">" + challengeAddress + "</a>, yourtype = " + yourtype + ", yourip = " + yourip);
                     } else {
                         prop.put("table_comment",2);
-                        prop.putHTML("table_comment_status","publish: handshaked " + peer.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + peer.getName() + "' at " + peer.getPublicAddress());
+                        prop.put("table_comment_status","publish: handshaked " + peer.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + peer.getName() + "' at <a href=\"http://" + challengeAddress + "\" target=\"_blank\">" + challengeAddress + "</a>, yourtype = " + yourtype + ", yourip = " + yourip);
                         prop.putHTML("table_comment_details",peer.toString());
                     }
                 }
@@ -237,6 +258,9 @@ public class Network {
 
                 prop.put("table_comment",0);
             }
+        } else if (post != null && post.getInt("page", 1) == 5) {
+            prop.put("page", 5); // triggers stats page
+            prop.put("table", 5);
         } else {
             // generate table
             final int page = (post == null ? 1 : post.getInt("page", 1));
@@ -285,7 +309,7 @@ public class Network {
 
                     boolean dark = true;
                     Seed seed;
-                    final boolean complete = (post != null && post.containsKey("ip"));
+                    final boolean c = (post != null && post.containsKey("ip"));
                     final boolean onlyIncomingDHT = (post != null && post.containsKey("onlydhtin"));
                     final boolean onlyNode = (post != null && post.containsKey("onlynode"));
                     final long onlyAgeOverDays = post == null ? 0 : post.getLong("onlyageoverdays", 0);
@@ -341,6 +365,7 @@ public class Network {
                             prop.put(STR_TABLE_LIST + conCount + "_updatedWikiPage", 0);
                             prop.put(STR_TABLE_LIST + conCount + "_updatedBlog", 0);
                             prop.put(STR_TABLE_LIST + conCount + "_isCrawling", 0);
+                            String ip = seed.getIP();
                             if (conCount >= maxCount) { break; }
                             if (sb.peers != null && sb.peers.mySeed() != null && seed.hash != null && seed.hash.equals(sb.peers.mySeed().hash)) {
                                 prop.put(STR_TABLE_LIST + conCount + "_dark", 2);
@@ -356,7 +381,7 @@ public class Network {
                             } else {
                                 prop.put(STR_TABLE_LIST + conCount + "_updatedWiki", 1);
                                 prop.putHTML(STR_TABLE_LIST + conCount + "_updatedWiki_page", wikiMap.get("page"));
-                                prop.put(STR_TABLE_LIST + conCount + "_updatedWiki_address", seed.getPublicAddress());
+                                prop.put(STR_TABLE_LIST + conCount + "_updatedWiki_address", seed.getPublicAddress(ip));
                             }
                             if ((blogMap = updatedBlog.get(seed.hash)) == null) {
                                 prop.put(STR_TABLE_LIST + conCount + "_updatedBlog", 0);
@@ -364,7 +389,7 @@ public class Network {
                                 prop.put(STR_TABLE_LIST + conCount + "_updatedBlog", 1);
                                 prop.putHTML(STR_TABLE_LIST + conCount + "_updatedBlog_page", blogMap.get("page"));
                                 prop.putHTML(STR_TABLE_LIST + conCount + "_updatedBlog_subject", blogMap.get("subject"));
-                                prop.put(STR_TABLE_LIST + conCount + "_updatedBlog_address", seed.getPublicAddress());
+                                prop.put(STR_TABLE_LIST + conCount + "_updatedBlog_address", seed.getPublicAddress(ip));
                             }
                             PPM = seed.getPPM();
                             QPM = seed.getQPM();
@@ -386,28 +411,38 @@ public class Network {
                                 userAgent = ClientIdentification.yacyInternetCrawlerAgent.userAgent;
                                 location = ClientIdentification.generateLocation();
                             } else {
-                                userAgent = sb.peers.peerActions.getUserAgent(seed.getIP());
+                                userAgent = sb.peers.peerActions.getUserAgent(ip);
                                 location = ClientIdentification.parseLocationInUserAgent(userAgent);
                             }
                             if (location.length() > 10) location = location.substring(0, 10);
                             if (location.length() == 0) {
-                                Locale l = Domains.getLocale(seed.getIP());
+                                Locale l = Domains.getLocale(ip);
                                 if (l != null) location = l.toString();
                             }
                             prop.putHTML(STR_TABLE_LIST + conCount + "_location", location);
-                            if (complete) {
-                                prop.put(STR_TABLE_LIST + conCount + "_complete", 1);
-                                prop.put(STR_TABLE_LIST + conCount + "_complete_ip", seed.getIP() );
-                                prop.put(STR_TABLE_LIST + conCount + "_complete_port", seed.get(Seed.PORT, "-") );
-                                prop.put(STR_TABLE_LIST + conCount + "_complete_hash", seed.hash);
-                                prop.put(STR_TABLE_LIST + conCount + "_complete_age", seed.getAge());
-                                prop.putNum(STR_TABLE_LIST + conCount + "_complete_seeds", seed.getLong(Seed.SCOUNT, 0L));
-                                prop.putNum(STR_TABLE_LIST + conCount + "_complete_connects", seed.getFloat(Seed.CCOUNT, 0F));
-                                prop.putHTML(STR_TABLE_LIST + conCount + "_complete_userAgent", userAgent);
+                            String port = seed.get(Seed.PORT, "-");
+                            Set<String> ips = seed.getIPs();
+                            int ipsc = 0;
+                            for (String s: ips) {
+                                prop.put(STR_TABLE_LIST + conCount + "_ips_" + ipsc + "_nodestate", seed.getFlagRootNode() ? 1 : 0);
+                                prop.put(STR_TABLE_LIST + conCount + "_ips_" + ipsc + "_c", c ? 1 : 0);
+                                prop.putHTML(STR_TABLE_LIST + conCount + "_ips_" + ipsc + "_c_hash", seed.hash);
+                                prop.putHTML(STR_TABLE_LIST + conCount + "_ips_" + ipsc + "_c_ip", s);
+                                prop.putHTML(STR_TABLE_LIST + conCount + "_ips_" + ipsc + "_c_port", port);
+                                prop.put(STR_TABLE_LIST + conCount + "_ips_" + ipsc++ + "_c_ipv6", s.indexOf(':') >= 0 ? 1 : 0);
+                            }
+                            prop.put(STR_TABLE_LIST + conCount + "_ips", ipsc);
+                            prop.put(STR_TABLE_LIST + conCount + "_port", port);
+                            prop.put(STR_TABLE_LIST + conCount + "_hash", seed.hash);
+                            prop.put(STR_TABLE_LIST + conCount + "_age", seed.getAge());
+                            prop.putNum(STR_TABLE_LIST + conCount + "_seeds", seed.getLong(Seed.SCOUNT, 0L));
+                            prop.putNum(STR_TABLE_LIST + conCount + "_connects", seed.getFloat(Seed.CCOUNT, 0F));
+                            if (c) {
+                                prop.put(STR_TABLE_LIST + conCount + "_c", 1);
+                                prop.putHTML(STR_TABLE_LIST + conCount + "_c_userAgent", userAgent);
                             } else {
-                                prop.put(STR_TABLE_LIST + conCount + "_complete", 0);
+                                prop.put(STR_TABLE_LIST + conCount + "_c", 0);
                             }
-
 
                             if (seed.isJunior()) {
                                 prop.put(STR_TABLE_LIST + conCount + "_type", 0);
@@ -446,9 +481,6 @@ public class Network {
                                     prop.put(STR_TABLE_LIST + conCount + "_dhtreceive", 0);  // red/red; offline was off
                                 }
                             }
-                            prop.put(STR_TABLE_LIST + conCount + "_nodestate", seed.getFlagRootNode() ? 1 : 0);
-                            prop.put(STR_TABLE_LIST + conCount + "_nodestate_ip", seed.getIP() );
-                            prop.put(STR_TABLE_LIST + conCount + "_nodestate_port", seed.get(Seed.PORT, "-") );
                             if (seed.getFlagAcceptRemoteIndex()) {
                                 prop.put(STR_TABLE_LIST + conCount + "_dhtreceive_peertags", "");
                             } else {
@@ -478,7 +510,7 @@ public class Network {
                     prop.put("table", 1);
                     prop.putNum("table_num", conCount);
                     prop.putNum("table_total", ((page == 1) && (iAmActive)) ? (size + 1) : size );
-                    prop.put("table_complete", ((complete)? 1 : 0) );
+                    prop.put("table_c", ((c)? 1 : 0) );
                 }
             }
             prop.put("page", page);
