@@ -99,7 +99,7 @@ public class SettingsAck_p {
             /*
              * display port info
              */
-            prop.putHTML("info_port", env.getConfig("port", "8090"));
+            prop.put("info_port", env.getLocalPort("port", 8090));
             prop.put("info_restart", "0");
      
             // read and process data
@@ -154,7 +154,12 @@ public class SettingsAck_p {
             boolean isTransparentProxy = post.containsKey("isTransparentProxy");
             env.setConfig("isTransparentProxy", isTransparentProxy);
             prop.put("info_isTransparentProxy", isTransparentProxy ? "on" : "off");
-
+            
+            // set proxyAlwaysFresh flag
+            boolean proxyAlwaysFresh = post.containsKey("proxyAlwaysFresh");
+            env.setConfig("proxyAlwaysFresh", proxyAlwaysFresh);
+            prop.put("info_proxyAlwaysFresh", proxyAlwaysFresh ? "on" : "off");
+            
             // setting via header property
             env.setConfig("proxy.sendViaHeader", post.containsKey("proxy.sendViaHeader"));
             prop.put("info_proxy.sendViaHeader", post.containsKey("proxy.sendViaHeader")? "on" : "off");
@@ -169,6 +174,12 @@ public class SettingsAck_p {
 
         // server access
         if (post.containsKey("serveraccount")) {
+        	
+        	// fileHost
+        	String fileHost = (post.get("fileHost")).trim();
+        	if (fileHost != null && !fileHost.isEmpty() && !fileHost.equals(env.getConfig("fileHost", "localpeer"))) {
+        		env.setConfig("fileHost", fileHost);
+        	}
 
             // static IP
             String staticIP =  (post.get("staticIP")).trim();
@@ -177,7 +188,7 @@ public class SettingsAck_p {
             } else if (staticIP.startsWith("https://")) {
                 if (staticIP.length() > 8) { staticIP = staticIP.substring(8); } else { staticIP = ""; }
             }
-            String error = Seed.isProperIP(staticIP);
+            String error = Seed.isProperIP(staticIP) ? null : "ip not proper: " + staticIP;
             if (error == null) {
                 serverCore.useStaticIP = true;
                 sb.peers.mySeed().setIP(staticIP);
@@ -483,7 +494,7 @@ public class SettingsAck_p {
         // change https port
         if (post.containsKey("port.ssl")) {
             int port = post.getInt("port.ssl", 8443);
-            if (port > 0 && port != env.getConfigInt("port", 8090)) {
+            if (port > 0 && port != env.getLocalPort("port", 8090)) {
                 env.setConfig("port.ssl", port);
             }
             prop.put("info_port.ssl", port);
