@@ -27,8 +27,10 @@
 // javac -classpath .:../Classes Status.java
 // if the shell's current path is HTROOT
 
-import java.net.InetAddress;
+import java.lang.management.ManagementFactory;
+import java.lang.management.ThreadMXBean;
 import java.util.Date;
+import java.util.Set;
 
 import net.yacy.cora.protocol.ConnectionInfo;
 import net.yacy.cora.protocol.Domains;
@@ -189,8 +191,9 @@ public class Status
         } else {
             prop.put("extPortFormat", "0");
         }
-        final InetAddress hostIP = Domains.myPublicLocalIP();
-        prop.put("host", hostIP != null ? hostIP.getHostAddress() : "Unkown IP");
+
+        Set<String> ips = Domains.myPublicIPs();
+        prop.put("host", ips.toString());
 
         // ssl support
         prop.put("sslSupport", sb.getConfig("keyStore", "").isEmpty() || !sb.getConfigBool("server.https", false) ? 0 : 1);
@@ -227,12 +230,12 @@ public class Status
             prop.putNum("peerStatistics_disconnects", sb.peers.peerActions.disconnects);
             prop.put("peerStatistics_connects", Formatter.number(sb.peers.mySeed().get(Seed.CCOUNT, "0")));
             thisHash = sb.peers.mySeed().hash;
-            if ( sb.peers.mySeed().getPublicAddress() == null ) {
+            if ( sb.peers.mySeed().getIPs().size() == 0 ) {
                 prop.put("peerAddress", "0"); // not assigned + instructions
                 prop.put("warningGoOnline", "1");
             } else {
                 prop.put("peerAddress", "1"); // Address
-                prop.put("peerAddress_address", sb.peers.mySeed().getPublicAddress());
+                prop.put("peerAddress_address", sb.peers.mySeed().getPublicAddress(sb.peers.mySeed().getIP()));
                 prop.putXML("peerAddress_peername", sb.peers.mySeed().getName().toLowerCase());
             }
         }
@@ -321,6 +324,11 @@ public class Status
         prop.put("freeDisk", Formatter.bytesToString(sb.observer.getUsableSpace()));
         prop.put("processors", WorkflowProcessor.availableCPU);
         prop.put("load", Memory.load());
+        ThreadMXBean threadbean = ManagementFactory.getThreadMXBean();
+        prop.put("processesCurrentInclDaemon", threadbean.getThreadCount());
+        prop.put("processesCurrentOnlyDaemon", threadbean.getDaemonThreadCount());
+        prop.put("processesTotal", threadbean.getTotalStartedThreadCount());
+        prop.put("processesPeak", threadbean.getPeakThreadCount());
 
         // proxy traffic
         //prop.put("trafficIn",bytesToString(httpdByteCountInputStream.getGlobalCount()));
