@@ -126,8 +126,8 @@ public class Table_API_p {
                         if (action.equals("selminutes") && time > 0 && time < 10) {
                             row.put(WorkTables.TABLE_API_COL_APICALL_SCHEDULE_TIME, 10);
                         }
-                        if (action.equals("selminutes") && time > 50) {
-                            row.put(WorkTables.TABLE_API_COL_APICALL_SCHEDULE_TIME, 50);
+                        if (action.equals("selminutes") && time > 59) {
+                            row.put(WorkTables.TABLE_API_COL_APICALL_SCHEDULE_TIME, 59);
                         }
                         if (action.equals("selhours") && time > 23) {
                             row.put(WorkTables.TABLE_API_COL_APICALL_SCHEDULE_TIME, 23);
@@ -206,7 +206,7 @@ public class Table_API_p {
             }
 
             // now call the api URLs and store the result status
-            final Map<String, Integer> l = sb.tables.execAPICalls(Domains.LOCALHOST, (int) sb.getConfigLong("port", 8090), pks, sb.getConfig(SwitchboardConstants.ADMIN_ACCOUNT_USER_NAME, "admin"), sb.getConfig(SwitchboardConstants.ADMIN_ACCOUNT_B64MD5, ""));
+            final Map<String, Integer> l = sb.tables.execAPICalls(Domains.LOCALHOST, sb.getLocalPort("port", 8090), pks, sb.getConfig(SwitchboardConstants.ADMIN_ACCOUNT_USER_NAME, "admin"), sb.getConfig(SwitchboardConstants.ADMIN_ACCOUNT_B64MD5, ""));
 
             // construct result table
             prop.put("showexec", l.isEmpty() ? 0 : 1);
@@ -240,34 +240,32 @@ public class Table_API_p {
         try {
             tablesize = sb.tables.size(WorkTables.TABLE_API_NAME);
             final Iterator<Tables.Row> plainIterator = sb.tables.iterator(WorkTables.TABLE_API_NAME);
-            final Iterator<Tables.Row> mapIterator = sb.tables.orderBy(plainIterator, -1, WorkTables.TABLE_API_COL_DATE_RECORDING).iterator();
+            final Iterator<Tables.Row> mapIterator = Tables.orderBy(plainIterator, -1, WorkTables.TABLE_API_COL_DATE_RECORDING).iterator();
             Tables.Row r;
             boolean dark = true;
             boolean scheduledactions = false;
             int c = 0;
+            byte[] typeb, commentb, urlb;
             String type, comment, url;
             // first prepare a list
             while (mapIterator.hasNext()) {
                 r = mapIterator.next();
-                if (r == null) {
-                    continue;
-                }
-                type = UTF8.String(r.get(WorkTables.TABLE_API_COL_TYPE));
-                if (!typefilter.matcher(type).matches()) {
-                    continue;
-                }
-                comment = UTF8.String(r.get(WorkTables.TABLE_API_COL_COMMENT));
-                url = UTF8.String(r.get(WorkTables.TABLE_API_COL_URL));
-                if (!(query.matcher(comment).matches() || query.matcher(url).matches())) {
-                    continue;
-                }
-                if (c >= startRecord) {
-                    table.add(r);
-                }
+                if (r == null) continue;
+                typeb = r.get(WorkTables.TABLE_API_COL_TYPE);
+                if (typeb == null) continue;
+                type = UTF8.String(typeb);
+                if (!typefilter.matcher(type).matches()) continue;
+                commentb = r.get(WorkTables.TABLE_API_COL_COMMENT);
+                if (commentb == null) continue;
+                comment = UTF8.String(commentb);
+                if (!query.matcher(comment).matches()) continue;
+                urlb = r.get(WorkTables.TABLE_API_COL_URL);
+                if (urlb == null) continue;
+                url = UTF8.String(urlb);
+                if (!query.matcher(url).matches()) continue;
+                if (c >= startRecord) table.add(r);
                 c++;
-                if (table.size() >= maximumRecords) {
-                    break;
-                }
+                if (table.size() >= maximumRecords) break;
             }
             // then work on the list
             for (final Tables.Row row : table) {
@@ -297,7 +295,7 @@ public class Table_API_p {
                 } else {
                     prop.put("showtable_list_" + count + "_isCrawlerStart", 0);
                 }
-                prop.putHTML("showtable_list_" + count + "_inline_url", "http://" + sb.myPublicIP() + ":" + sb.getConfig("port", "8090") + UTF8.String(row.get(WorkTables.TABLE_API_COL_URL)));
+                prop.putHTML("showtable_list_" + count + "_inline_url", "http://" + sb.myPublicIP() + ":" + sb.getPublicPort("port", 8090) + UTF8.String(row.get(WorkTables.TABLE_API_COL_URL)));
                 prop.put("showtable_list_" + count + "_scheduler_inline", inline ? "true" : "false");
                 prop.put("showtable_list_" + count + "_scheduler_filter", typefilter.pattern());
                 prop.put("showtable_list_" + count + "_scheduler_query", query.pattern());
