@@ -31,6 +31,7 @@ import java.io.IOException;
 import java.net.MalformedURLException;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.Map;
 
@@ -155,8 +156,10 @@ public class ViewFile {
             url = urlEntry.url();
             descr = urlEntry.dc_title();
             //urlEntry.wordCount();
-            size = urlEntry.size();
+            size = urlEntry.filesize();
             pre = urlEntry.flags().get(Condenser.flag_cat_indexof);
+            prop.put("moar", 1);
+            prop.putHTML("moar_search", post.get("search",""));
         }
 
         prop.put("error_inurldb", urlEntry == null ? 0 : 1);
@@ -168,8 +171,6 @@ public class ViewFile {
             return prop;
         }
         prop.put("url", url.toNormalform(true));
-        prop.put("moar", 1);
-        prop.putHTML("moar_search", post.get("search",""));
 
         // loading the resource content as byte array
         prop.put("error_incache", Cache.has(url.hash()) ? 1 : 0);
@@ -177,7 +178,8 @@ public class ViewFile {
         Response response = null;
         try {
             ClientIdentification.Agent agent = ClientIdentification.getAgent(post.get("agentName", ClientIdentification.yacyInternetCrawlerAgentName));
-            response = sb.loader.load(sb.loader.request(url, true, false), authorized ? CacheStrategy.IFEXIST : CacheStrategy.CACHEONLY, Integer.MAX_VALUE, null, agent);
+            // use sb.loader.requst( , , global=true) to use crawlprofile to allow index update
+            response = sb.loader.load(sb.loader.request(url, true, true), authorized ? CacheStrategy.IFEXIST : CacheStrategy.CACHEONLY, Integer.MAX_VALUE, null, agent);
         } catch (final IOException e) {
             prop.put("error", "4");
             prop.put("error_errorText", "error loading resource: " + e.getMessage());
@@ -373,12 +375,19 @@ public class ViewFile {
                 prop.put("showSnippet_teasertext", desc);
                 prop.put("showSnippet", 1);
             }
+            // update index with parsed resouce if index entry is older
+            if (urlEntry.loaddate().before(response.lastModified())) {
+                Switchboard.getSwitchboard().toIndexer(response);
+            }
             if (document != null) document.close();
         }
         prop.put("error", "0");
         prop.put("error_url", url.toNormalform(true));
         prop.put("error_hash", urlHash);
         prop.put("error_wordCount", wordCount);
+        prop.put("error_firstSeen", "");
+        long firstseen = sb.index.getFirstSeenTime(ASCII.getBytes(urlHash));
+        prop.put("error_firstSeen", firstseen < 0 ? "" : new Date(firstseen).toString());
         prop.putHTML("error_desc", (descr.isEmpty()) ? "&nbsp;" : descr);
         prop.putNum("error_size", size);
         prop.put("error_mimeTypeAvailable", (response.getMimeType() == null) ? "0" : "1");
