@@ -28,7 +28,6 @@
 // if the shell's current path is HTROOT
 
 import java.io.IOException;
-import java.net.InetAddress;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.ConcurrentModificationException;
@@ -46,7 +45,7 @@ import net.yacy.cora.document.encoding.UTF8;
 import net.yacy.cora.document.feed.RSSMessage;
 import net.yacy.cora.document.id.DigestURL;
 import net.yacy.cora.document.id.MultiProtocolURL;
-import net.yacy.cora.federate.opensearch.OpenSearchConnector;
+import net.yacy.cora.federate.FederateSearchManager;
 import net.yacy.cora.federate.yacy.CacheStrategy;
 import net.yacy.cora.geo.GeoLocation;
 import net.yacy.cora.lod.vocabulary.Tagging;
@@ -56,6 +55,7 @@ import net.yacy.cora.protocol.HeaderFramework;
 import net.yacy.cora.protocol.RequestHeader;
 import net.yacy.cora.protocol.ResponseHeader;
 import net.yacy.cora.util.ConcurrentLog;
+import net.yacy.data.BookmarksDB.Bookmark;
 import net.yacy.data.DidYouMean;
 import net.yacy.data.UserDB;
 import net.yacy.data.ymark.YMarkTables;
@@ -88,6 +88,7 @@ import net.yacy.search.ranking.RankingProfile;
 import net.yacy.server.serverObjects;
 import net.yacy.server.serverSwitch;
 import net.yacy.server.servletProperties;
+import net.yacy.utils.crypt;
 
 public class yacysearch {
 
@@ -118,7 +119,7 @@ public class yacysearch {
         if (authenticated && sb.getThread(SwitchboardConstants.CRAWLJOB_LOCAL_CRAWL).getJobCount() > 0) {
             sb.index.fulltext().commit(true);
         }
-        
+        final boolean focus  = (post == null) ? true : post.get("focus", "1").equals("1");
         // get query
         final String originalquerystring = (post == null) ? "" : post.get("query", post.get("search", "")).trim();
         String querystring = originalquerystring.replace('+', ' ').trim();
@@ -147,7 +148,7 @@ public class yacysearch {
         // adding some additional properties needed for the rss feed
         String hostName = header.get("Host", Domains.LOCALHOST);
         if ( hostName.indexOf(':', 0) == -1 ) {
-            hostName += ":" + env.getConfig("port", "8090");
+            hostName += ":" + env.getLocalPort("port", 8090);
         }
         prop.put("searchBaseURL", "http://" + hostName + "/yacysearch.html");
         prop.put("rssYacyImageURL", "http://" + hostName + "/env/grafics/yacy.png");
@@ -168,10 +169,8 @@ public class yacysearch {
             prop.put("resource", "global");
             prop.put("urlmaskfilter", (post == null) ? ".*" : post.get("urlmaskfilter", ".*"));
             prop.put("prefermaskfilter", (post == null) ? "" : post.get("prefermaskfilter", ""));
-            prop.put("tenant", (post == null) ? "" : post.get("tenant", ""));
             prop.put("indexof", "off");
             prop.put("constraint", "");
-            prop.put("cat", "href");
             prop.put("depth", "0");
             prop.put(
                 "search.verify",
@@ -348,7 +347,7 @@ public class yacysearch {
             }
         }
 
-        if ( !block && (post == null || post.get("cat", "href").equals("href")) ) {
+        if ( !block ) {
             String urlmask = null;
             String tld = null;
             String inlink = null;
@@ -373,7 +372,7 @@ public class yacysearch {
                 if (querystring.length() == 1) {
                     querystring = Segment.catchallString;
                 } else {
-                    querystring = querystring.replaceAll("* ", Segment.catchallString + " ").replace(" *", " " + Segment.catchallString);
+                    querystring = querystring.replaceAll("\\* ", Segment.catchallString + " ").replace(" \\*", " " + Segment.catchallString);
                 }
             }
             if ( querystring.indexOf("/near", 0) >= 0 ) {
@@ -588,24 +587,31 @@ public class yacysearch {
                 	prop.authenticationRequired();
                     return prop;
                 }
-                final String bookmarkHash = post.get("bookmarkref", ""); // urlhash
-                try {
-                    final DigestURL url = indexSegment.fulltext().getURL(bookmarkHash);
-                    if ( url != null ) {
-                        try {
-                            sb.tables.bookmarks.createBookmark(
+                //final String bookmarkHash = post.get("bookmarkref", ""); // urlhash
+                final String urlstr = crypt.simpleDecode(post.get("bookmarkurl"));
+                if (urlstr != null) {
+                    try {
+                        final Bookmark bmk = sb.bookmarksDB.createBookmark(urlstr, YMarkTables.USER_ADMIN);
+                        bmk.setProperty(Bookmark.BOOKMARK_DESCRIPTION, "query="+querystring);
+                        //bmk.setProperty(Bookmark.BOOKMARK_QUERY, originalquerystring);
+                        bmk.addTag("/search"); // add to bookmark folder
+                        bmk.addTag("searchresult"); // add tag
+                        String urlhash = post.get("bookmarkref");
+                        final URIMetadataNode urlentry = indexSegment.fulltext().getMetadata(UTF8.getBytes(urlhash));
+                        if (urlentry != null && !urlentry.dc_title().isEmpty()) 
+                            bmk.setProperty(Bookmark.BOOKMARK_TITLE,urlentry.dc_title());
+                        sb.bookmarksDB.saveBookmark(bmk);
+
+                        // do the same for YMarks ?
+                        sb.tables.bookmarks.createBookmark(
                                 sb.loader,
-                                url,
+                                urlstr,
                                 ClientIdentification.yacyInternetCrawlerAgent,
                                 YMarkTables.USER_ADMIN,
                                 true,
                                 "searchresult",
                                 "/search");
-                        } catch (final Throwable e ) {
-                        }
-                    }
-                } catch (IOException e) {
-                    ConcurrentLog.logException(e);
+                    } catch (final Throwable e) { }
                 }
             }
 
@@ -713,10 +719,10 @@ public class yacysearch {
                     sb.heuristicSite(theSearch, modifier.sitehost);
                 }
                 if ( heuristicBlekko >= 0  && authenticated && !stealthmode ) {
-                    OpenSearchConnector.query(sb, theSearch);
+                    FederateSearchManager.getManager().search(theSearch);
                 }
                 if (sb.getConfigBool(SwitchboardConstants.HEURISTIC_OPENSEARCH, false) && authenticated && !stealthmode) {
-                    OpenSearchConnector.query(sb, theSearch);
+                    FederateSearchManager.getManager().search(theSearch);
                 }
             }
 
@@ -848,8 +854,8 @@ public class yacysearch {
                 prop.put("excluded", "0");
             }
 
-            if ( prop == null || prop.isEmpty() ) {
-                if ( post.get("query", post.get("search", "")).length() < 2 ) {
+            if (prop.isEmpty() || querystring.length() == 0) {
+                if ( querystring.length() == 0 ) { // querystring is trimmed originalquerystring
                     prop.put("num-results", "2"); // no results - at least 2 chars
                 } else {
                     prop.put("num-results", "1"); // no results
@@ -858,26 +864,21 @@ public class yacysearch {
                 prop.put("num-results", "3");
             }
 
-            prop.put("cat", "href");
             prop.put("depth", "0");
 
         }
-
+        prop.put("focus", focus ? 1 : 0); // focus search field
         prop.put("searchagain", global ? "1" : "0");
-        prop.putHTML("former", originalquerystring);
+        prop.putHTML("former", originalquerystring.replaceAll(Segment.catchallString, "*"));
         prop.put("count", itemsPerPage);
         prop.put("offset", startRecord);
         prop.put("resource", global ? "global" : "local");
         prop.putHTML("prefermaskfilter", prefermask);
         prop.put("indexof", (indexof) ? "on" : "off");
         prop.put("constraint", (constraint == null) ? "" : constraint.exportB64());
-        prop.put("search.verify", snippetFetchStrategy == null
-            ? sb.getConfig("search.verify", "iffresh")
-            : snippetFetchStrategy.toName());
-        prop.put(
-            "search.navigation",
-            (post == null) ? sb.getConfig("search.navigation", "all") : post.get("nav", "all"));
-        prop.put("contentdom", (post == null ? "text" : post.get("contentdom", "text")));
+        prop.put("search.verify", snippetFetchStrategy == null ? sb.getConfig("search.verify", "iffresh") : snippetFetchStrategy.toName());
+        prop.put("search.navigation", (post == null) ? sb.getConfig("search.navigation", "all") : post.get("nav", "all"));
+        prop.putHTML("contentdom", (post == null ? "text" : post.get("contentdom", "text")));
 
         // for RSS: don't HTML encode some elements
         prop.putXML("rss_query", originalquerystring);
@@ -886,9 +887,9 @@ public class yacysearch {
         sb.localSearchLastAccess = System.currentTimeMillis();
 
         // hostname and port (assume locahost if nothing helps)
-        final InetAddress hostIP = Domains.myPublicLocalIP();
-        prop.put("myhost", hostIP != null ? hostIP.getHostAddress() : Domains.LOCALHOST);
-        prop.put("myport", sb.getConfig("port", "8090"));
+        final String hostIP = sb.peers.mySeed().getIP();
+        prop.put("myhost", hostIP != null ? hostIP : Domains.LOCALHOST);
+        prop.put("myport", Domains.LOCALHOST.equals(hostIP) ? sb.getLocalPort("port", 8090) : sb.getPublicPort("port", 8090));
 
         // return rewrite properties
         return prop;
