@@ -24,8 +24,11 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import java.io.IOException;
 import java.net.MalformedURLException;
+import java.util.Collection;
 import java.util.Iterator;
+import java.util.Map;
 
 import net.yacy.cora.date.GenericFormatter;
 import net.yacy.cora.date.ISO8601Formatter;
@@ -42,6 +45,7 @@ import net.yacy.cora.util.ConcurrentLog;
 import net.yacy.cora.util.Memory;
 import net.yacy.crawler.data.Cache;
 import net.yacy.data.URLLicense;
+import net.yacy.kelondro.data.meta.URIMetadataNode;
 import net.yacy.kelondro.util.Formatter;
 import net.yacy.peers.NewsPool;
 import net.yacy.peers.Seed;
@@ -130,12 +134,22 @@ public class yacysearchitem {
             prop.put("content", 1); // switch on specific content
             prop.put("content_authorized", authenticated ? "1" : "0");
             final String urlhash = ASCII.String(result.hash());
-            prop.put("content_authorized_bookmark", sb.tables.bookmarks.hasBookmark("admin", urlhash) ? "0" : "1");
-            prop.putHTML("content_authorized_bookmark_bookmarklink", "yacysearch.html?query=" + origQ.replace(' ', '+') + "&Enter=Search&count=" + theSearch.query.itemsPerPage() + "&offset=" + (theSearch.query.neededResults() - theSearch.query.itemsPerPage()) + "&order=" + crypt.simpleEncode(theSearch.query.ranking.toExternalString()) + "&resource=" + resource + "&time=3&bookmarkref=" + urlhash + "&urlmaskfilter=.*");
-            prop.put("content_authorized_recommend", (sb.peers.newsPool.getSpecific(NewsPool.OUTGOING_DB, NewsPool.CATEGORY_SURFTIPP_ADD, "url", resultUrlstring) == null) ? "1" : "0");
-            prop.putHTML("content_authorized_recommend_deletelink", "yacysearch.html?query=" + origQ.replace(' ', '+') + "&Enter=Search&count=" + theSearch.query.itemsPerPage() + "&offset=" + (theSearch.query.neededResults() - theSearch.query.itemsPerPage()) + "&order=" + crypt.simpleEncode(theSearch.query.ranking.toExternalString()) + "&resource=" + resource + "&time=3&deleteref=" + urlhash + "&urlmaskfilter=.*");
-            prop.putHTML("content_authorized_recommend_recommendlink", "yacysearch.html?query=" + origQ.replace(' ', '+') + "&Enter=Search&count=" + theSearch.query.itemsPerPage() + "&offset=" + (theSearch.query.neededResults() - theSearch.query.itemsPerPage()) + "&order=" + crypt.simpleEncode(theSearch.query.ranking.toExternalString()) + "&resource=" + resource + "&time=3&recommendref=" + urlhash + "&urlmaskfilter=.*");
-            prop.put("content_authorized_urlhash", urlhash);
+            if (authenticated) { // only needed if authorized
+                boolean bookmarkexists;
+                try { // check url exists in bookkmarks
+                    bookmarkexists = sb.bookmarksDB.getBookmark(urlhash) != null;
+                } catch (IOException ex) {
+                    bookmarkexists = false;
+                }
+                prop.put("content_authorized_bookmark", !bookmarkexists);
+                // bookmark icon check for YMarks
+                //prop.put("content_authorized_bookmark", sb.tables.bookmarks.hasBookmark("admin", urlhash) ? "0" : "1");
+                prop.putHTML("content_authorized_bookmark_bookmarklink", "yacysearch.html?query=" + origQ.replace(' ', '+') + "&Enter=Search&count=" + theSearch.query.itemsPerPage() + "&offset=" + (theSearch.query.neededResults() - theSearch.query.itemsPerPage()) + "&resource=" + resource + "&time=3&bookmarkref=" + urlhash + "&bookmarkurl=" + crypt.simpleEncode(resultUrlstring) + "&urlmaskfilter=.*");
+                prop.put("content_authorized_recommend", (sb.peers.newsPool.getSpecific(NewsPool.OUTGOING_DB, NewsPool.CATEGORY_SURFTIPP_ADD, "url", resultUrlstring) == null) ? "1" : "0");
+                prop.putHTML("content_authorized_recommend_deletelink", "yacysearch.html?query=" + origQ.replace(' ', '+') + "&Enter=Search&count=" + theSearch.query.itemsPerPage() + "&offset=" + (theSearch.query.neededResults() - theSearch.query.itemsPerPage()) + "&order=" + crypt.simpleEncode(theSearch.query.ranking.toExternalString()) + "&resource=" + resource + "&time=3&deleteref=" + urlhash + "&urlmaskfilter=.*");
+                prop.putHTML("content_authorized_recommend_recommendlink", "yacysearch.html?query=" + origQ.replace(' ', '+') + "&Enter=Search&count=" + theSearch.query.itemsPerPage() + "&offset=" + (theSearch.query.neededResults() - theSearch.query.itemsPerPage()) + "&order=" + crypt.simpleEncode(theSearch.query.ranking.toExternalString()) + "&resource=" + resource + "&time=3&recommendref=" + urlhash + "&urlmaskfilter=.*");
+                prop.put("content_authorized_urlhash", urlhash);
+            }
             prop.putHTML("content_title", result.title());
             prop.putXML("content_title-xml", result.title());
             prop.putJSON("content_title-json", result.title());
@@ -143,37 +157,34 @@ public class yacysearchitem {
             //prop.putHTML("content_link", resultUrlstring);
 
 // START interaction
-            String modifyURL = resultUrlstring;
-			if (sb.getConfigBool("proxyURL.useforresults", false) && sb.getConfigBool("proxyURL", false)) {
-				// check if url is allowed to view
-				if (sb.getConfig("proxyURL.rewriteURLs", "all").equals("all")) {
-					modifyURL = "./proxy.html?url="+modifyURL;
-				}
-
-				// check if url is allowed to view
-				if (sb.getConfig("proxyURL.rewriteURLs", "all").equals("domainlist")) {
-					try {
-						if (sb.crawlStacker.urlInAcceptedDomain(new DigestURL (modifyURL)) == null) {
-							modifyURL = "./proxy.html?url="+modifyURL;
-						}
-					} catch (final MalformedURLException e) {
-						// TODO Auto-generated catch block
-						e.printStackTrace();
-					}
-				}
-
-				if (sb.getConfig("proxyURL.rewriteURLs", "all").equals("yacy")) {
-					try {
-						if ((new DigestURL (modifyURL).getHost().endsWith(".yacy"))) {
-							modifyURL = "./proxy.html?url="+modifyURL;
-						}
-					} catch (final MalformedURLException e) {
-						// TODO Auto-generated catch block
-						e.printStackTrace();
-					}
-				}
-			}
-            prop.putXML("content_link", modifyURL); // putXML for rss
+            if (sb.getConfigBool("proxyURL.useforresults", false) && sb.getConfigBool("proxyURL", false)) {
+                String modifyURL = resultUrlstring;
+                // check if url is allowed to view
+                final String tmprewritecfg = sb.getConfig("proxyURL.rewriteURLs", "all");
+                if (tmprewritecfg.equals("all")) {
+                    modifyURL = "./proxy.html?url=" + resultUrlstring;
+                } else if (tmprewritecfg.equals("domainlist")) { // check if url is allowed to view
+                    try {
+                        if (sb.crawlStacker.urlInAcceptedDomain(new DigestURL(resultUrlstring)) == null) {
+                            modifyURL = "./proxy.html?url=" + resultUrlstring;
+                        }
+                    } catch (final MalformedURLException e) {
+                        ConcurrentLog.logException(e);
+                    }
+                } else if (tmprewritecfg.equals("yacy")) {
+                    try {
+                        if ((new DigestURL(resultUrlstring).getHost().endsWith(".yacy"))) {
+                            modifyURL = "./proxy.html?url=" + resultUrlstring;
+                        }
+                    } catch (final MalformedURLException e) {
+                        ConcurrentLog.logException(e);
+                    }
+                }
+                prop.putXML("content_link", modifyURL); // putXML for rss
+            } else {
+                prop.putXML("content_link", resultUrlstring); // putXML for rss
+            }
+            
 //            prop.putHTML("content_value", Interaction.TripleGet(result.urlstring(), "http://virtual.x/hasvalue", "anonymous"));
 // END interaction
 
@@ -194,6 +205,7 @@ public class yacysearchitem {
                 prop.put("content_showCache", sb.getConfigBool("search.result.show.cache", true) && Cache.has(resultURL.hash()) ? 1 : 0);
                 prop.put("content_showProxy", sb.getConfigBool("search.result.show.proxy", true) ? 1 : 0);
                 prop.put("content_showHostBrowser", sb.getConfigBool("search.result.show.hostbrowser", true) ? 1 : 0);
+                prop.put("content_showVocabulary", sb.getConfigBool("search.result.show.vocabulary", true) ? 1 : 0);
 
                 prop.put("content_showDate_date", GenericFormatter.RFC1123_SHORT_FORMATTER.format(result.modified()));
                 prop.putHTML("content_showSize_sizename", RSSMessage.sizename(result.filesize()));
@@ -204,6 +216,25 @@ public class yacysearchitem {
                 prop.put("content_showCache_link", resultUrlstring);
                 prop.put("content_showProxy_link", resultUrlstring);
                 prop.put("content_showHostBrowser_link", resultUrlstring);
+                if (sb.getConfigBool("search.result.show.vocabulary", true)) {
+                    URIMetadataNode node = result.getNode();
+                    int c = 0;
+                    for (Map.Entry<String, Object> entry: node.entrySet()) {
+                        String key = entry.getKey();
+                        if (key.startsWith("vocabulary_") && key.endsWith("_sxt")) {
+                            @SuppressWarnings("unchecked")
+                            Collection<String> terms = (Collection<String>) entry.getValue();
+                            prop.putHTML("content_showVocabulary_vocabulary_" + c + "_name", key.substring(11, key.length() - 4));
+                            prop.putHTML("content_showVocabulary_vocabulary_" + c + "_terms", terms.toString());
+                            c++;
+                        }
+                    }
+                    prop.put("content_showVocabulary_vocabulary", c);
+                    prop.put("content_showVocabulary", 1);
+                } else {
+                    prop.put("content_showVocabulary_vocabulary", 0);
+                    prop.put("content_showVocabulary", 0);
+                }
             }
             prop.put("content_urlhexhash", Seed.b64Hash2hexHash(urlhash));
             prop.putHTML("content_urlname", nxTools.shortenURLString(result.urlname(), MAX_URL_LENGTH));
@@ -276,11 +307,12 @@ public class yacysearchitem {
             try {
                 image = theSearch.oneImageResult(item, timeout);
                 final String imageUrlstring = image.imageUrl.toNormalform(true);
+                final String imageUrlExt = MultiProtocolURL.getFileExtension(imageUrlstring);
                 final String target = sb.getConfig(imageUrlstring.matches(target_special_pattern) ? SwitchboardConstants.SEARCH_TARGET_SPECIAL : SwitchboardConstants.SEARCH_TARGET_DEFAULT, "_self");
 
                 final String license = URLLicense.aquireLicense(image.imageUrl); // this is just the license key to get the image forwarded through the YaCy thumbnail viewer, not an actual lawful license
                 //sb.loader.loadIfNotExistBackground(image.imageUrl, 1024 * 1024 * 10, null, ClientIdentification.yacyIntranetCrawlerAgent);
-                prop.putHTML("content_item_hrefCache", "/ViewImage.png?maxwidth=128&maxheight=128&quadratic=&url=" + imageUrlstring);
+                prop.putHTML("content_item_hrefCache", "/ViewImage." + ("gif".equals(imageUrlExt) ? "gif" : "png") + "?maxwidth=128&maxheight=128&isStatic=true&quadratic=&url=" + imageUrlstring);
                 prop.putHTML("content_item_href", imageUrlstring);
                 prop.putHTML("content_item_target", target);
                 prop.put("content_item_code", license);
