@@ -53,9 +53,7 @@ public class yacysearchtrailer {
 
     private static final int TOPWORDS_MAXCOUNT = 16;
     private static final int TOPWORDS_MINSIZE = 8;
-    private static final int TOPWORDS_MAXSIZE = 20;
-    private static final int MAXLIMIT_NAV_LOW = 5;
-    private static final int MAXLIMIT_NAV_HIGH = 20;
+    private static final int TOPWORDS_MAXSIZE = 22;
 
     public static serverObjects respond(final RequestHeader header, final serverObjects post, final serverSwitch env) {
         final serverObjects prop = new serverObjects();
@@ -131,7 +129,6 @@ public class yacysearchtrailer {
                 i++;
             }
             prop.put("nav-namespace_element", i);
-            prop.put("nav-namespace_activate", on(pos, neg, MAXLIMIT_NAV_LOW) ? 1 : 0);
             i--;
             prop.put("nav-namespace_element_" + i + "_nl", 0);
             if (pos == 1 && neg == 0)
@@ -173,7 +170,6 @@ public class yacysearchtrailer {
                 i++;
             }
             prop.put("nav-domains_element", i);
-            prop.put("nav-domains_activate", on(pos, neg, MAXLIMIT_NAV_HIGH) ? 1 : 0);
             i--;
             prop.put("nav-domains_element_" + i + "_nl", 0);
             if (pos == 1 && neg == 0)
@@ -216,7 +212,6 @@ public class yacysearchtrailer {
                 i++;
             }
             prop.put("nav-languages_element", i);
-            prop.put("nav-languages_activate", on(pos, neg, MAXLIMIT_NAV_HIGH) ? 1 : 0);
             i--;
             prop.put("nav-languages_element_" + i + "_nl", 0);
             if (pos == 1 && neg == 0)
@@ -257,7 +252,6 @@ public class yacysearchtrailer {
                 i++;
             }
             prop.put("nav-authors_element", i);
-            prop.put("nav-authors_activate", neg > 0 ? 1 : 0); // by default off
             i--;
             prop.put("nav-authors_element_" + i + "_nl", 0);
             if (pos == 1 && neg == 0)
@@ -265,7 +259,7 @@ public class yacysearchtrailer {
                 prop.put("nav-authors", 0); // this navigation is not useful
             }
         }
-        
+
         // collection navigators
         if (theSearch.collectionNavigator == null || theSearch.collectionNavigator.isEmpty()) {
             prop.put("nav-collections", 0);
@@ -298,7 +292,6 @@ public class yacysearchtrailer {
                 i++;
             }
             prop.put("nav-collections_element", i);
-            prop.put("nav-collections_activate", neg > 0 ? 1 : 0); // by default off
             i--;
             prop.put("nav-collections_element_" + i + "_nl", 0);
             if (pos == 1 && neg == 0)
@@ -339,7 +332,7 @@ public class yacysearchtrailer {
                 prop.put(fileType, "nav-topics_element_" + i + "_name", name);
                 prop.put(fileType, "nav-topics_element_" + i + "_url", QueryParams.navurl(fileType, 0, theSearch.query, name, false).toString());
                 prop.put("nav-topics_element_" + i + "_count", count);
-                int fontsize = TOPWORDS_MINSIZE + (TOPWORDS_MAXSIZE - TOPWORDS_MINSIZE) * (count - mincount) / (maxcount / mincount);
+                int fontsize = TOPWORDS_MINSIZE + (TOPWORDS_MAXSIZE - TOPWORDS_MINSIZE) * (count - mincount) / (maxcount - mincount);
                 fontsize = Math.max(TOPWORDS_MINSIZE, fontsize - (name.length() - 5));
                 prop.put("nav-topics_element_" + i + "_size", fontsize); // font size in pixel
                 prop.put("nav-topics_element_" + i + "_nl", 1);
@@ -349,7 +342,7 @@ public class yacysearchtrailer {
             i--;
             prop.put("nav-topics_element_" + i + "_nl", 0);
         }
-
+        
         // protocol navigators
         if (theSearch.protocolNavigator == null || theSearch.protocolNavigator.isEmpty()) {
             prop.put("nav-protocols", 0);
@@ -393,10 +386,9 @@ public class yacysearchtrailer {
                 i++;
             }
             theSearch.query.modifier.protocol = oldProtocolModifier;
-            if (oldProtocolModifier != null && oldProtocolModifier.length() > 0) theSearch.query.modifier.add(oldProtocolModifier);
+            if (oldProtocolModifier != null && oldProtocolModifier.length() > 0) theSearch.query.modifier.add(oldProtocolModifier.startsWith("/") ? oldProtocolModifier : "/" + oldProtocolModifier);
             theSearch.query.getQueryGoal().query_original = oldQuery;
             prop.put("nav-protocols_element", i);
-            prop.put("nav-protocols_activate", neg > 0 || visible ? 1 : 0); // by default off
             i--;
             prop.put("nav-protocols_element_" + i + "_nl", 0);
             if (pos == 1 && neg == 0)
@@ -439,7 +431,6 @@ public class yacysearchtrailer {
                 i++;
             }
             prop.put("nav-filetypes_element", i);
-            prop.put("nav-filetypes_activate", neg > 0 || visible ? 1 : 0); // by default off
             i--;
             prop.put("nav-filetypes_element_" + i + "_nl", 0);
             if (pos == 1 && neg == 0)
@@ -525,5 +516,5 @@ public class yacysearchtrailer {
     }
 
 }
-//http://localhost:8090/yacysearch.html?query=java+&amp;maximumRecords=10&amp;resource=local&amp;verify=cacheonly&amp;nav=hosts,authors,namespace,topics,filetype,protocol&amp;urlmaskfilter=ftp://.*&amp;prefermaskfilter=&amp;cat=href&amp;constraint=&amp;contentdom=text&amp;former=java+%2Fftp&amp;startRecord=0
-//http://localhost:8090/yacysearch.html?query=java+&amp;maximumRecords=10&amp;resource=local&amp;verify=cacheonly&amp;nav=hosts,authors,namespace,topics,filetype,protocol&amp;urlmaskfilter=.*&amp;prefermaskfilter=&amp;cat=href&amp;constraint=&amp;contentdom=text&amp;former=java+%2Fvocabulary%2FGewerke%2FTore&amp;startRecord=0
+//http://localhost:8090/yacysearch.html?query=java+&amp;maximumRecords=10&amp;resource=local&amp;verify=cacheonly&amp;nav=hosts,authors,namespace,topics,filetype,protocol&amp;urlmaskfilter=ftp://.*&amp;prefermaskfilter=&amp;constraint=&amp;contentdom=text&amp;former=java+%2Fftp&amp;startRecord=0
+//http://localhost:8090/yacysearch.html?query=java+&amp;maximumRecords=10&amp;resource=local&amp;verify=cacheonly&amp;nav=hosts,authors,namespace,topics,filetype,protocol&amp;urlmaskfilter=.*&amp;prefermaskfilter=&amp;constraint=&amp;contentdom=text&amp;former=java+%2Fvocabulary%2FGewerke%2FTore&amp;startRecord=0
