@@ -21,12 +21,16 @@
 package net.yacy.cora.federate.solr.connector;
 
 import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.BlockingQueue;
@@ -49,6 +53,7 @@ import org.apache.solr.common.SolrDocument;
 import org.apache.solr.common.SolrDocumentList;
 import org.apache.solr.common.SolrException;
 import org.apache.solr.common.SolrInputDocument;
+import org.apache.solr.common.SolrInputField;
 import org.apache.solr.common.params.CommonParams;
 import org.apache.solr.common.params.DisMaxParams;
 import org.apache.solr.common.params.FacetParams;
@@ -85,7 +90,9 @@ public abstract class AbstractSolrConnector implements SolrConnector {
         catchSuccessQuery.setRows(0);
         catchSuccessQuery.setStart(0);
     }
-    protected final static int pagesize = 100;
+    
+    protected final static int pagesize_docs = 100;
+    protected final static int pagesize_ids = 1000;
     
     protected static LoadTimeURL getLoadTimeURL(final Object doc) {
         if (doc == null) return null;
@@ -132,7 +139,7 @@ public abstract class AbstractSolrConnector implements SolrConnector {
     }
     
     /**
-     * Get a query result from solr as a stream of documents.
+     * Get results from a solr query as a stream of documents.
      * The result queue is considered as terminated if AbstractSolrConnector.POISON_DOCUMENT is returned.
      * The method returns immediately and feeds the search results into the queue
      * @param querystring the solr query string
@@ -142,7 +149,9 @@ public abstract class AbstractSolrConnector implements SolrConnector {
      * @param maxtime the maximum time in milliseconds
      * @param buffersize the size of an ArrayBlockingQueue; if <= 0 then a LinkedBlockingQueue is used
      * @param concurrency is the number of AbstractSolrConnector.POISON_DOCUMENT entries to add at the end of the feed
-     * @return a blocking queue which is terminated  with AbstractSolrConnector.POISON_DOCUMENT as last element
+     * @param prefetchIDs if true, then first all IDs are fetched and then all documents are queries by the ID. If false then documents are retrieved directly
+     * @param fields list of fields
+     * @return a blocking queue which is terminated with AbstractSolrConnector.POISON_DOCUMENT as last element
      */
     @Override
     public BlockingQueue<SolrDocument> concurrentDocumentsByQuery(
@@ -153,53 +162,156 @@ public abstract class AbstractSolrConnector implements SolrConnector {
             final long maxtime,
             final int buffersize,
             final int concurrency,
+            final boolean prefetchIDs,
+            final String ... fields) {
+        List<String> querystrings = new ArrayList<>(1);
+        querystrings.add(querystring);
+        return concurrentDocumentsByQueries(querystrings, sort, offset, maxcount, maxtime, buffersize, concurrency, prefetchIDs, fields);
+    }
+    
+    /**
+     * Get results from solr queries as a stream of documents.
+     * The result queue is considered as terminated if AbstractSolrConnector.POISON_DOCUMENT is returned.
+     * The method returns immediately and feeds the search results into the queue
+     * @param querystrings the list of solr query strings
+     * @param sort the solr sort string, may be null to be not used
+     * @param offset first result offset
+     * @param maxcount the maximum number of results
+     * @param maxtime the maximum time in milliseconds
+     * @param buffersize the size of an ArrayBlockingQueue; if <= 0 then a LinkedBlockingQueue is used
+     * @param concurrency is the number of AbstractSolrConnector.POISON_DOCUMENT entries to add at the end of the feed
+     * @param prefetchIDs if true, then first all IDs are fetched and then all documents are queries by the ID. If false then documents are retrieved directly
+     * @param fields list of fields
+     * @return a blocking queue which is terminated with AbstractSolrConnector.POISON_DOCUMENT as last element
+     */
+    @Override
+    public BlockingQueue<SolrDocument> concurrentDocumentsByQueries(
+            final List<String> querystrings,
+            final String sort,
+            final int offset,
+            final int maxcount,
+            final long maxtime,
+            final int buffersize,
+            final int concurrency,
+            final boolean prefetchIDs,
+            final String ... fields) {
+        assert buffersize > 0;
+        if (!prefetchIDs) return concurrentDocumentsByQueriesNoPrefetch(querystrings, sort, offset, maxcount, maxtime, buffersize, concurrency, fields);
+        final BlockingQueue<SolrDocument> queue = buffersize <= 0 ? new LinkedBlockingQueue<SolrDocument>() : new ArrayBlockingQueue<SolrDocument>(Math.max(buffersize, concurrency));
+        if (querystrings.size() == 0) {
+            for (int i = 0; i < Math.max(1, concurrency); i++) try {queue.put(AbstractSolrConnector.POISON_DOCUMENT);} catch (final InterruptedException e1) {}
+            return queue;
+        }
+        final BlockingQueue<String> idQueue = concurrentIDsByQueries(querystrings, sort, offset, maxcount, maxtime, Math.min(maxcount, 10000000), concurrency);
+        final long endtime = maxtime < 0 || maxtime == Long.MAX_VALUE ? Long.MAX_VALUE : System.currentTimeMillis() + maxtime; // we know infinity!
+        final Thread[] t = new Thread[concurrency];
+        for (int i = 0; i < Math.max(1, concurrency); i++) {
+            t[i] = new Thread() {
+                @Override
+                public void run() {
+                    this.setName("AbstractSolrConnector:concurrentDocumentsByQueriesWithPrefetch(" + querystrings.size() + " queries, first: " + querystrings.iterator().next() + ")");
+                    String nextID;
+                    try {
+                        while (System.currentTimeMillis() < endtime && (nextID = idQueue.take()) != AbstractSolrConnector.POISON_ID) {
+                            try {
+                                SolrDocument d = getDocumentById(nextID, fields);
+                                // document may be null if another process has deleted the document meanwhile
+                                // in case that the document is absent then, we silently ignore that case
+                                if (d != null) try {queue.put(d);} catch (final InterruptedException e) {}
+                            } catch (final SolrException | IOException e) {
+                                ConcurrentLog.logException(e);
+                                // fail
+                                ConcurrentLog.severe("AbstractSolrConnector", "aborted concurrentDocumentsByQuery: " + e.getMessage());
+                                break;
+                            }
+                        }
+                    } catch (InterruptedException e) {
+                        ConcurrentLog.severe("AbstractSolrConnector", "interrupted concurrentDocumentsByQuery: " + e.getMessage());
+                    }
+                    try {queue.put(AbstractSolrConnector.POISON_DOCUMENT);} catch (final InterruptedException e1) {}
+                }
+            };
+            t[i].start();
+        }
+        return queue;
+    }
+    
+    private BlockingQueue<SolrDocument> concurrentDocumentsByQueriesNoPrefetch(
+            final List<String> querystrings,
+            final String sort,
+            final int offset,
+            final int maxcount,
+            final long maxtime,
+            final int buffersize,
+            final int concurrency,
             final String ... fields) {
         assert buffersize > 0;
         final BlockingQueue<SolrDocument> queue = buffersize <= 0 ? new LinkedBlockingQueue<SolrDocument>() : new ArrayBlockingQueue<SolrDocument>(buffersize);
-        final long endtime = maxtime == Long.MAX_VALUE ? Long.MAX_VALUE : System.currentTimeMillis() + maxtime; // we know infinity!
-        final int ps = Math.min(pagesize, buffersize);
-        final int maxretries = 60;
+        if (querystrings.size() == 0) {
+            for (int i = 0; i < Math.max(1, concurrency); i++) try {queue.put(AbstractSolrConnector.POISON_DOCUMENT);} catch (final InterruptedException e1) {}
+            return queue;
+        }
+        final long endtime = maxtime < 0 || maxtime == Long.MAX_VALUE ? Long.MAX_VALUE : System.currentTimeMillis() + maxtime; // we know infinity!
+        final int ps = buffersize < 0 ? pagesize_docs : Math.min(pagesize_docs, buffersize);
+        final int maxretries = 6;
         final Thread t = new Thread() {
             @Override
             public void run() {
-                this.setName("AbstractSolrConnector:concurrentDocumentsByQuery(" + querystring + ")");
-                int o = offset;
-                int count = 0;
-                int retry = 0;
-                loop: while (System.currentTimeMillis() < endtime && count < maxcount) {
-                    try {
-                        SolrDocumentList sdl = getDocumentListByQuery(querystring, sort, o, Math.min(maxcount, ps), fields);
-                        for (SolrDocument d: sdl) {
-                            try {queue.put(d);} catch (final InterruptedException e) {break;}
-                            count++;
+                try {
+                    for (String querystring: querystrings) {
+                        this.setName("AbstractSolrConnector:concurrentDocumentsByQueryNoPrefetch(" + querystring + ")");
+                        int o = offset;
+                        int count = 0;
+                        int retry = 0;
+                        loop: while (System.currentTimeMillis() < endtime && count < maxcount) {
+                            try {
+                                SolrDocumentList sdl = getDocumentListByQuery(querystring, sort, o, Math.min(maxcount, ps), fields);
+                                for (SolrDocument d: sdl) {
+                                    try {queue.put(d);} catch (final InterruptedException e) {break;}
+                                    count++;
+                                }
+                                if (sdl.size() < ps) {
+                                    //System.out.println("sdl.size() = " + sdl.size() + ", pagesize = " + pagesize);
+                                    break loop; // finished
+                                }
+                                o += sdl.size();
+                                retry = 0;
+                            } catch (final SolrException | IOException e) {
+                                ConcurrentLog.logException(e);
+                                if (retry++ < maxretries) {
+                                    // remote Solr may be temporary down, so we wait a bit
+                                    try {Thread.sleep(100);} catch (InterruptedException e1) {}
+                                    continue loop;
+                                }
+                                // fail
+                                ConcurrentLog.severe("AbstractSolrConnector", "aborted concurrentDocumentsByQueryNoPrefetch after " + maxretries + " retries: " + e.getMessage());
+                                break;
+                            }
                         }
-                        if (sdl.size() < ps) {
-                            //System.out.println("sdl.size() = " + sdl.size() + ", pagesize = " + pagesize);
-                            break loop; // finished
-                        }
-                        o += sdl.size();
-                        retry = 0;
-                    } catch (final SolrException | IOException e) {
-                        ConcurrentLog.logException(e);
-                        if (retry++ < maxretries) {
-                            // remote Solr may be temporary down, so we wait a bit
-                            try {Thread.sleep(100);} catch (InterruptedException e1) {}
-                            continue loop;
-                        }
-                        // fail
-                        ConcurrentLog.severe("AbstractSolrConnector", "aborted concurrentDocumentsByQuery after " + maxretries + " retries: " + e.getMessage());
-                        break;
                     }
-                }
-                for (int i = 0; i < Math.max(1, concurrency); i++) {
-                    try {queue.put(AbstractSolrConnector.POISON_DOCUMENT);} catch (final InterruptedException e1) {}
+                } catch (Throwable e) {} finally {
+                    for (int i = 0; i < Math.max(1, concurrency); i++) {
+                        try {queue.put(AbstractSolrConnector.POISON_DOCUMENT);} catch (final InterruptedException e1) {}
+                    }
                 }
             }
         };
         t.start();
         return queue;
     }
-
+    
+    /**
+     * get a document id result stream from a solr query.
+     * The result queue is considered as terminated if AbstractSolrConnector.POISON_ID is returned.
+     * The method returns immediately and feeds the search results into the queue
+     * @param querystring
+     * @param sort the solr sort string, may be null to be not used
+     * @param offset
+     * @param maxcount
+     * @param buffersize the size of an ArrayBlockingQueue; if <= 0 then a LinkedBlockingQueue is used
+     * @param concurrency is the number of AbstractSolrConnector.POISON_ID entries to add at the end of the feed
+     * @return a list of ids in q blocking queue which is terminated with a number of AbstractSolrConnector.POISON_ID
+     */
     @Override
     public BlockingQueue<String> concurrentIDsByQuery(
             final String querystring,
@@ -209,29 +321,63 @@ public abstract class AbstractSolrConnector implements SolrConnector {
             final long maxtime,
             final int buffersize,
             final int concurrency) {
+        List<String> querystrings = new ArrayList<>(1);
+        querystrings.add(querystring);
+        return concurrentIDsByQueries(querystrings, sort, offset, maxcount, maxtime, buffersize, concurrency);
+    }
+    
+    /**
+     * get a document id result stream from a set of solr queries.
+     * The result queue is considered as terminated if AbstractSolrConnector.POISON_ID is returned.
+     * The method returns immediately and feeds the search results into the queue
+     * @param querystring a list of query strings
+     * @param sort the solr sort string, may be null to be not used
+     * @param offset common offset of all queries
+     * @param maxcount maximum count for each query
+     * @param buffersize the size of an ArrayBlockingQueue; if <= 0 then a LinkedBlockingQueue is used
+     * @param concurrency is the number of AbstractSolrConnector.POISON_ID entries to add at the end of the feed
+     * @return a list of ids in q blocking queue which is terminated with a number of AbstractSolrConnector.POISON_ID
+     */
+    @Override
+    public BlockingQueue<String> concurrentIDsByQueries(
+            final List<String> querystrings,
+            final String sort,
+            final int offset,
+            final int maxcount,
+            final long maxtime,
+            final int buffersize,
+            final int concurrency) {
         final BlockingQueue<String> queue = buffersize <= 0 ? new LinkedBlockingQueue<String>() : new ArrayBlockingQueue<String>(buffersize);
-        final long endtime = maxtime == Long.MAX_VALUE ? Long.MAX_VALUE : System.currentTimeMillis() + maxtime; // we know infinity!
+        final long endtime = maxtime < 0 || maxtime == Long.MAX_VALUE ? Long.MAX_VALUE : System.currentTimeMillis() + maxtime; // we know infinity!
         final Thread t = new Thread() {
             @Override
             public void run() {
-                this.setName("AbstractSolrConnector:concurrentIDsByQuery(" + querystring + ")");
-                int o = offset;
-                while (System.currentTimeMillis() < endtime) {
-                    try {
-                        SolrDocumentList sdl = getDocumentListByQuery(querystring, sort, o, Math.min(maxcount, pagesize), CollectionSchema.id.getSolrFieldName());
-                        for (SolrDocument d: sdl) {
-                            try {queue.put((String) d.getFieldValue(CollectionSchema.id.getSolrFieldName()));} catch (final InterruptedException e) {break;}
+                try {
+                    for (String querystring: querystrings) {
+                        this.setName("AbstractSolrConnector:concurrentIDsByQueries(" + querystring + ")");
+                        int o = offset;
+                        while (System.currentTimeMillis() < endtime) {
+                            try {
+                                SolrDocumentList sdl = getDocumentListByQuery(querystring, sort, o, maxcount < 0 ? pagesize_ids : Math.min(maxcount, pagesize_ids), CollectionSchema.id.getSolrFieldName());
+                                int count = 0;
+                                for (SolrDocument d: sdl) {
+                                    try {queue.put((String) d.getFieldValue(CollectionSchema.id.getSolrFieldName()));} catch (final InterruptedException e) {break;}
+                                    count++;
+                                }
+                                if (count < pagesize_ids) break;
+                                o += count;
+                                if (o > maxcount && maxcount > 0) break;
+                            } catch (final SolrException e) {
+                                break;
+                            } catch (final IOException e) {
+                                break;
+                            }
                         }
-                        if (sdl.size() < pagesize) break;
-                        o += sdl.size();
-                    } catch (final SolrException e) {
-                        break;
-                    } catch (final IOException e) {
-                        break;
                     }
-                }
-                for (int i = 0; i < concurrency; i++) {
-                    try {queue.put(AbstractSolrConnector.POISON_ID);} catch (final InterruptedException e1) {}
+                } catch (Throwable e) {} finally {
+                    for (int i = 0; i < concurrency; i++) {
+                        try {queue.put(AbstractSolrConnector.POISON_ID);} catch (final InterruptedException e1) {}
+                    }
                 }
             }
         };
@@ -241,7 +387,7 @@ public abstract class AbstractSolrConnector implements SolrConnector {
 
     @Override
     public Iterator<String> iterator() {
-        final BlockingQueue<String> queue = concurrentIDsByQuery(CATCHALL_QUERY, null, 0, Integer.MAX_VALUE, 60000, 2 * pagesize, 1);
+        final BlockingQueue<String> queue = concurrentIDsByQuery(CATCHALL_QUERY, null, 0, Integer.MAX_VALUE, 60000, 2 * pagesize_ids, 1);
         return new LookAheadIterator<String>() {
             @Override
             protected String next0() {
@@ -299,7 +445,7 @@ public abstract class AbstractSolrConnector implements SolrConnector {
         params.setRows(count);
         params.setStart(offset);
         params.setFacet(false);
-        if (fields.length > 0) params.setFields(fields);
+        if (fields != null && fields.length > 0) params.setFields(fields);
         params.setIncludeScore(false);
         params.setParam("defType", "edismax");
         params.setParam(DisMaxParams.QF, CollectionSchema.text_t.getSolrFieldName() + "^1.0");
@@ -317,7 +463,7 @@ public abstract class AbstractSolrConnector implements SolrConnector {
         // construct raw query
         final SolrQuery params = new SolrQuery();
         //params.setQuery(CollectionSchema.id.getSolrFieldName() + ":\"" + id + "\"");
-        String q = "{!raw f=" + CollectionSchema.id.getSolrFieldName() + "}" + id;
+        String q = "{!cache=false raw f=" + CollectionSchema.id.getSolrFieldName() + "}" + id;
         params.setQuery(q);
         params.setRows(1);
         params.setStart(0);
@@ -366,7 +512,7 @@ public abstract class AbstractSolrConnector implements SolrConnector {
      * @throws IOException
      */
     @Override
-    public Map<String, ReversibleScoreMap<String>> getFacets(String query, int maxresults, final String ... fields) throws IOException {
+    public LinkedHashMap<String, ReversibleScoreMap<String>> getFacets(String query, int maxresults, final String ... fields) throws IOException {
         // construct query
         assert fields.length > 0;
         final SolrQuery params = new SolrQuery();
@@ -377,7 +523,7 @@ public abstract class AbstractSolrConnector implements SolrConnector {
         params.setFacetMinCount(1); // there are many 0-count facets in the uninverted index cache
         params.setFacetLimit(maxresults);
         params.setFacetSort(FacetParams.FACET_SORT_COUNT);
-        params.setParam(FacetParams.FACET_METHOD, FacetParams.FACET_METHOD_fcs);
+        params.setParam(FacetParams.FACET_METHOD, FacetParams.FACET_METHOD_fc /*FACET_METHOD_fcs*/);
         params.setFields(fields);
         params.clearSorts();
         params.setIncludeScore(false);
@@ -385,7 +531,7 @@ public abstract class AbstractSolrConnector implements SolrConnector {
         
         // query the server
         QueryResponse rsp = getResponseByParams(params);
-        Map<String, ReversibleScoreMap<String>> facets = new HashMap<String, ReversibleScoreMap<String>>(fields.length);
+        LinkedHashMap<String, ReversibleScoreMap<String>> facets = new LinkedHashMap<String, ReversibleScoreMap<String>>(fields.length);
         for (String field: fields) {
             FacetField facet = rsp.getFacetField(field);
             ReversibleScoreMap<String> result = new ClusteredScoreMap<String>(UTF8.insensitiveUTF8Comparator);
@@ -403,25 +549,70 @@ public abstract class AbstractSolrConnector implements SolrConnector {
         final SolrQuery query = new SolrQuery();
         // construct query
         StringBuilder sb = new StringBuilder(23);
-        sb.append("{!raw f=").append(CollectionSchema.id.getSolrFieldName()).append('}').append(id);
+        sb.append("{!cache=false raw f=").append(CollectionSchema.id.getSolrFieldName()).append('}').append(id);
         query.setQuery(sb.toString());
         //query.setQuery("*:*");
         //query.addFilterQuery(sb.toString());
         query.clearSorts();
         query.setRows(1);
         query.setStart(0);
-        if (fields.length > 0) query.setFields(fields);
+        if (fields != null && fields.length > 0) query.setFields(fields);
         query.setIncludeScore(false);
 
         // query the server
         try {
             final SolrDocumentList docs = getDocumentListByParams(query);
             if (docs == null || docs.isEmpty()) return null;
-            return docs.get(0);
+            SolrDocument doc = docs.get(0);
+            return doc;
         } catch (final Throwable e) {
             clearCaches(); // we clear the in case that this is caused by OOM
             throw new IOException(e.getMessage(), e);
         }
     }
+    
+    /**
+     * Update a solr document.
+     * This will write only a partial update for all fields given in the SolrInputDocument
+     * and leaves all other fields untouched.
+     * @param solrdoc
+     * @throws IOException
+     * @throws SolrException
+     */
+    @Override
+    public void update(final SolrInputDocument solrdoc) throws IOException, SolrException {
+        this.add(partialUpdatePatch(solrdoc));
+    }
+
+    /**
+     * Update a collection of solr input documents.
+     * This will write only a partial update for all fields given in the SolrInputDocuments
+     * and leaves all other fields untouched.
+     * @param solrdocs
+     * @throws IOException
+     * @throws SolrException
+     */
+    @Override
+    public void update(final Collection<SolrInputDocument> solrdoc) throws IOException, SolrException {
+        Collection<SolrInputDocument> docs = new ArrayList<>(solrdoc.size());
+        for (SolrInputDocument doc: solrdoc) docs.add(partialUpdatePatch(doc));
+        this.add(docs);
+    }
+    
+    private SolrInputDocument partialUpdatePatch(final SolrInputDocument docIn) {
+        SolrInputDocument docOut = new SolrInputDocument();
+        docOut.setField(CollectionSchema.id.name(), docIn.getFieldValue(CollectionSchema.id.name()));
+        for (Entry<String, SolrInputField> entry: docIn.entrySet()) {
+            if (entry.getKey().equals(CollectionSchema.id.name())) continue;
+            SolrInputField sif = entry.getValue();
+            Map<String, Object> partialUpdate = new HashMap<>(1);
+            Object value = sif.getValue();
+            docOut.removeField(entry.getKey());
+            partialUpdate.put("set", value);
+            docOut.setField(entry.getKey(), partialUpdate);
+        }
+        return docOut;
+    }
+    
 
 }
