@@ -25,9 +25,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Map;
 import java.util.Set;
-import java.util.concurrent.ArrayBlockingQueue;
-import java.util.concurrent.BlockingQueue;
-import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ConcurrentHashMap;
 
 import net.yacy.cora.federate.solr.instance.EmbeddedInstance;
 import net.yacy.cora.federate.solr.instance.SolrInstance;
@@ -261,11 +259,26 @@ public class EmbeddedSolrConnector extends SolrServerConnector implements SolrCo
         return sdl;
     }
     
+    /**
+     * The following schemaFieldCache is a hack-patch of a Solr internal request which is really slow.
+     * The Solr-internal method is flexible because it may respond on a real-time schema change, but that
+     * effectively never happens. In our case the schema declaration against Solr never changes.
+     */
+    private final Map<String, SchemaField> schemaFieldCache = new ConcurrentHashMap<>();
+    private final SchemaField getSchemaField(final String fieldName) {
+        SchemaField sf = schemaFieldCache.get(fieldName);
+        if (sf == null) {
+            sf = this.core.getLatestSchema().getFieldOrNull(fieldName);
+            schemaFieldCache.put(fieldName, sf);
+        }
+        return sf;
+    }
+    
     public SolrDocument doc2SolrDoc(Document doc) {
         SolrDocument solrDoc = new SolrDocument();
         for (IndexableField field : doc) {
             String fieldName = field.name();
-            SchemaField sf = this.core.getLatestSchema().getFieldOrNull(fieldName);
+            SchemaField sf = getSchemaField(fieldName); // hack-patch of this.core.getLatestSchema().getFieldOrNull(fieldName); makes it a lot faster!!
             Object val = null;
             try {
                 FieldType ft = null;
@@ -408,7 +421,7 @@ public class EmbeddedSolrConnector extends SolrServerConnector implements SolrCo
         int responseCount = 0;
         DocListSearcher docListSearcher = null;
         try {
-            docListSearcher = new DocListSearcher("{!raw f=" + CollectionSchema.id.getSolrFieldName() + "}" + id, null, 0, 1, CollectionSchema.id.getSolrFieldName(), CollectionSchema.load_date_dt.getSolrFieldName());
+            docListSearcher = new DocListSearcher("{!cache=false raw f=" + CollectionSchema.id.getSolrFieldName() + "}" + id, null, 0, 1, CollectionSchema.id.getSolrFieldName(), CollectionSchema.load_date_dt.getSolrFieldName());
             responseCount = docListSearcher.response.size();
             if (responseCount == 0) return null;
             SolrIndexSearcher searcher = docListSearcher.request.getSearcher();
@@ -425,7 +438,7 @@ public class EmbeddedSolrConnector extends SolrServerConnector implements SolrCo
             if (docListSearcher != null) docListSearcher.close();
         }
     }
-    
+    /*
     @Override
     public BlockingQueue<String> concurrentIDsByQuery(final String querystring, final String sort, final int offset, final int maxcount, final long maxtime, final int buffersize, final int concurrency) {
         final BlockingQueue<String> queue = buffersize <= 0 ? new LinkedBlockingQueue<String>() : new ArrayBlockingQueue<String>(buffersize);
@@ -439,7 +452,7 @@ public class EmbeddedSolrConnector extends SolrServerConnector implements SolrCo
                 while (System.currentTimeMillis() < endtime) {
                     try {
                     	responseCount = 0;
-                        docListSearcher = new DocListSearcher(querystring, sort, o, pagesize, CollectionSchema.id.getSolrFieldName());
+                        docListSearcher = new DocListSearcher(querystring, sort, o, pagesize_ids, CollectionSchema.id.getSolrFieldName());
                         responseCount = docListSearcher.response.size();
                         SolrIndexSearcher searcher = docListSearcher.request.getSearcher();
                         DocIterator iterator = docListSearcher.response.iterator();
@@ -453,8 +466,8 @@ public class EmbeddedSolrConnector extends SolrServerConnector implements SolrCo
                     } finally {
                         if (docListSearcher != null) docListSearcher.close();
                     }
-                    if (responseCount < pagesize) break;
-                    o += pagesize;
+                    if (responseCount < pagesize_ids) break;
+                    o += pagesize_ids;
                 }
                 try {queue.put(AbstractSolrConnector.POISON_ID);} catch (final InterruptedException e1) {}
             }
@@ -462,4 +475,5 @@ public class EmbeddedSolrConnector extends SolrServerConnector implements SolrCo
         t.start();
         return queue;
     }
+    */
 }
