@@ -22,8 +22,10 @@ package net.yacy.cora.lod.vocabulary;
 
 import java.io.BufferedWriter;
 import java.io.File;
+import java.io.FileOutputStream;
 import java.io.FileWriter;
 import java.io.IOException;
+import java.io.OutputStreamWriter;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.Map;
@@ -34,6 +36,7 @@ import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.regex.Pattern;
 
+import net.yacy.cora.document.encoding.UTF8;
 import net.yacy.cora.geo.GeoLocation;
 import net.yacy.cora.geo.Locations;
 import net.yacy.cora.storage.Files;
@@ -50,6 +53,7 @@ public class Tagging {
     private final Map<String, String> term2objectlink;
     private final Map<String, Set<String>> synonym2synonyms;
     private File propFile;
+    private boolean isFacet; // true if the vocabulary shall generate a navigation facet
 
     private String predicate, namespace, objectspace;
 
@@ -96,6 +100,7 @@ public class Tagging {
         this.predicate = this.namespace + name;
         this.objectspace = null;
         this.propFile = null;
+        this.isFacet = true;
     }
 
     public Tagging(String name, File propFile) throws IOException {
@@ -158,7 +163,8 @@ public class Tagging {
 			    }
 			}
         } else {
-	        BufferedWriter w = new BufferedWriter(new FileWriter(propFile));
+            //
+            BufferedWriter w = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(propFile), UTF8.charset.name()));
 	        if (objectspace != null && objectspace.length() > 0) w.write("#objectspace:" + objectspace + "\n");
 	        for (Map.Entry<String, SOTuple> e: table.entrySet()) {
 	            String s = e.getValue() == null ? "" : e.getValue().getSynonymsCSV();
@@ -202,7 +208,9 @@ public class Tagging {
         String[] tags;
         int p;
         String line;
+        Pattern kommapattern = Pattern.compile(",");
         try {
+            String[] pl;
             vocloop: while ((line = list.take()) != Files.POISON_LINE) {
                 line = line.trim();
                 p = line.indexOf('#');
@@ -220,10 +228,8 @@ public class Tagging {
                         continue vocloop;
                     }
                 }
-                String[] pl = parseLine(line);
-                if (pl == null) {
-                    continue vocloop;
-                }
+                pl = parseLine(line);
+                if (pl == null) continue vocloop;
                 if (pl[1] == null) {
                     term = normalizeKey(pl[0]);
                     v = normalizeTerm(pl[0]);
@@ -234,7 +240,7 @@ public class Tagging {
                 }
                 term = normalizeKey(pl[0]);
                 v = pl[1];
-                tags = v.split(",");
+                tags = kommapattern.split(v);
                 Set<String> synonyms = new HashSet<String>();
                 synonyms.add(term);
                 tagloop: for (String synonym: tags) {
@@ -259,6 +265,14 @@ public class Tagging {
         }
     }
 
+    public boolean isFacet() {
+        return this.isFacet;
+    }
+    
+    public void setFacet(boolean isFacet) {
+        this.isFacet = isFacet;
+    }
+    
     public int size() {
         return this.term2objectlink.size();
     }
@@ -342,7 +356,7 @@ public class Tagging {
 
     public void setObjectspace(String os) throws IOException {
         if (this.propFile == null) return;
-        if (os == null || (this.objectspace != null && this.objectspace.equals(os))) return;
+        if (os == null || os.length() == 0 || (this.objectspace != null && this.objectspace.equals(os))) return;
         this.objectspace = os;
         File tmp = tmpFile();
         BufferedWriter w = new BufferedWriter(new FileWriter(tmp));
@@ -466,14 +480,21 @@ public class Tagging {
     public String getObjectspace() {
         return this.objectspace;
     }
-
+    
+    private final static Pattern PATTERN_SPACEPLUS = Pattern.compile(" \\+");
+    private final static Pattern PATTERN_SPACESLASH= Pattern.compile(" /");
+    private final static Pattern PATTERN_PLUS = Pattern.compile("\\+");
+    private final static Pattern PATTERN_SLASH = Pattern.compile("/");
+    private final static Pattern PATTERN_SPACESPACE = Pattern.compile("  ");
+    
     private final String normalizeKey(String k) {
         k = k.trim();
-        k = k.replaceAll(" \\+", ", "); // remove symbols that are bad in a query attribute
-        k = k.replaceAll(" /", ", ");
-        k = k.replaceAll("\\+", ",");
-        k = k.replaceAll("/", ",");
-        k = k.replaceAll("  ", " ");
+        // remove symbols that are bad in a query attribute
+        k = PATTERN_SPACEPLUS.matcher(k).replaceAll(", ");
+        k = PATTERN_SPACESLASH.matcher(k).replaceAll(", ");
+        k = PATTERN_PLUS.matcher(k).replaceAll(",");
+        k = PATTERN_SLASH.matcher(k).replaceAll(",");
+        k = PATTERN_SPACESPACE.matcher(k).replaceAll(" ");
         return k;
     }
 
@@ -523,6 +544,7 @@ public class Tagging {
     private final static Pattern PATTERN_OE = Pattern.compile("\u00F6");
     private final static Pattern PATTERN_UE = Pattern.compile("\u00FC");
     private final static Pattern PATTERN_SZ = Pattern.compile("\u00DF");
+    private final static Pattern PATTERN_COMMA = Pattern.compile(",");
 
     public static final String normalizeTerm(String term) {
         term = term.trim().toLowerCase();
@@ -530,11 +552,7 @@ public class Tagging {
         term = PATTERN_OE.matcher(term).replaceAll("oe");
         term = PATTERN_UE.matcher(term).replaceAll("ue");
         term = PATTERN_SZ.matcher(term).replaceAll("ss");
-        // remove comma
-        int p;
-        while ((p = term.indexOf(',')) >= 0) {
-            term = term.substring(p + 1).trim() + " " + term.substring(0, p);
-        }
+        term = PATTERN_COMMA.matcher(term).replaceAll(" ");
         return term;
     }
 
