@@ -36,7 +36,6 @@ import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import net.yacy.contentcontrol.ContentControlFilterUpdateThread;
-import net.yacy.cora.document.analysis.Classification.ContentDomain;
 import net.yacy.cora.document.encoding.ASCII;
 import net.yacy.cora.document.encoding.UTF8;
 import net.yacy.cora.document.id.AnchorURL;
@@ -210,8 +209,6 @@ public final class CrawlStacker {
                         url.getNameProperty(),
                         new Date(),
                         profileHandle,
-                        0,
-                        0,
                         0
                         ));
             }
@@ -251,8 +248,6 @@ public final class CrawlStacker {
                                 MultiProtocolURL.unescape(entry.name),
                                 entry.date,
                                 profileHandle,
-                                0,
-                                0,
                                 0));
                     }
                 } catch (final IOException e1) {
@@ -277,8 +272,6 @@ public final class CrawlStacker {
                 "CRAWLING-ROOT",
                 new Date(),
                 pe.handle(),
-                0,
-                0,
                 0));
     }
 
@@ -325,12 +318,8 @@ public final class CrawlStacker {
 
         // check availability of parser and maxfilesize
         String warning = null;
-        ContentDomain contentDomain = entry.url().getContentDomainFromExt();
-        if (contentDomain == ContentDomain.APP  ||
-            (contentDomain == ContentDomain.IMAGE && TextParser.supportsExtension(entry.url()) != null) ||
-            contentDomain == ContentDomain.AUDIO  ||
-            contentDomain == ContentDomain.VIDEO ||
-            contentDomain == ContentDomain.CTRL) {
+        //ContentDomain contentDomain = entry.url().getContentDomainFromExt();
+        if (TextParser.supportsExtension(entry.url()) != null) {
             warning = this.nextQueue.noticeURL.push(NoticedURL.StackType.NOLOAD, entry, profile, this.robots);
             //if (warning != null && this.log.isFine()) this.log.logFine("CrawlStacker.stackCrawl of URL " + entry.url().toNormalform(true, false) + " - not pushed: " + warning);
             return null;
@@ -380,19 +369,6 @@ public final class CrawlStacker {
             ConcurrentLog.logException(e);
             return "exception during double-test: " + e.getMessage();
         }
-        final Long oldDate = oldEntry == null ? null : oldEntry.date;
-        if (oldDate == null) {
-            return null; // no evidence that we know that url
-        }
-        final boolean recrawl = profile.recrawlIfOlder() > oldDate.longValue();
-        final String urlstring = url.toNormalform(false);
-        if (recrawl) {
-            if (CrawlStacker.log.isFine())
-                CrawlStacker.log.fine("RE-CRAWL of URL '" + urlstring + "': this url was crawled " +
-                    ((System.currentTimeMillis() - oldDate.longValue()) / 60000 / 60 / 24) + " days ago.");
-        } else {
-            return "double in: LURL-DB, oldDate = " + oldDate.toString();
-        }
 
         // deny urls that exceed allowed number of occurrences
         final int maxAllowedPagesPerDomain = profile.domMaxPages();
@@ -410,6 +386,20 @@ public final class CrawlStacker {
             }
             */
         }
+        
+        final Long oldDate = oldEntry == null ? null : oldEntry.date;
+        if (oldDate == null) {
+            return null; // no evidence that we know that url
+        }
+        final boolean recrawl = profile.recrawlIfOlder() > oldDate.longValue();
+        final String urlstring = url.toNormalform(false);
+        if (recrawl) {
+            if (CrawlStacker.log.isFine())
+                CrawlStacker.log.fine("RE-CRAWL of URL '" + urlstring + "': this url was crawled " +
+                    ((System.currentTimeMillis() - oldDate.longValue()) / 60000 / 60 / 24) + " days ago.");
+        } else {
+            return "double in: LURL-DB, oldDate = " + oldDate.toString();
+        }
 
         return null;
     }
@@ -546,7 +536,7 @@ public final class CrawlStacker {
         if (this.acceptLocalURLs && local) return null;
         if (this.acceptGlobalURLs && !local) return null;
         final String host = url.getHost();
-        if (host == null) return "url.host is null";
+        if (host == null) return "url.host is null (you must switch to intranet mode to crawl these sources)";
         // check if this is a local address and we are allowed to index local pages:
         //boolean local = hostAddress.isSiteLocalAddress() || hostAddress.isLoopbackAddress();
         //assert local == yacyURL.isLocalDomain(url.hash()); // TODO: remove the dnsResolve above!
