@@ -67,7 +67,6 @@ public final class CrawlSwitchboard {
     public static final String CRAWL_PROFILE_SNIPPET_LOCAL_MEDIA = "snippetLocalMedia";
     public static final String CRAWL_PROFILE_SNIPPET_GLOBAL_MEDIA = "snippetGlobalMedia";
     public static final String CRAWL_PROFILE_SURROGATE = "surrogates";
-    public static final String CRAWL_PROFILE_PUSH_STUB = "push_";
 
     public static Set<String> DEFAULT_PROFILES = new HashSet<String>();
     static {
@@ -293,6 +292,7 @@ public final class CrawlSwitchboard {
                 sb.getConfigBool(SwitchboardConstants.PROXY_INDEXING_LOCAL_MEDIA, true),
                 true,
                 sb.getConfigBool(SwitchboardConstants.PROXY_INDEXING_REMOTE, false),
+                -1, false, true,
                 CacheStrategy.IFFRESH,
                 "robot_" + CRAWL_PROFILE_PROXY,
                 ClientIdentification.yacyProxyAgentName);
@@ -322,6 +322,7 @@ public final class CrawlSwitchboard {
                 true,
                 false,
                 false,
+                -1, false, true,
                 CacheStrategy.IFFRESH,
                 "robot_" + CRAWL_PROFILE_REMOTE,
                 ClientIdentification.yacyInternetCrawlerAgentName);
@@ -351,6 +352,7 @@ public final class CrawlSwitchboard {
                 false,
                 true,
                 false,
+                -1, false, true,
                 CacheStrategy.IFEXIST,
                 "robot_" + CRAWL_PROFILE_SNIPPET_LOCAL_TEXT,
                 ClientIdentification.yacyIntranetCrawlerAgentName);
@@ -380,6 +382,7 @@ public final class CrawlSwitchboard {
                 true,
                 true,
                 false,
+                -1, false, true,
                 CacheStrategy.IFEXIST,
                 "robot_" + CRAWL_PROFILE_SNIPPET_GLOBAL_TEXT,
                 ClientIdentification.yacyIntranetCrawlerAgentName);
@@ -410,6 +413,7 @@ public final class CrawlSwitchboard {
                 false,
                 true,
                 false,
+                -1, false, true,
                 CacheStrategy.IFEXIST,
                 "robot_" + CRAWL_PROFILE_GREEDY_LEARNING_TEXT,
                 ClientIdentification.browserAgentName);
@@ -439,6 +443,7 @@ public final class CrawlSwitchboard {
                 false,
                 true,
                 false,
+                -1, false, true,
                 CacheStrategy.IFEXIST,
                 "robot_" + CRAWL_PROFILE_SNIPPET_LOCAL_MEDIA,
                 ClientIdentification.yacyIntranetCrawlerAgentName);
@@ -468,6 +473,7 @@ public final class CrawlSwitchboard {
                 true,
                 true,
                 false,
+                -1, false, true,
                 CacheStrategy.IFEXIST,
                 "robot_" + CRAWL_PROFILE_SNIPPET_GLOBAL_MEDIA,
                 ClientIdentification.yacyIntranetCrawlerAgentName);
@@ -497,6 +503,7 @@ public final class CrawlSwitchboard {
                 false,
                 false,
                 false,
+                -1, false, true,
                 CacheStrategy.NOCACHE,
                 "robot_" + CRAWL_PROFILE_SURROGATE,
                 ClientIdentification.yacyIntranetCrawlerAgentName);
@@ -509,7 +516,7 @@ public final class CrawlSwitchboard {
         CrawlProfile genericPushProfile = this.defaultPushProfiles.get(collection);
         if (genericPushProfile != null) return genericPushProfile;
         genericPushProfile = new CrawlProfile(
-                CRAWL_PROFILE_PUSH_STUB + collection,
+                CrawlProfile.CRAWL_PROFILE_PUSH_STUB + collection,
                 CrawlProfile.MATCH_ALL_STRING,   //crawlerUrlMustMatch
                 CrawlProfile.MATCH_NEVER_STRING, //crawlerUrlMustNotMatch
                 CrawlProfile.MATCH_ALL_STRING,   //crawlerIpMustMatch
@@ -529,6 +536,7 @@ public final class CrawlSwitchboard {
                 true,
                 false,
                 false,
+                -1, false, true,
                 CacheStrategy.NOCACHE,
                 collection,
                 ClientIdentification.yacyIntranetCrawlerAgentName);
@@ -536,7 +544,7 @@ public final class CrawlSwitchboard {
         this.defaultPushProfiles.put(collection, genericPushProfile);
         return genericPushProfile;
     }
-
+    
     private void resetProfiles() {
         this.profilesActiveCrawlsCache.clear();
         final File pdb = new File(this.queuesRoot, DBFILE_ACTIVE_CRAWL_PROFILES);
@@ -676,12 +684,10 @@ public final class CrawlSwitchboard {
         try {
             ret = new MapHeap(file, Word.commonHashLength, NaturalOrder.naturalOrder, 1024 * 64, 500, ' ');
         } catch (final IOException e ) {
-            ConcurrentLog.logException(e);
             ConcurrentLog.logException(e);
             FileUtils.deletedelete(file);
             try {
-                ret =
-                    new MapHeap(file, Word.commonHashLength, NaturalOrder.naturalOrder, 1024 * 64, 500, ' ');
+                ret = new MapHeap(file, Word.commonHashLength, NaturalOrder.naturalOrder, 1024 * 64, 500, ' ');
             } catch (final IOException e1 ) {
                 ConcurrentLog.logException(e1);
                 ret = null;
