@@ -49,6 +49,7 @@ import net.yacy.crawler.robots.RobotsTxt;
 import net.yacy.kelondro.data.word.Word;
 import net.yacy.kelondro.index.RowHandleMap;
 import net.yacy.kelondro.index.RowHandleSet;
+import net.yacy.kelondro.util.FileUtils;
 
 /**
  * wrapper for single HostQueue queues; this is a collection of such queues.
@@ -85,9 +86,9 @@ public class HostBalancer implements Balancer {
         for (String address: list) try {
             File queuePath = new File(this.hostsPath, address);
             HostQueue queue = new HostQueue(queuePath, this.queues.size() > this.onDemandLimit, this.exceed134217727);
-            if (queue.size() == 0) {
+            if (queue.isEmpty()) {
                 queue.close();
-                queuePath.delete();
+                FileUtils.deletedelete(queuePath);
             } else {
                 this.queues.put(DigestURL.hosthash(queue.getHost(), queue.getPort()), queue);
             }
@@ -126,7 +127,9 @@ public class HostBalancer implements Balancer {
     @Override
     public int removeAllByProfileHandle(final String profileHandle, final long timeout) throws IOException, SpaceExceededException {
         int c = 0;
-        for (HostQueue queue: this.queues.values()) c += queue.removeAllByProfileHandle(profileHandle, timeout);
+        for (HostQueue queue: this.queues.values()) {
+            c += queue.removeAllByProfileHandle(profileHandle, timeout);
+        }
         return c;
     }
     
@@ -186,13 +189,17 @@ public class HostBalancer implements Balancer {
     @Override
     public int size() {
         int c = 0;
-        for (HostQueue queue: this.queues.values()) c += queue.size();
+        for (HostQueue queue: this.queues.values()) {
+            c += queue.size();
+        }
         return c;
     }
 
     @Override
     public boolean isEmpty() {
-        for (HostQueue queue: this.queues.values()) if (!queue.isEmpty()) return false;
+        for (HostQueue queue: this.queues.values()) {
+            if (!queue.isEmpty()) return false;
+        }
         return true;
     }
     
@@ -400,8 +407,7 @@ public class HostBalancer implements Balancer {
                 }
             }
             
-            int size = rhq.size();
-            if (size == 0) {
+            if (rhq.isEmpty()) {
                 synchronized (this) {
                     this.queues.remove(rhh);
                 }
