@@ -131,7 +131,7 @@ public class HostQueue implements Balancer {
             if (s.endsWith(indexSuffix)) try {
                 int depth = Integer.parseInt(s.substring(0, s.length() - indexSuffix.length()));
                 File stackFile = new File(this.hostPath, s);
-                Index depthStack = openStack(stackFile, depth);
+                Index depthStack = openStack(stackFile);
                 if (depthStack != null) {
                     int sz = depthStack.size();
                     if (sz == 0) {
@@ -200,7 +200,7 @@ public class HostQueue implements Balancer {
             if (depthStack != null) return depthStack;
             // now actually create a new stack
             final File f = getFile(depth);
-            depthStack = openStack(f, depth);
+            depthStack = openStack(f);
             if (depthStack != null) this.depthStacks.put(depth, depthStack);
         }
         return depthStack;
@@ -213,10 +213,10 @@ public class HostQueue implements Balancer {
         return f;
     }
     
-    private Index openStack(File f, int depth) {
+    private Index openStack(File f) {
         for (int i = 0; i < 10; i++) {
             // we try that again if it fails because it shall not fail
-            if (this.onDemand && depth > 3 && (!f.exists() || f.length() < 10000)) {
+            if (this.onDemand && (!f.exists() || f.length() < 10000)) {
                 try {
                     return new BufferedObjectIndex(new OnDemandOpenFileIndex(f, Request.rowdef, exceed134217727), objectIndexBufferSize);
                 } catch (kelondroException e) {
@@ -379,8 +379,12 @@ public class HostQueue implements Balancer {
             if (this.has(hash)) return "double occurrence in urlFileIndex";
 
             // increase dom counter
-            if (profile != null && profile.domMaxPages() != Integer.MAX_VALUE && profile.domMaxPages() > 0) {
-                profile.domInc(entry.url().getHost());
+            if (profile != null) {
+                int maxPages = profile.domMaxPages();
+                if (maxPages != Integer.MAX_VALUE && maxPages > 0) {
+                    String host = entry.url().getHost();
+                    profile.domInc(host);
+                }
             }
             
             // add to index
