@@ -25,7 +25,6 @@
 
 package net.yacy.crawler.data;
 
-import java.text.DateFormat;
 import java.util.Collection;
 import java.util.Date;
 import java.util.HashMap;
@@ -59,6 +58,8 @@ public class CrawlProfile extends ConcurrentHashMap<String, String> implements M
     public static final Pattern MATCH_ALL_PATTERN   = Pattern.compile(MATCH_ALL_STRING);
     public static final Pattern MATCH_NEVER_PATTERN = Pattern.compile(MATCH_NEVER_STRING);
 
+    public static final String CRAWL_PROFILE_PUSH_STUB = "push_";
+    
     // this is a simple record structure that hold all properties of a single crawl start
     private static final String HANDLE          = "handle";
     public static final String AGENT_NAME       = "agentName";
@@ -87,7 +88,10 @@ public class CrawlProfile extends ConcurrentHashMap<String, String> implements M
     public static final String INDEXING_URL_MUSTNOTMATCH     = "indexURLMustNotMatch";
     public static final String INDEXING_CONTENT_MUSTMATCH    = "indexContentMustMatch";
     public static final String INDEXING_CONTENT_MUSTNOTMATCH = "indexContentMustNotMatch";
-
+    public static final String SNAPSHOTS_MAXDEPTH            = "snapshotsMaxDepth"; // if previews shall be loaded, this is positive and denotes the maximum depth; if not this is -1
+    public static final String SNAPSHOTS_REPLACEOLD          = "snapshotsReplaceOld"; // if this is set to true, only one version of a snapshot per day is stored, otherwise we store also different versions per day
+    public static final String SNAPSHOTS_LOADIMAGE           = "snapshotsLoadImage"; // if true, an image is loaded
+    
     private Pattern crawlerurlmustmatch = null, crawlerurlmustnotmatch = null;
     private Pattern crawleripmustmatch = null, crawleripmustnotmatch = null;
     private Pattern crawlernodepthlimitmatch = null;
@@ -142,6 +146,9 @@ public class CrawlProfile extends ConcurrentHashMap<String, String> implements M
                  final boolean indexMedia,
                  final boolean storeHTCache,
                  final boolean remoteIndexing,
+                 final int snapshotsMaxDepth,
+                 final boolean snapshotsLoadImage,
+                 final boolean snapshotsReplaceOld,
                  final CacheStrategy cacheStrategy,
                  final String collections,
                  final String userAgentName) {
@@ -177,6 +184,9 @@ public class CrawlProfile extends ConcurrentHashMap<String, String> implements M
         put(INDEX_MEDIA,      indexMedia);
         put(STORE_HTCACHE,    storeHTCache);
         put(REMOTE_INDEXING,  remoteIndexing);
+        put(SNAPSHOTS_MAXDEPTH, snapshotsMaxDepth);
+        put(SNAPSHOTS_LOADIMAGE, snapshotsLoadImage);
+        put(SNAPSHOTS_REPLACEOLD, snapshotsReplaceOld);
         put(CACHE_STRAGEGY,   cacheStrategy.toString());
         put(COLLECTIONS,      CommonPattern.SPACE.matcher(collections.trim()).replaceAll(""));
     }
@@ -566,11 +576,37 @@ public class CrawlProfile extends ConcurrentHashMap<String, String> implements M
         if (r == null) return false;
         return (r.equals(Boolean.TRUE.toString()));
     }
+    
     public boolean remoteIndexing() {
         final String r = get(REMOTE_INDEXING);
         if (r == null) return false;
         return (r.equals(Boolean.TRUE.toString()));
     }
+    
+    public int snapshotMaxdepth() {
+        final String r = get(SNAPSHOTS_MAXDEPTH);
+        if (r == null) return -1;
+        try {
+            final int i = Integer.parseInt(r);
+            if (i < 0) return -1;
+            return i;
+        } catch (final NumberFormatException e) {
+            ConcurrentLog.logException(e);
+            return -1;
+        }
+    }
+    
+    public boolean snapshotLoadImage() {
+        final String r = get(SNAPSHOTS_LOADIMAGE);
+        if (r == null) return false;
+        return (r.equals(Boolean.TRUE.toString()));
+    }
+
+    public boolean snapshotReplaceold() {
+        final String r = get(SNAPSHOTS_REPLACEOLD);
+        if (r == null) return false;
+        return (r.equals(Boolean.TRUE.toString()));
+    }
 
     /**
      * get a recrawl date for a given age in minutes
@@ -614,6 +650,10 @@ public class CrawlProfile extends ConcurrentHashMap<String, String> implements M
         if ("http".equals(protocol) || "https".equals(protocol)) protocol = "https?+";
         return new StringBuilder(host.length() + 20).append(protocol).append("://(www.)?").append(Pattern.quote(host)).append(url.getPath()).append(".*").toString();
     }
+    
+    public boolean isPushCrawlProfile() {
+        return this.name().startsWith(CrawlProfile.CRAWL_PROFILE_PUSH_STUB);
+    }
 
     public void putProfileEntry(
     		final String CRAWL_PROFILE_PREFIX,
@@ -622,40 +662,61 @@ public class CrawlProfile extends ConcurrentHashMap<String, String> implements M
             final boolean dark,
             final int count,
             final int domlistlength) {
-
+        boolean terminateButton = active && !CrawlSwitchboard.DEFAULT_PROFILES.contains(this.name());
+        boolean deleteButton = !active;
         prop.put(CRAWL_PROFILE_PREFIX + count + "_dark", dark ? "1" : "0");
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_name", this.collectionName());
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_terminateButton", (!active || CrawlSwitchboard.DEFAULT_PROFILES.contains(this.name())) ? "0" : "1");
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_terminateButton_handle", this.handle());
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_deleteButton", (active) ? "0" : "1");
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_deleteButton_handle", this.handle());
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_handle", this.handle());
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_handle", this.handle());
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_name", this.name());
+        //prop.putXML(CRAWL_PROFILE_PREFIX + count + "_collection", this.get(COLLECTIONS)); // TODO: remove, replace with 'collections'
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_collections", this.get(COLLECTIONS));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_agentName", this.get(AGENT_NAME));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_userAgent", this.getAgent().userAgent);
         prop.put(CRAWL_PROFILE_PREFIX + count + "_depth", this.depth());
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_mustmatch", this.urlMustMatchPattern().toString());
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_mustnotmatch", this.urlMustNotMatchPattern().toString());
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_crawlingIfOlder", (this.recrawlIfOlder() == 0L) ? "no re-crawl" : DateFormat.getDateTimeInstance().format(this.recrawlIfOlder()));
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_directDocByURL", this.directDocByURL() ? 1 : 0);
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_recrawlIfOlder", this.recrawlIfOlder() == Long.MAX_VALUE ? "eternity" : (new Date(this.recrawlIfOlder()).toString()));
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_domMaxPages", this.domMaxPages());
+        //prop.put(CRAWL_PROFILE_PREFIX + count + "_crawlingDomMaxPages", (this.domMaxPages() == Integer.MAX_VALUE) ? "unlimited" : Integer.toString(this.domMaxPages())); // TODO: remove, replace with 'domMaxPages'
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_crawlingQ", this.crawlingQ() ? 1 : 0);
+        //prop.put(CRAWL_PROFILE_PREFIX + count + "_withQuery", (this.crawlingQ()) ? "1" : "0"); // TODO: remove, replace with crawlingQ
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_followFrames", this.followFrames() ? 1 : 0);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_obeyHtmlRobotsNoindex", this.obeyHtmlRobotsNoindex() ? 1 : 0);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_obeyHtmlRobotsNofollow", this.obeyHtmlRobotsNofollow() ? 1 : 0);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_indexText", this.indexText() ? 1 : 0);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_indexMedia", this.indexMedia() ? 1 : 0);
+        //prop.put(CRAWL_PROFILE_PREFIX + count + "_storeCache", this.storeHTCache() ? 1 : 0); // TODO: remove, replace with 'storeHTCache'
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_storeHTCache", this.storeHTCache() ? 1 : 0);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_remoteIndexing", this.remoteIndexing() ? 1 : 0);
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_cacheStrategy", this.get(CACHE_STRAGEGY));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_crawlerURLMustMatch", this.get(CRAWLER_URL_MUSTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_crawlerURLMustNotMatch", this.get(CRAWLER_URL_MUSTNOTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_crawlerIPMustMatch", this.get(CRAWLER_IP_MUSTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_crawlerIPMustNotMatch", this.get(CRAWLER_IP_MUSTNOTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_crawlerCountryMustMatch", this.get(CRAWLER_COUNTRY_MUSTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_crawlerNoLimitURLMustMatch", this.get(CRAWLER_URL_NODEPTHLIMITMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_indexURLMustMatch", this.get(INDEXING_URL_MUSTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_indexURLMustNotMatch", this.get(INDEXING_URL_MUSTNOTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_indexContentMustMatch", this.get(INDEXING_CONTENT_MUSTMATCH));
+        prop.putXML(CRAWL_PROFILE_PREFIX + count + "_indexContentMustNotMatch", this.get(INDEXING_CONTENT_MUSTNOTMATCH));
+        //prop.putXML(CRAWL_PROFILE_PREFIX + count + "_mustmatch", this.urlMustMatchPattern().toString()); // TODO: remove, replace with crawlerURLMustMatch
+        //prop.putXML(CRAWL_PROFILE_PREFIX + count + "_mustnotmatch", this.urlMustNotMatchPattern().toString()); // TODO: remove, replace with crawlerURLMustNotMatch
+        //prop.put(CRAWL_PROFILE_PREFIX + count + "_crawlingIfOlder", (this.recrawlIfOlder() == 0L) ? "no re-crawl" : DateFormat.getDateTimeInstance().format(this.recrawlIfOlder())); // TODO: remove, replace with recrawlIfOlder
         prop.put(CRAWL_PROFILE_PREFIX + count + "_crawlingDomFilterDepth", "inactive");
-
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_status", terminateButton ? 1 : deleteButton ? 0 : 2);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_terminateButton", terminateButton);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_terminateButton_handle", this.handle());
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_deleteButton", deleteButton);
+        prop.put(CRAWL_PROFILE_PREFIX + count + "_deleteButton_handle", this.handle());
+        
         int i = 0;
-        if (active && this.domMaxPages() > 0
-                && this.domMaxPages() != Integer.MAX_VALUE) {
-        String item;
-        while (i <= domlistlength && !(item = this.domName(true, i)).isEmpty()){
-            if (i == domlistlength) {
-                item += " ...";
+        if (active && this.domMaxPages() > 0 && this.domMaxPages() != Integer.MAX_VALUE) {
+            String item;
+            while (i <= domlistlength && !(item = this.domName(true, i)).isEmpty()) {
+                if (i == domlistlength) item += " ...";
+                prop.putHTML(CRAWL_PROFILE_PREFIX + count + "_crawlingDomFilterContent_" + i + "_item", item);
+                i++;
             }
-            prop.putHTML(CRAWL_PROFILE_PREFIX + count + "_crawlingDomFilterContent_" + i + "_item", item);
-            i++;
         }
-        }
-
         prop.put(CRAWL_PROFILE_PREFIX+count+"_crawlingDomFilterContent", i);
 
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_crawlingDomMaxPages", (this.domMaxPages() == Integer.MAX_VALUE) ? "unlimited" : Integer.toString(this.domMaxPages()));
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_withQuery", (this.crawlingQ()) ? "1" : "0");
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_storeCache", (this.storeHTCache()) ? "1" : "0");
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_indexText", (this.indexText()) ? "1" : "0");
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_indexMedia", (this.indexMedia()) ? "1" : "0");
-        prop.put(CRAWL_PROFILE_PREFIX + count + "_remoteIndexing", (this.remoteIndexing()) ? "1" : "0");
     }
 }
