@@ -25,6 +25,7 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -80,19 +81,20 @@ public final class Condenser {
     private String fuzzy_signature_text = null; // signatures for double-check detection
     
     public int RESULT_NUMB_WORDS = -1;
-    public int RESULT_DIFF_WORDS = -1;
+    //public int RESULT_DIFF_WORDS = -1;
     public int RESULT_NUMB_SENTENCES = -1;
-    public int RESULT_DIFF_SENTENCES = -1;
+    //public int RESULT_DIFF_SENTENCES = -1;
     public Bitfield RESULT_FLAGS = new Bitfield(4);
     private final Identificator languageIdentificator;
-
+    public LinkedHashSet<Date> dates_in_content;
+    
     public Condenser(
             final Document document,
             final boolean indexText,
             final boolean indexMedia,
             final WordCache meaningLib,
-            final SynonymLibrary synlib,
-            final boolean doAutotagging
+            final boolean doAutotagging,
+            final boolean findDatesInContent
             ) {
         Thread.currentThread().setName("condenser-" + document.dc_identifier()); // for debugging
         // if addMedia == true, then all the media links are also parsed and added to the words
@@ -100,7 +102,8 @@ public final class Condenser {
         this.words = new HashMap<String, Word>();
         this.synonyms = new LinkedHashSet<String>();
         this.RESULT_FLAGS = new Bitfield(4);
-
+        this.dates_in_content = new LinkedHashSet<Date>();
+        
         // construct flag set for document
         ContentDomain contentDomain = document.getContentDomain();
         if (contentDomain == ContentDomain.IMAGE || !document.getImages().isEmpty())     this.RESULT_FLAGS.set(flag_cat_hasimage, true);
@@ -116,7 +119,9 @@ public final class Condenser {
 
         Map.Entry<AnchorURL, String> entry;
         if (indexText) {
-            createCondensement(document.getTextString(), meaningLib, doAutotagging);
+            String text = document.getTextString();
+            if (findDatesInContent) this.dates_in_content = DateDetection.parse(text);
+            createCondensement(text, meaningLib, doAutotagging);
             // the phrase counter:
             // phrase   0 are words taken from the URL
             // phrase   1 is the MainTitle
@@ -158,9 +163,9 @@ public final class Condenser {
             */
         } else {
             this.RESULT_NUMB_WORDS = 0;
-            this.RESULT_DIFF_WORDS = 0;
+            //this.RESULT_DIFF_WORDS = 0;
             this.RESULT_NUMB_SENTENCES = 0;
-            this.RESULT_DIFF_SENTENCES = 0;
+            //this.RESULT_DIFF_SENTENCES = 0;
         }
 
         if (indexMedia) {
@@ -221,9 +226,9 @@ public final class Condenser {
         }
 
         // create the synonyms set
-        if (synlib != null && synlib.size() > 0) {
+        if (SynonymLibrary.size() > 0) {
             for (String word: this.words.keySet()) {
-                Set<String> syms = synlib.getSynonyms(word);
+                Set<String> syms = SynonymLibrary.getSynonyms(word);
                 if (syms != null) this.synonyms.addAll(syms);
             }
         }
@@ -275,7 +280,7 @@ public final class Condenser {
 	            this.words.put(word.toLowerCase(), wprop);
 	            pip++;
 	            this.RESULT_NUMB_WORDS++;
-	            this.RESULT_DIFF_WORDS++;
+	            //this.RESULT_DIFF_WORDS++;
 	        }
         } finally {
         	wordenum.close();
@@ -331,12 +336,12 @@ public final class Condenser {
         final Word wsp1;
         int wordHandle;
         int wordHandleCount = 0;
-        final int sentenceHandleCount = 0;
+        //final int sentenceHandleCount = 0;
         int allwordcounter = 0;
         final int allsentencecounter = 0;
         int wordInSentenceCounter = 1;
         boolean comb_indexof = false, last_last = false, last_index = false;
-        final Map<StringBuilder, Phrase> sentences = new HashMap<StringBuilder, Phrase>(100);
+        //final Map<StringBuilder, Phrase> sentences = new HashMap<StringBuilder, Phrase>(100);
         if (LibraryProvider.autotagging.isEmpty()) doAutotagging = false;
 
         // read source
@@ -380,7 +385,7 @@ public final class Condenser {
 
 	            // distinguish punctuation and words
 	            wordlen = word.length();
-	            if (wordlen == 1 && SentenceReader.punctuation(word.charAt(0))) {
+	            if (wordlen == 1 && SentenceReader.punctuation(word.charAt(0))) { // TODO: wordlen == 1 never true (see earlier if < wordminsize )
 	                // store sentence
 	                currsentwords.clear();
 	                wordInSentenceCounter = 1;
@@ -405,7 +410,7 @@ public final class Condenser {
 	                } else {
 	                    // word does not yet exist, create new word entry
 	                    wordHandle = wordHandleCount++;
-	                    wsp = new Word(wordHandle, wordInSentenceCounter, sentences.size() + 100);
+	                    wsp = new Word(wordHandle, wordInSentenceCounter, /* sentences.size() + */ 100);
 	                    wsp.flags = this.RESULT_FLAGS.clone();
 	                    this.words.put(word.toLowerCase(), wsp);
 	                }
@@ -447,9 +452,9 @@ public final class Condenser {
         // store result
         //this.RESULT_NUMB_TEXT_BYTES = wordenum.count();
         this.RESULT_NUMB_WORDS = allwordcounter;
-        this.RESULT_DIFF_WORDS = wordHandleCount;
+        //this.RESULT_DIFF_WORDS = wordHandleCount;
         this.RESULT_NUMB_SENTENCES = allsentencecounter;
-        this.RESULT_DIFF_SENTENCES = sentenceHandleCount;
+        //this.RESULT_DIFF_SENTENCES = sentenceHandleCount;
     }
 
     public static Map<String, Word> getWords(final String text, final WordCache meaningLib) {
