@@ -36,6 +36,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import net.yacy.cora.document.encoding.UTF8;
 import net.yacy.cora.document.id.AnchorURL;
 import net.yacy.cora.document.id.MultiProtocolURL;
+import net.yacy.document.parser.apkParser;
 import net.yacy.document.parser.audioTagParser;
 import net.yacy.document.parser.bzipParser;
 import net.yacy.document.parser.csvParser;
@@ -64,6 +65,7 @@ import net.yacy.document.parser.xlsParser;
 import net.yacy.document.parser.zipParser;
 import net.yacy.document.parser.augment.AugmentParser;
 import net.yacy.document.parser.images.genericImageParser;
+import net.yacy.document.parser.images.metadataImageParser;
 import net.yacy.document.parser.rdfa.impl.RDFaParser;
 import net.yacy.kelondro.util.FileUtils;
 import net.yacy.kelondro.util.MemoryControl;
@@ -82,6 +84,7 @@ public final class TextParser {
     private static final Map<String, Object> denyExtensionx = new ConcurrentHashMap<String, Object>();
 
     static {
+        initParser(new apkParser());
         initParser(new bzipParser());
         initParser(new csvParser());
         initParser(new docParser());
@@ -92,6 +95,7 @@ public final class TextParser {
         if (Switchboard.getSwitchboard().getConfigBool("parserAugmentation.RDFa", true)) initParser(new RDFaParser());          
         initParser(new htmlParser()); // called within rdfa parser
         initParser(new genericImageParser());
+        initParser(new metadataImageParser());
         initParser(new linkScraperParser());
         initParser(new mmParser());
         initParser(new odtParser());
