@@ -31,23 +31,15 @@
 
 package net.yacy.document.parser.html;
 
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.FileReader;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
-import java.io.Reader;
 import java.io.Writer;
-import java.net.MalformedURLException;
 import java.nio.charset.Charset;
 import java.util.Enumeration;
 import java.util.Properties;
 import java.util.Stack;
 
-import net.yacy.cora.document.encoding.UTF8;
-import net.yacy.cora.document.id.DigestURL;
-import net.yacy.cora.util.ConcurrentLog;
 import net.yacy.kelondro.io.CharBuffer;
 
 
@@ -542,30 +534,4 @@ public final class TransformerWriter extends Writer {
         return !this.binaryUnsuspect;
     }
 
-    public static void main(final String[] args) {
-        // takes one argument: a file name
-        if (args.length != 1) return;
-        // TODO: this does not work at the moment
-        System.out.println("this does not work at the moment");
-        System.exit(0);
-        final char[] buffer = new char[512];
-        try {
-            final ContentScraper scraper = new ContentScraper(new DigestURL("http://localhost:8090"), 1000);
-            final Transformer transformer = new ContentTransformer();
-            final Reader is = new FileReader(args[0]);
-            final FileOutputStream fos = new FileOutputStream(new File(args[0] + ".out"));
-            final Writer os = new TransformerWriter(fos, UTF8.charset, scraper, transformer, false);
-            int i;
-            while ((i = is.read(buffer)) > 0) os.write(buffer, 0, i);
-            os.close();
-            fos.close();
-            is.close();
-            scraper.print();
-        } catch (final MalformedURLException e) {
-            ConcurrentLog.logException(e);
-        } catch (final IOException e) {
-            ConcurrentLog.logException(e);
-        }
-    }
-
 }
\ No newline at end of file
