@@ -72,6 +72,7 @@ public class Jetty9HttpServerImpl implements YaCyHttpServer {
         ServerConnector connector = new ServerConnector(server);
         connector.setPort(port);
         connector.setName("httpd:"+Integer.toString(port));
+        connector.setIdleTimeout(9000); // timout in ms when no bytes send / received
         server.addConnector(connector);
         
         // add ssl/https connector
@@ -82,7 +83,7 @@ public class Jetty9HttpServerImpl implements YaCyHttpServer {
             final SSLContext sslContext = initSslContext(sb);
             if (sslContext != null) {
 
-                int sslport = sb.getConfigInt("port.ssl", 8443);
+                int sslport = sb.getLocalPort("port.ssl", 8443);
                 sslContextFactory.setSslContext(sslContext);
 
                 // SSL HTTP Configuration
@@ -95,6 +96,7 @@ public class Jetty9HttpServerImpl implements YaCyHttpServer {
                         new HttpConnectionFactory(https_config));
                 sslConnector.setPort(sslport);
                 sslConnector.setName("ssld:" + Integer.toString(sslport)); // name must start with ssl (for withSSL() to work correctly)
+                sslConnector.setIdleTimeout(9000); // timout in ms when no bytes send / received
 
                 server.addConnector(sslConnector);
                 ConcurrentLog.info("SERVER", "SSL support initialized successfully on port " + sslport);
@@ -114,13 +116,13 @@ public class Jetty9HttpServerImpl implements YaCyHttpServer {
 
             // set web.xml to use
             // make use of Jetty feature to define web.xml other as default WEB-INF/web.xml
-            // look in DATA/SETTINGS or use the one in DEFAULTS
+            // and to use a DefaultsDescriptor merged with a individual web.xml
+            // use defaults/web.xml as default and look in DATA/SETTINGS for local addition/changes
+            htrootContext.setDefaultsDescriptor(sb.appPath + "/defaults/web.xml");
             Resource webxml = Resource.newResource(sb.dataPath + "/DATA/SETTINGS/web.xml");
             if (webxml.exists()) {
                 htrootContext.setDescriptor(webxml.getName());
-            } else {
-                htrootContext.setDescriptor(sb.appPath + "/defaults/web.xml");
-            }
+            } 
 
         } catch (IOException ex) {
             if (htrootContext.getBaseResource() == null) {
@@ -286,8 +288,8 @@ public class Jetty9HttpServerImpl implements YaCyHttpServer {
                 }
                 try { // reconnect with new settings (instead to stop/start server, just manipulate connectors
                     final Connector[] cons = server.getConnectors();
-                    final int port = Switchboard.getSwitchboard().getConfigInt("port", 8090);
-                    final int sslport = Switchboard.getSwitchboard().getConfigInt("port.ssl", 8443);
+                    final int port = Switchboard.getSwitchboard().getLocalPort("port", 8090);
+                    final int sslport = Switchboard.getSwitchboard().getLocalPort("port.ssl", 8443);
                     for (Connector con : cons) {
                         // check http connector
                         if (con.getName().startsWith("httpd") && ((ServerConnector)con).getPort() != port) {
