@@ -480,6 +480,9 @@ public class YaCyDefaultServlet extends HttpServlet  {
         byte[] data = dir.getBytes("UTF-8");
         response.setContentType(TEXT_HTML_UTF_8.asString());
         response.setContentLength(data.length);
+        response.setHeader(HeaderFramework.CACHE_CONTROL, "no-cache, no-store");
+        response.setDateHeader(HeaderFramework.EXPIRES, System.currentTimeMillis() + 10000); // consider that directories are not modified that often
+        response.setDateHeader(HeaderFramework.LAST_MODIFIED, resource.lastModified());
         response.getOutputStream().write(data);
     }
 
@@ -511,6 +514,9 @@ public class YaCyDefaultServlet extends HttpServlet  {
             out = new WriterOutputStream(response.getWriter());
         }
 
+        response.setDateHeader(HeaderFramework.EXPIRES, System.currentTimeMillis() + 600000); // expires ten minutes in the future
+        response.setDateHeader(HeaderFramework.LAST_MODIFIED, resource.lastModified());
+        
         if (reqRanges == null || !reqRanges.hasMoreElements() || content_length < 0) {
             //  if there were no ranges, send entire entity
             if (include) {
@@ -776,6 +782,16 @@ public class YaCyDefaultServlet extends HttpServlet  {
         File targetClass = rewriteClassFile(_resourceBase.addPath(target).getFile());
         String targetExt = target.substring(target.lastIndexOf('.') + 1);
 
+        long now = System.currentTimeMillis();
+        response.setDateHeader(HeaderFramework.LAST_MODIFIED, now);
+        if (target.endsWith(".css")) {
+            response.setDateHeader(HeaderFramework.EXPIRES, now + 4000); // expires in 4 seconds (which is still too often)
+        } else if (target.endsWith(".png")) {
+            response.setDateHeader(HeaderFramework.EXPIRES, now + 1000); // expires in 1 seconds (reduce heavy image creation load)
+        } else {
+            response.setDateHeader(HeaderFramework.EXPIRES, now); // expires now
+        }
+        
         if ((targetClass != null)) {
             serverObjects args = new serverObjects();
             Enumeration<String> argNames = request.getParameterNames();
@@ -826,6 +842,9 @@ public class YaCyDefaultServlet extends HttpServlet  {
                 } else if (tmp instanceof EncodedImage) {
                     final EncodedImage yp = (EncodedImage) tmp;
                     result = yp.getImage();
+                    if (yp.isStatic()) {
+                        response.setDateHeader(HeaderFramework.EXPIRES, now + 600000); // expires in ten minutes
+                    }
                 } else if (tmp instanceof Image) {
                     final Image i = (Image) tmp;
 
@@ -853,6 +872,19 @@ public class YaCyDefaultServlet extends HttpServlet  {
                 return;
             }
 
+            if (tmp instanceof InputStream) {
+                final InputStream is = (InputStream) tmp;
+                final String mimeType = Classification.ext2mime(targetExt, TEXT_HTML.asString());
+                response.setContentType(mimeType);
+                response.setStatus(HttpServletResponse.SC_OK);
+                byte[] buffer = new byte[4096];
+                int l, size = 0;
+                while ((l = is.read(buffer)) > 0) {response.getOutputStream().write(buffer, 0, l); size += l;}
+                response.setContentLength(size);
+                is.close();
+                return;
+            }
+
             servletProperties templatePatterns;
             if (tmp == null) {
                 // if no args given, then tp will be an empty Hashtable object (not null)
@@ -903,15 +935,17 @@ public class YaCyDefaultServlet extends HttpServlet  {
                 templatePatterns.putHTML("newpeer_peerhash", myPeer.hash);
                 boolean authorized = sb.adminAuthenticated(legacyRequestHeader) >= 2;
                 templatePatterns.put("authorized", authorized ? 1 : 0);
+
+                templatePatterns.put("simpleheadernavbar", sb.getConfig("decoration.simpleheadernavbar", "navbar-default"));
                 
                 // add navigation keys to enable or disable menu items
                 templatePatterns.put("navigation-p2p", sb.getConfigBool(SwitchboardConstants.DHT_ENABLED, true) || !sb.isRobinsonMode() ? 1 : 0);
                 templatePatterns.put("navigation-p2p_authorized", authorized ? 1 : 0);
                 String submitted = sb.getConfig("server.servlets.submitted", "");
-                boolean crawler_enabled =
+                boolean crawler_enabled = true; /*
                         submitted.contains("Crawler_p") ||
                         submitted.contains("ConfigBasic") ||
-                        submitted.contains("Load_RSS_p");
+                        submitted.contains("Load_RSS_p");*/
                 boolean advanced_enabled =
                         crawler_enabled ||
                         submitted.contains("IndexImportMediawiki_p") ||
