@@ -879,7 +879,7 @@ public class ArrayStack implements BLOB {
         assert mem() <= m : "m = " + m + ", mem() = " + mem();
     }
 
-    private static final ExecutorService DELETE_EXECUTOR = Executors.newFixedThreadPool(128);
+    private static final ExecutorService DELETE_EXECUTOR = Executors.newCachedThreadPool();
 
     /**
      * close the BLOB
