@@ -24,6 +24,7 @@
 
 package net.yacy.kelondro.util;
 
+import java.io.BufferedInputStream;
 import java.io.BufferedReader;
 import java.io.BufferedWriter;
 import java.io.ByteArrayInputStream;
@@ -49,10 +50,14 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.regex.Pattern;
 import java.util.zip.GZIPInputStream;
 
+import org.mozilla.intl.chardet.nsDetector;
+import org.mozilla.intl.chardet.nsPSMDetector;
+
 import net.yacy.cora.document.encoding.UTF8;
 import net.yacy.cora.storage.Files;
 import net.yacy.cora.util.ConcurrentLog;
@@ -403,6 +408,7 @@ public final class FileUtils {
     private final static Pattern escaped_backslash = Pattern.compile(Pattern.quote("\\"), Pattern.LITERAL);
 
     public static void saveMap(final File file, final Map<String, String> props, final String comment) {
+    	boolean err = false;
         PrintWriter pw = null;
         final File tf = new File(file.toString() + "." + (System.currentTimeMillis() % 1000));
         try {
@@ -428,15 +434,17 @@ public final class FileUtils {
             pw.println("# EOF");
         } catch (final  FileNotFoundException e ) {
             ConcurrentLog.warn("FileUtils", e.getMessage(), e);
+            err = true;
         } catch (final  UnsupportedEncodingException e ) {
             ConcurrentLog.warn("FileUtils", e.getMessage(), e);
+            err = true;
         } finally {
             if ( pw != null ) {
                 pw.close();
             }
             pw = null;
         }
-        try {
+        if (!err) try {
             forceMove(tf, file);
         } catch (final  IOException e ) {
             // ignore
@@ -806,6 +814,8 @@ public final class FileUtils {
             }
         }
 
+        if (path.exists()) path.delete();
+        /*
         int c = 0;
         while ( c++ < 20 ) {
             if ( !path.exists() ) {
@@ -823,6 +833,7 @@ public final class FileUtils {
                 break;
             }
         }
+        */
         if ( path.exists() ) {
             path.deleteOnExit();
             String p = "";
@@ -876,5 +887,64 @@ public final class FileUtils {
         
         return inDirectory;
     }
+    
+    /**
+     * auto-detect the charset of a file
+     * used code from http://jchardet.sourceforge.net/;
+     * see also: http://www-archive.mozilla.org/projects/intl/chardet.html
+     * @param file
+     * @return a set of probable charsets
+     * @throws IOException
+     */
+    public static Set<String> detectCharset(File file) throws IOException {
+        // auto-detect charset, used code from http://jchardet.sourceforge.net/; see also: http://www-archive.mozilla.org/projects/intl/chardet.html
+        nsDetector det = new nsDetector(nsPSMDetector.ALL);
+        BufferedInputStream imp = new BufferedInputStream(new FileInputStream(file));
+
+        byte[] buf = new byte[1024] ;
+        int len;
+        boolean done = false ;
+        boolean isAscii = true ;
+
+        while ((len = imp.read(buf,0,buf.length)) != -1) {
+            if (isAscii) isAscii = det.isAscii(buf,len);
+            if (!isAscii && !done) done = det.DoIt(buf,len, false);
+        }
+        det.DataEnd();
+        Set<String> result = new HashSet<>();
+        if (isAscii) {
+            result.add("ASCII");
+        } else {
+            for (String c: det.getProbableCharsets()) result.add(c);
+        }
+
+        return result;
+    }
+    
+    /**
+     * Because the checking of very large files for their charset may take some time, we do this concurrently in this method
+     * This method does not return anything but it logs an info line if the charset is a good choice
+     * and it logs a warning line if the choice was bad.
+     * @param file the file to be checked
+     * @param givenCharset the charset that we consider to be valid
+     * @param concurrent if this shall run concurrently
+     */
+    public static void checkCharset(final File file, final String givenCharset, final boolean concurrent) {
+        Thread t = new Thread() {
+            @Override
+            public void run() {
+                try {
+                    Set<String> charsets = FileUtils.detectCharset(file);
+                    if (charsets.contains(givenCharset)) {
+                        ConcurrentLog.info("checkCharset", "appropriate charset '" + givenCharset + "' for import of " + file + ", is part one detected " + charsets);
+                    } else {
+                        ConcurrentLog.warn("checkCharset", "possibly wrong charset '" + givenCharset + "' for import of " + file + ", use one of " + charsets);
+                    }
+                } catch (IOException e) {}
+                
+            }
+        };
+        if (concurrent) t.start(); else t.run();
+    }
 
 }
