@@ -46,6 +46,7 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Semaphore;
 
@@ -101,7 +102,7 @@ public class Network
 
         // ensure that correct IP is used
         final String staticIP = sb.getConfig("staticIP", "");
-        if ( staticIP.length() != 0 && Seed.isProperIP(staticIP) == null ) {
+        if (staticIP.length() != 0 && Seed.isProperIP(staticIP)) {
             serverCore.useStaticIP = true;
             sb.peers.mySeed().setIP(staticIP);
             log.info("staticIP set to " + staticIP);
@@ -118,9 +119,7 @@ public class Network
     }
 
     public final void publishSeedList() {
-        if ( log.isFine() ) {
-            log.fine("yacyCore.publishSeedList: Triggered Seed Publish");
-        }
+        if (log.isFine()) log.fine("yacyCore.publishSeedList: Triggered Seed Publish");
 
         /*
         if (oldIPStamp.equals((String) seedDB.mySeed.get(yacySeed.IP, "127.0.0.1")))
@@ -131,14 +130,11 @@ public class Network
             yacyCore.log.logDebug("***DEBUG publishSeedList: I can reach myself");
         */
 
-        if ( (this.sb.peers.lastSeedUpload_myIP.equals(this.sb.peers.mySeed().getIP()))
+        if ((this.sb.peers.mySeed().getIPs().contains(this.sb.peers.lastSeedUpload_myIP))
             && (this.sb.peers.lastSeedUpload_seedDBSize == this.sb.peers.sizeConnected())
             && (System.currentTimeMillis() - this.sb.peers.lastSeedUpload_timeStamp < 1000 * 60 * 60 * 24)
             && (this.sb.peers.mySeed().isPrincipal()) ) {
-            if ( log.isFine() ) {
-                log
-                    .fine("yacyCore.publishSeedList: not necessary to publish: oldIP is equal, sizeConnected is equal and I can reach myself under the old IP.");
-            }
+            if (log.isFine()) log.fine("yacyCore.publishSeedList: not necessary to publish: oldIP is equal, sizeConnected is equal and I can reach myself under the old IP.");
             return;
         }
 
@@ -162,9 +158,7 @@ public class Network
             if ( seedUploadMethod.equals("") ) {
                 this.sb.setConfig("seedUploadMethod", "none");
             }
-            if ( log.isFine() ) {
-                log.fine("yacyCore.publishSeedList: No uploading method configured");
-            }
+            if (log.isFine()) log.fine("yacyCore.publishSeedList: No uploading method configured");
             return;
         }
     }
@@ -191,14 +185,7 @@ public class Network
                 + this.sb.peers.sizeConnected()
                 + " new peer(s)");
         }
-        final int newSeeds = publishMySeed(false);
-        if ( newSeeds > 0 ) {
-            log.info("received "
-                + newSeeds
-                + " new peer(s), know a total of "
-                + this.sb.peers.sizeConnected()
-                + " different peers");
-        }
+        publishMySeed();
     }
 
     // use our own formatter to prevent concurrency locks with other processes
@@ -208,7 +195,7 @@ public class Network
 
     protected class publishThread extends Thread
     {
-        int added;
+        private Map<String, String> result;
         private final Seed seed;
         private final Semaphore sync;
         private final List<Thread> syncList;
@@ -225,88 +212,44 @@ public class Network
             this.syncList = syncList;
 
             this.seed = seed;
-            this.added = 0;
+            this.result = null;
         }
 
         @Override
         public final void run() {
             try {
-                this.added =
-                    Protocol.hello(
-                        Network.this.sb.peers.mySeed(),
-                        Network.this.sb.peers.peerActions,
-                        this.seed.getClusterAddress(),
-                        this.seed.hash,
-                        this.seed.getName());
-                if ( this.added < 0 ) {
-                    // no or wrong response, delete that address
-                    final String cause = "peer ping to peer resulted in error response (added < 0)";
-                    log.info("publish: disconnected "
-                        + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR)
-                        + " peer '"
-                        + this.seed.getName()
-                        + "' from "
-                        + this.seed.getPublicAddress()
-                        + ": "
-                        + cause);
-                    Network.this.sb.peers.peerActions.peerDeparture(this.seed, cause);
-                } else {
+                for (String ip: this.seed.getIPs()) {
+                    this.result = Protocol.hello(Network.this.sb.peers.mySeed(), Network.this.sb.peers.peerActions, this.seed.getPublicAddress(ip), this.seed.hash);
+                    if ( this.result == null ) {
+                        // no or wrong response, delete that address
+                        final String cause = "peer ping to peer resulted in error response (added < 0)";
+                        log.info("publish: disconnected " + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + this.seed.getName() + "' from " + this.seed.getIPs() + ": " + cause);
+                        Network.this.sb.peers.peerActions.interfaceDeparture(this.seed, ip);
+                        continue;
+                    }
                     // success! we have published our peer to a senior peer
                     // update latest news from the other peer
-                    log.info("publish: handshaked "
-                        + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR)
-                        + " peer '"
-                        + this.seed.getName()
-                        + "' at "
-                        + this.seed.getPublicAddress());
+                    log.info("publish: handshaked "+ this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + this.seed.getName() + "' at " + this.seed.getIPs());
                     // check if seed's lastSeen has been updated
                     final Seed newSeed = Network.this.sb.peers.getConnected(this.seed.hash);
                     if ( newSeed != null ) {
                         if ( !newSeed.isOnline() ) {
                             if ( log.isFine() ) {
-                                log.fine("publish: recently handshaked "
-                                    + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR)
-                                    + " peer '"
-                                    + this.seed.getName()
-                                    + "' at "
-                                    + this.seed.getPublicAddress()
-                                    + " is not online."
-                                    + " Removing Peer from connected");
+                                log.fine("publish: recently handshaked " + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + this.seed.getName() + "' at " + this.seed.getIPs() + " is not online." + " Removing Peer from connected");
                             }
-                            Network.this.sb.peers.peerActions.peerDeparture(newSeed, "peer not online");
+                            Network.this.sb.peers.peerActions.interfaceDeparture(newSeed, ip);
+                            continue;
                         } else if ( newSeed.getLastSeenUTC() < (System.currentTimeMillis() - 10000) ) {
                             // update last seed date
                             if ( newSeed.getLastSeenUTC() >= this.seed.getLastSeenUTC() ) {
                                 if ( log.isFine() ) {
-                                    log
-                                        .fine("publish: recently handshaked "
-                                            + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR)
-                                            + " peer '"
-                                            + this.seed.getName()
-                                            + "' at "
-                                            + this.seed.getPublicAddress()
-                                            + " with old LastSeen: '"
-                                            + my_SHORT_SECOND_FORMATTER.format(new Date(newSeed
-                                                .getLastSeenUTC())) + "'");
+                                    log.fine("publish: recently handshaked " + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + this.seed.getName() + "' at " + this.seed.getIPs() + " with old LastSeen: '" + my_SHORT_SECOND_FORMATTER.format(new Date(newSeed.getLastSeenUTC())) + "'");
                                 }
                                 newSeed.setLastSeenUTC();
                                 Network.this.sb.peers.peerActions.peerArrival(newSeed, true);
                             } else {
                                 if ( log.isFine() ) {
-                                    log
-                                        .fine("publish: recently handshaked "
-                                            + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR)
-                                            + " peer '"
-                                            + this.seed.getName()
-                                            + "' at "
-                                            + this.seed.getPublicAddress()
-                                            + " with old LastSeen: '"
-                                            + my_SHORT_SECOND_FORMATTER.format(new Date(newSeed
-                                                .getLastSeenUTC()))
-                                            + "', this is more recent: '"
-                                            + my_SHORT_SECOND_FORMATTER.format(new Date(this.seed
-                                                .getLastSeenUTC()))
-                                            + "'");
+                                    log.fine("publish: recently handshaked " + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + this.seed.getName() + "' at " + this.seed.getIPs() + " with old LastSeen: '" + my_SHORT_SECOND_FORMATTER.format(new Date(newSeed.getLastSeenUTC())) + "', this is more recent: '" + my_SHORT_SECOND_FORMATTER.format(new Date(this.seed.getLastSeenUTC())) + "'");
                                 }
                                 this.seed.setLastSeenUTC();
                                 Network.this.sb.peers.peerActions.peerArrival(this.seed, true);
@@ -314,13 +257,7 @@ public class Network
                         }
                     } else {
                         if ( log.isFine() ) {
-                            log.fine("publish: recently handshaked "
-                                + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR)
-                                + " peer '"
-                                + this.seed.getName()
-                                + "' at "
-                                + this.seed.getPublicAddress()
-                                + " not in connectedDB");
+                            log.fine("publish: recently handshaked " + this.seed.get(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR) + " peer '" + this.seed.getName() + "' at " + this.seed.getIPs() + " not in connectedDB");
                         }
                     }
                 }
@@ -336,7 +273,7 @@ public class Network
         }
     }
 
-    private int publishMySeed(final boolean force) {
+    private boolean publishMySeed() {
         try {
             // call this after the httpd was started up
 
@@ -361,28 +298,20 @@ public class Network
 
             // getting a list of peers to contact
             if ( this.sb.peers.mySeed().get(Seed.PEERTYPE, Seed.PEERTYPE_VIRGIN).equals(Seed.PEERTYPE_VIRGIN) ) {
-                if ( attempts > PING_INITIAL ) {
-                    attempts = PING_INITIAL;
-                }
-                final Map<byte[], String> ch = Switchboard.getSwitchboard().clusterhashes;
+                if (attempts > PING_INITIAL) attempts = PING_INITIAL;
+                final Set<byte[]> ch = Switchboard.getSwitchboard().clusterhashes;
                 seeds = DHTSelection.seedsByAge(this.sb.peers, true, attempts - ((ch == null) ? 0 : ch.size())); // best for fast connection
                 // add also all peers from cluster if this is a public robinson cluster
                 if ( ch != null ) {
-                    final Iterator<Map.Entry<byte[], String>> i = ch.entrySet().iterator();
                     String hash;
-                    Map.Entry<byte[], String> entry;
                     Seed seed;
-                    while ( i.hasNext() ) {
-                        entry = i.next();
-                        hash = ASCII.String(entry.getKey());
+                    for (byte[] hashb: ch) {
+                        hash = ASCII.String(hashb);
                         seed = seeds.get(hash);
-                        if ( seed == null ) {
+                        if (seed == null) {
                             seed = this.sb.peers.get(hash);
-                            if ( seed == null ) {
-                                continue;
-                            }
+                            if (seed == null) continue;
                         }
-                        seed.setAlternativeAddress(entry.getValue());
                         seeds.put(hash, seed);
                     }
                 }
@@ -401,12 +330,8 @@ public class Network
                 seeds = DHTSelection.seedsByAge(this.sb.peers, false, attempts); // best for seed list maintenance/cleaning
             }
 
-            if ( seeds == null || seeds.isEmpty() ) {
-                return 0;
-            }
-            if ( seeds.size() < attempts ) {
-                attempts = seeds.size();
-            }
+            if (seeds == null || seeds.isEmpty()) return false;
+            if (seeds.size() < attempts) attempts = seeds.size();
 
             // This will try to get Peers that are not currently in amIAccessibleDB
             final Iterator<Seed> si = seeds.values().iterator();
@@ -424,14 +349,13 @@ public class Network
                 log.severe("publishMySeed: problem with news encoding", e);
             }
             this.sb.peers.mySeed().setUnusedFlags();
-            int newSeeds = -1;
             //if (seeds.length > 1) {
             // holding a reference to all started threads
             int contactedSeedCount = 0;
             final List<Thread> syncList = Collections.synchronizedList(new LinkedList<Thread>()); // memory for threads
             final Semaphore sync = new Semaphore(attempts);
 
-            // going through the peer list and starting a new publisher thread for each peer
+            // go through the peer list and starting a new publisher thread for each peer
             int i = 0;
             while ( si.hasNext() ) {
                 seed = si.next();
@@ -441,17 +365,13 @@ public class Network
                 }
                 i++;
 
-                final String address = seed.getClusterAddress();
-                if ( log.isFine() ) {
-                    log.fine("HELLO #" + i + " to peer '" + seed.get(Seed.NAME, "") + "' at " + address); // debug
-                }
+                String ip = seed.getIP();
+                final String address = seed.getPublicAddress(ip);
+                if ( log.isFine() ) log.fine("HELLO #" + i + " to peer '" + seed.get(Seed.NAME, "") + "' at " + address); // debug
                 final String seederror = seed.isProper(false);
                 if ( (address == null) || (seederror != null) ) {
                     // we don't like that address, delete it
-                    this.sb.peers.peerActions.peerDeparture(seed, "peer ping to peer resulted in address = "
-                        + address
-                        + "; seederror = "
-                        + seederror);
+                    this.sb.peers.peerActions.interfaceDeparture(seed, ip);
                     sync.acquire();
                 } else {
                     // starting a new publisher thread
@@ -475,15 +395,6 @@ public class Network
 
                 // getting a reference to the finished thread
                 final publishThread t = (publishThread) syncList.remove(0);
-
-                // getting the amount of new reported seeds
-                if ( t.added >= 0 ) {
-                    if ( newSeeds == -1 ) {
-                        newSeeds = t.added;
-                    } else {
-                        newSeeds += t.added;
-                    }
-                }
             }
 
             int accessible = 0;
@@ -505,19 +416,9 @@ public class Network
                         }
                     }
                 }
-                if ( log.isFine() ) {
-                    log
-                        .fine("DBSize before -> after Cleanup: "
-                            + dbSize
-                            + " -> "
-                            + amIAccessibleDB.size());
-                }
+                if (log.isFine()) log.fine("DBSize before -> after Cleanup: " + dbSize + " -> " + amIAccessibleDB.size());
             }
-            log.info("PeerPing: I am accessible for "
-                + accessible
-                + " peer(s), not accessible for "
-                + notaccessible
-                + " peer(s).");
+            log.info("PeerPing: I am accessible for " + accessible + " peer(s), not accessible for " + notaccessible + " peer(s).");
 
             if ( (accessible + notaccessible) > 0 ) {
                 final String newPeerType;
@@ -536,11 +437,7 @@ public class Network
                 if ( this.sb.peers.mySeed().orVirgin().equals(newPeerType) ) {
                     log.info("PeerPing: myType is " + this.sb.peers.mySeed().orVirgin());
                 } else {
-                    log.info("PeerPing: changing myType from '"
-                        + this.sb.peers.mySeed().orVirgin()
-                        + "' to '"
-                        + newPeerType
-                        + "'");
+                    log.info("PeerPing: changing myType from '" + this.sb.peers.mySeed().orVirgin() + "' to '" + newPeerType + "'");
                     this.sb.peers.mySeed().put(Seed.PEERTYPE, newPeerType);
                 }
             } else {
@@ -553,32 +450,20 @@ public class Network
             this.sb.peers.saveMySeed();
 
             // if we have an address, we do nothing
-            if ( this.sb.peers.mySeed().isProper(true) == null && !force ) {
-                return 0;
-            }
-            if ( newSeeds > 0 ) {
-                return newSeeds;
-            }
+            if (this.sb.peers.mySeed().isProper(true) == null) return true;
 
-            // still no success: ask own NAT or internet responder
-            //final boolean DI604use = switchboard.getConfig("DI604use", "false").equals("true");
-            //final String  DI604pw  = switchboard.getConfig("DI604pw", "");
+            // still no success
             final String ip = this.sb.getConfig("staticIP", "");
-            //if (ip.equals("")) ip = natLib.retrieveIP(DI604use, DI604pw);
 
-            // yacyCore.log.logDebug("DEBUG: new IP=" + ip);
-            if ( Seed.isProperIP(ip) == null ) {
+            if (Seed.isProperIP(ip)) {
                 this.sb.peers.mySeed().setIP(ip);
             }
             if ( this.sb.peers.mySeed().get(Seed.PEERTYPE, Seed.PEERTYPE_JUNIOR).equals(Seed.PEERTYPE_JUNIOR) ) {
                 this.sb.peers.mySeed().put(Seed.PEERTYPE, Seed.PEERTYPE_SENIOR); // to start bootstraping, we need to be recognised as PEERTYPE_SENIOR peer
             }
-            log.info("publish: no recipient found, our address is "
-                + ((this.sb.peers.mySeed().getPublicAddress() == null) ? "unknown" : this.sb.peers
-                    .mySeed()
-                    .getPublicAddress()));
+            log.info("publish: no recipient found, our address is " + this.sb.peers.mySeed().getIPs());
             this.sb.peers.saveMySeed();
-            return 0;
+            return false;
         } catch (final InterruptedException e ) {
             try {
                 log.info("publish: Interruption detected while publishing my seed.");
@@ -628,12 +513,10 @@ public class Network
                 log.info("publish: Shutdown off all remaining publishing thread finished.");
 
             } catch (final Exception ee ) {
-                log.warn(
-                    "publish: Unexpected error while trying to shutdown all remaining publishing threads.",
-                    e);
+                log.warn("publish: Unexpected error while trying to shutdown all remaining publishing threads.", e);
             }
 
-            return 0;
+            return false;
         }
     }
 
@@ -703,7 +586,7 @@ public class Network
             String logt;
 
             // be shure that we have something to say
-            if ( sb.peers.mySeed().getPublicAddress() == null ) {
+            if ( sb.peers.mySeed().getPublicAddress(sb.peers.mySeed().getIP()) == null ) {
                 final String errorMsg = "We have no valid IP address until now";
                 log.warn("SaveSeedList: " + errorMsg);
                 return errorMsg;
