@@ -30,7 +30,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Random;
 import java.util.Set;
-import java.util.SortedMap;
+import java.util.SortedSet;
 
 import org.apache.solr.client.solrj.SolrQuery;
 
@@ -144,7 +144,7 @@ public class RemoteSearch extends Thread {
     		final int start, final int count, 
             final long time,
             final Blacklist blacklist,
-            final SortedMap<byte[], String> clusterselection) {
+            final SortedSet<byte[]> clusterselection) {
         // check own peer status
         //if (wordIndex.seedDB.mySeed() == null || wordIndex.seedDB.mySeed().getPublicAddress() == null) { return null; }
         
@@ -174,7 +174,6 @@ public class RemoteSearch extends Thread {
             dhtPeers = DHTSelection.selectClusterPeers(event.peers, clusterselection);
         } else {
             if (event.query.getQueryGoal().isCatchall() || event.query.getQueryGoal().getIncludeHashes().has(Segment.catchallHash)) {
-               
                 if (event.query.modifier.sitehost != null && event.query.modifier.sitehost.length() > 0) {
                     // select peers according to host name, not the query goal
                     String newGoal = Domains.getSmartSLD(event.query.modifier.sitehost);
@@ -186,29 +185,29 @@ public class RemoteSearch extends Thread {
                             random);
                 } else {
                     // select just random peers
-                    dhtPeers = DHTSelection.seedsByAge(event.peers, false, count).values();
+                    dhtPeers = DHTSelection.seedsByAge(event.peers, false, event.peers.redundancy()).values();
+                }
+            } else {
+                dhtPeers = DHTSelection.selectDHTSearchTargets(
+                                event.peers,
+                                event.query.getQueryGoal().getIncludeHashes(),
+                                minage,
+                                redundancy, event.peers.redundancy(),
+                                random);
+                // this set of peers may be too large and consume too many threads if more than one word is searched.
+                // to prevent overloading, we do a subset collection based on random to prevent the death of the own peer
+                // and to do a distributed load-balancing on the target peers
+                long targetSize = 1 + redundancy * event.peers.scheme.verticalPartitions(); // this is the maximum for one word plus one
+                if (dhtPeers.size() > targetSize) {
+                    ArrayList<Seed> pa = new ArrayList<Seed>(dhtPeers.size());
+                    pa.addAll(dhtPeers);
+                    dhtPeers.clear();
+                    for (int i = 0; i < targetSize; i++) dhtPeers.add(pa.remove(random.nextInt(pa.size())));
                 }
-            }
-            
-            dhtPeers = DHTSelection.selectDHTSearchTargets(
-                            event.peers,
-                            event.query.getQueryGoal().getIncludeHashes(),
-                            minage,
-                            redundancy, event.peers.redundancy(),
-                            random);
-            // this set of peers may be too large and consume too many threads if more than one word is searched.
-            // to prevent overloading, we do a subset collection based on random to prevent the death of the own peer
-            // and to do a distributed load-balancing on the target peers
-            long targetSize = 1 + redundancy * event.peers.scheme.verticalPartitions(); // this is the maximum for one word plus one
-            if (dhtPeers.size() > targetSize) {
-                ArrayList<Seed> pa = new ArrayList<Seed>(dhtPeers.size());
-                pa.addAll(dhtPeers);
-                dhtPeers.clear();
-                for (int i = 0; i < targetSize; i++) dhtPeers.add(pa.remove(random.nextInt(pa.size())));
             }
         }
         if (dhtPeers == null) dhtPeers = new HashSet<Seed>();
-        
+
         // select node targets
         final Collection<Seed> robinsonPeers = DHTSelection.selectExtraTargets(event.peers, event.query.getQueryGoal().getIncludeHashes(), minage, dhtPeers, robinsoncount, random);
         
@@ -277,14 +276,13 @@ public class RemoteSearch extends Thread {
             final Blacklist blacklist) {
 
         // check own peer status
-        if (event.peers.mySeed() == null || event.peers.mySeed().getPublicAddress() == null) { return null; }
+        if (event.peers.mySeed() == null || event.peers.mySeed().getIPs().size() == 0) { return null; }
         assert urlhashes != null;
         assert urlhashes.length() > 0;
 
         // prepare seed targets and threads
         final Seed targetPeer = event.peers.getConnected(targethash);
         if (targetPeer == null || targetPeer.hash == null) return null;
-        if (event.preselectedPeerHashes != null) targetPeer.setAlternativeAddress(event.preselectedPeerHashes.get(ASCII.getBytes(targetPeer.hash)));
         Thread secondary = new Thread() {
             @Override
             public void run() {
@@ -332,12 +330,8 @@ public class RemoteSearch extends Thread {
 
         assert solrQuery != null;
         // check own peer status
-        if (event.peers.mySeed() == null || event.peers.mySeed().getPublicAddress() == null) { return null; }
-        // prepare seed targets and threads
-        if (targetPeer != null && targetPeer.hash != null && event.preselectedPeerHashes != null) {
-            if (!targetPeer.getFlagSolrAvailable()) return null; // solr interface not avail.
-            targetPeer.setAlternativeAddress(event.preselectedPeerHashes.get(ASCII.getBytes(targetPeer.hash)));
-        }
+        if (event.peers.mySeed() == null) { return null; }
+        // prepare threads
         Thread solr = new Thread() {
             @Override
             public void run() {
@@ -345,13 +339,12 @@ public class RemoteSearch extends Thread {
                     int urls = 0;
                     try {
                         event.oneFeederStarted();
-                        boolean localsearch = (targetPeer == null || targetPeer.equals(event.peers.mySeed())) && Switchboard.getSwitchboard().getConfigBool(SwitchboardConstants.DEBUG_SEARCH_REMOTE_SOLR_TESTLOCAL, false);
                         urls = Protocol.solrQuery(
                                         event,
                                         solrQuery,
                                         start,
                                         count,
-                                        localsearch ? event.peers.mySeed() : targetPeer,
+                                        targetPeer == null ? event.peers.mySeed() : targetPeer,
                                         partitions,
                                         blacklist);
                         if (urls >= 0) {
