@@ -35,7 +35,8 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.TreeMap;
+import java.util.Set;
+import java.util.TreeSet;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 
@@ -208,11 +209,7 @@ public final class SeedDB implements AlternativeDomainNames {
                 System.exit(-1);
             }
         }
-        if (Switchboard.getSwitchboard().isIntranetMode()) {
-            this.mySeed.setIP(Domains.myPublicLocalIP().getHostAddress()); // in intranet mode host address is best choice (to become senior peer)
-        } else {
-            this.mySeed.setIP("");// we delete the old information to see what we have now
-        }
+        this.mySeed.setIPs(Switchboard.getSwitchboard().myPublicIPs());
         this.mySeed.put(Seed.PEERTYPE, Seed.PEERTYPE_VIRGIN); // markup startup condition
     }
 
@@ -229,10 +226,6 @@ public final class SeedDB implements AlternativeDomainNames {
         if (this.mySeed == null) {
             if (sizeConnected() == 0) try {Thread.sleep(5000);} catch (final InterruptedException e) {} // wait for init
             initMySeed();
-            // check if my seed has an IP assigned
-            if (myIP() == null || myIP().isEmpty()) {
-                this.mySeed.setIP(Domains.myPublicLocalIP().getHostAddress());
-            }
         }
         return this.mySeed;
     }
@@ -246,10 +239,15 @@ public final class SeedDB implements AlternativeDomainNames {
         return mySeed().getName() + ".yacy";
     }
 
-    @Override
+    @Deprecated
     public String myIP() {
         return mySeed().getIP();
     }
+    
+    @Override
+    public Set<String> myIPs() {
+        return mySeed().getIPs();
+    }
 
     @Override
     public int myPort() {
@@ -349,7 +347,7 @@ public final class SeedDB implements AlternativeDomainNames {
         return new seedEnum(up, field, this.seedPotentialDB);
     }
 
-    public TreeMap<byte[], String> /* peer-b64-hashes/ipport */ clusterHashes(final String clusterdefinition) {
+    public TreeSet<byte[]> /* peer-b64-hashes/ipport */ clusterHashes(final String clusterdefinition) {
     	// collects seeds according to cluster definition string, which consists of
     	// comma-separated .yacy or .yacyh-domains
     	// the domain may be extended by an alternative address specification of the form
@@ -359,18 +357,16 @@ public final class SeedDB implements AlternativeDomainNames {
     	// address    ::= (<peername>'.yacy'|<peerhexhash>'.yacyh'){'='<ip>{':'<port}}
     	// clusterdef ::= {address}{','address}*
     	final String[] addresses = (clusterdefinition.isEmpty()) ? new String[0] : clusterdefinition.split(",");
-    	final TreeMap<byte[], String> clustermap = new TreeMap<byte[], String>(Base64Order.enhancedCoder);
+    	final TreeSet<byte[]> clustermap = new TreeSet<>(Base64Order.enhancedCoder);
     	Seed seed;
-    	String hash, yacydom, ipport;
+    	String hash, yacydom;
     	int p;
     	for (final String addresse : addresses) {
     		p = addresse.indexOf('=');
     		if (p >= 0) {
     			yacydom = addresse.substring(0, p);
-    			ipport  = addresse.substring(p + 1);
     		} else {
     			yacydom = addresse;
-    			ipport  = null;
     		}
     		if (yacydom.endsWith(".yacyh")) {
     			// find a peer with its hexhash
@@ -379,7 +375,7 @@ public final class SeedDB implements AlternativeDomainNames {
     			if (seed == null) {
     				Network.log.warn("cluster peer '" + yacydom + "' was not found.");
     			} else {
-    				clustermap.put(ASCII.getBytes(hash), ipport);
+    				clustermap.add(ASCII.getBytes(hash));
     			}
     		} else if (yacydom.endsWith(".yacy")) {
     			// find a peer with its name
@@ -387,7 +383,7 @@ public final class SeedDB implements AlternativeDomainNames {
     			if (seed == null) {
     				Network.log.warn("cluster peer '" + yacydom + "' was not found.");
     			} else {
-    				clustermap.put(ASCII.getBytes(seed.hash), ipport);
+    				clustermap.add(ASCII.getBytes(seed.hash));
     			}
     		} else {
     			Network.log.warn("cluster peer '" + addresse + "' has wrong syntax. the name must end with .yacy or .yacyh");
@@ -413,18 +409,18 @@ public final class SeedDB implements AlternativeDomainNames {
     }
 
     /**
-     * count the number of peers that had been seed within the time limit
-     * @param limit the time limit in minutes. 1440 minutes is a day
+     * count the number of peers that had been seen within the given time limit
+     * @param limitMinutes the time limit in minutes. 1440 minutes is a day
      * @return the number of peers seen in the given time
      */
-    public int sizeActiveSince(final long limit) {
+    public int sizeActiveSince(final long limitMinutes) {
         int c = this.seedActiveDB.size();
         Seed seed;
         Iterator<Seed> i = seedsSortedDisconnected(false, Seed.LASTSEEN);
         while (i.hasNext()) {
             seed = i.next();
             if (seed != null) {
-                if (Math.abs((System.currentTimeMillis() - seed.getLastSeenUTC()) / 1000 / 60) > limit) break;
+                if (Math.abs((System.currentTimeMillis() - seed.getLastSeenUTC()) / 1000 / 60) > limitMinutes) break;
                 c++;
             }
         }
@@ -432,7 +428,7 @@ public final class SeedDB implements AlternativeDomainNames {
         while (i.hasNext()) {
             seed = i.next();
             if (seed != null) {
-                if (Math.abs((System.currentTimeMillis() - seed.getLastSeenUTC()) / 1000 / 60) > limit) break;
+                if (Math.abs((System.currentTimeMillis() - seed.getLastSeenUTC()) / 1000 / 60) > limitMinutes) break;
                 c++;
             }
         }
@@ -459,7 +455,7 @@ public final class SeedDB implements AlternativeDomainNames {
     public long countPassiveRWI() { return this.seedPassiveDB.getLongAcc(Seed.ICOUNT); }
     public long countPotentialURL() { return this.seedPotentialDB.getLongAcc(Seed.LCOUNT); }
     public long countPotentialRWI() { return this.seedPotentialDB.getLongAcc(Seed.ICOUNT); }
-
+    
     public void addConnected(final Seed seed) {
         if (seed.isProper(false) != null) return;
         //seed.put(yacySeed.LASTSEEN, yacyCore.shortFormatter.format(new Date(yacyCore.universalTime())));
@@ -605,21 +601,41 @@ public final class SeedDB implements AlternativeDomainNames {
         return seed;
     }
 
-    public void update(final String hash, final Seed seed) {
-        if (this.mySeed == null) initMySeed();
-        if (hash.equals(this.mySeed.hash)) {
-            this.mySeed = seed;
-            return;
+    public void updateConnected(final Seed seed) {
+        if (seed.isProper(false) != null) return;
+        final ConcurrentMap<String, String> seedPropMap = seed.getMap();
+        synchronized (this) {
+            if (this.seedActiveDB.containsKey(ASCII.getBytes(seed.hash))) try {
+                this.seedActiveDB.insert(ASCII.getBytes(seed.hash), seedPropMap);
+            } catch (final Exception e) {
+                Network.log.severe("ERROR add: seed.db corrupt (" + e.getMessage() + "); resetting seed.db", e);
+                resetActiveTable();
+            }
+        }
+    }
+    public void updateDisconnected(final Seed seed) {
+        if (seed.isProper(false) != null) return;
+        final ConcurrentMap<String, String> seedPropMap = seed.getMap();
+        synchronized (this) {
+            if (this.seedPassiveDB.containsKey(ASCII.getBytes(seed.hash))) try {
+                this.seedPassiveDB.insert(ASCII.getBytes(seed.hash), seedPropMap);
+            } catch (final Exception e) {
+                Network.log.severe("ERROR add: seed.db corrupt (" + e.getMessage() + "); resetting seed.db", e);
+                resetActiveTable();
+            }
+        }
+    }
+    public void updatePotential(final Seed seed) {
+        if (seed.isProper(false) != null) return;
+        final ConcurrentMap<String, String> seedPropMap = seed.getMap();
+        synchronized (this) {
+            if (this.seedPotentialDB.containsKey(ASCII.getBytes(seed.hash))) try {
+                this.seedPotentialDB.insert(ASCII.getBytes(seed.hash), seedPropMap);
+            } catch (final Exception e) {
+                Network.log.severe("ERROR add: seed.db corrupt (" + e.getMessage() + "); resetting seed.db", e);
+                resetActiveTable();
+            }
         }
-        final byte[] hashb = ASCII.getBytes(hash);
-        Seed s = get(hash, this.seedActiveDB);
-        if (s != null) try { this.seedActiveDB.insert(hashb, seed.getMap()); return;} catch (final Exception e) {ConcurrentLog.logException(e);}
-
-        s = get(hash, this.seedPassiveDB);
-        if (s != null) try { this.seedPassiveDB.insert(hashb, seed.getMap()); return;} catch (final Exception e) {ConcurrentLog.logException(e);}
-
-        s = get(hash, this.seedPotentialDB);
-        if (s != null) try { this.seedPotentialDB.insert(hashb, seed.getMap()); return;} catch (final Exception e) {ConcurrentLog.logException(e);}
     }
 
     public Seed lookupByName(String peerName) {
@@ -666,6 +682,20 @@ public final class SeedDB implements AlternativeDomainNames {
         return null;
     }
 
+    public Seed lookupByIPs(
+            final Set<String> peerIPs,
+            final int port,                 /* port may be -1 if not significant */
+            final boolean lookupConnected,
+            final boolean lookupDisconnected,
+            final boolean lookupPotential
+    ) {
+        for (String i: peerIPs) {
+            Seed s = lookupByIP(Domains.dnsResolve(i), port, lookupConnected, lookupDisconnected, lookupPotential);
+            if (s != null) return s;
+        }
+        return null;
+    }
+    
     public Seed lookupByIP(
             final InetAddress peerIP,
             final int port,                 /* port may be -1 if not significant */
@@ -732,9 +762,7 @@ public final class SeedDB implements AlternativeDomainNames {
         }
 
         // check local seed
-        if (this.mySeed == null) return null;
-        String s = this.mySeed.getIP();
-        if (s == null || !ipString.equals(s)) return null;
+        if (this.mySeed == null || !this.mySeed.getIPs().contains(ipString)) return null;
         int p = this.mySeed.getPort();
         if (port > 0 && p != port) return null;
         //System.out.println("*** found lookupByIP as my seed: " + peerIP.toString() + " -> " + this.mySeed.getName());
@@ -838,7 +866,7 @@ public final class SeedDB implements AlternativeDomainNames {
         // Configure http headers
         final RequestHeader reqHeader = new RequestHeader();
         reqHeader.put(HeaderFramework.PRAGMA, "no-cache");
-        reqHeader.put(HeaderFramework.CACHE_CONTROL, "no-cache"); // httpc uses HTTP/1.0 is this necessary?
+        reqHeader.put(HeaderFramework.CACHE_CONTROL, "no-cache, no-store"); // httpc uses HTTP/1.0 is this necessary?
         reqHeader.put(HeaderFramework.USER_AGENT, ClientIdentification.yacyInternetCrawlerAgent.userAgent);
 
         final HTTPClient client = new HTTPClient(ClientIdentification.yacyInternetCrawlerAgent);
@@ -915,7 +943,7 @@ public final class SeedDB implements AlternativeDomainNames {
                     seed = this.mySeed;
                 else return null;
             }
-            return seed.getPublicAddress() + ((subdom == null) ? "" : ("/" + subdom));
+            return seed.getPublicAddress(seed.getIP()) + ((subdom == null) ? "" : ("/" + subdom));
         } else if (host.endsWith(".yacy")) {
             // identify subdomain
             p = host.indexOf('.');
@@ -928,30 +956,16 @@ public final class SeedDB implements AlternativeDomainNames {
             seed = lookupByName(domain);
             if (seed == null) return null;
             if (this.mySeed == null) initMySeed();
-            if ((seed == this.mySeed) && (!(seed.isOnline()))) {
+            if (seed == this.mySeed && !(seed.isOnline())) {
                 // take local ip instead of external
-                return Switchboard.getSwitchboard().myPublicIP() + ":" + Switchboard.getSwitchboard().getConfig("port", "8090") + ((subdom == null) ? "" : ("/" + subdom));
+                return Switchboard.getSwitchboard().myPublicIP() + ":" + Switchboard.getSwitchboard().getLocalPort("port", 8090) + ((subdom == null) ? "" : ("/" + subdom));
             }
-            return seed.getPublicAddress() + ((subdom == null) ? "" : ("/" + subdom));
+            return seed.getPublicAddress(seed.getIP()) + ((subdom == null) ? "" : ("/" + subdom));
         } else {
             return null;
         }
     }
 
-    public String targetAddress(final String targetHash) {
-        // find target address
-        String address;
-        if (targetHash.equals(mySeed().hash)) {
-            address = mySeed().getClusterAddress();
-        } else {
-            final Seed targetSeed = getConnected(targetHash);
-            if (targetSeed == null) { return null; }
-            address = targetSeed.getClusterAddress();
-        }
-        if (address == null) address = "localhost" + (this.mySeed.getPort() > 0 ? ":" + this.mySeed.getPort() : "");
-        return address;
-    }
-
     private class seedEnum implements Iterator<Seed> {
 
         private Iterator<Map.Entry<byte[], Map<String, String>>> it;
