@@ -156,6 +156,17 @@ public final class SwitchboardConstants {
     public static final String SEARCHRESULT_METHOD_START         = "searchresultProcess";
     public static final String SEARCHRESULT_METHOD_JOBCOUNT      = "searchresultQueueSize";
     public static final String SEARCHRESULT_METHOD_FREEMEM       = "searchresultFreeMem";
+    // 85_scheduler
+    /**
+     * <p><code>public static final String <strong>SCHEDULER</strong> = "85_scheduler"</code></p>
+     * <p>The cleanup thread which is responsible for the start of scheduled processes from the API table</p>
+     */
+    public static final String SCHEDULER                    = "85_scheduler";
+    public static final String SCHEDULER_METHOD_START       = "schedulerJob";
+    public static final String SCHEDULER_METHOD_JOBCOUNT    = "schedulerJobSize";
+    public static final String SCHEDULER_METHOD_FREEMEM     = null;
+    public static final String SCHEDULER_IDLESLEEP          = "85_scheduler_idlesleep";
+    public static final String SCHEDULER_BUSYSLEEP          = "85_scheduler_busysleep";
     // 90_cleanup
     /**
      * <p><code>public static final String <strong>CLEANUP</strong> = "90_cleanup"</code></p>
@@ -273,6 +284,8 @@ public final class SwitchboardConstants {
     public static final String INDEX_TRANSFER_GZIP_BODY         = "indexTransfer.gzipBody";
     public static final String PARSER_MIME_DENY                 = "parser.mime.deny";
     public static final String PARSER_EXTENSIONS_DENY           = "parser.extensions.deny";
+    public static final String PARSER_PDF_INDIVIDUALPAGES       = "parser.pdf.individualpages";
+    public static final String PARSER_PDF_INDIVIDUALPAGES_KEY   = "parser.pdf.individualpages.key";
     /**
      * <p><code>public static final String <strong>PROXY_ONLINE_CAUTION_DELAY</strong> = "onlineCautionDelay"</code></p>
      * <p>Name of the setting how long indexing should pause after the last time the proxy was used in milliseconds</p>
@@ -318,6 +331,8 @@ public final class SwitchboardConstants {
     public static final String REMOTESEARCH_MAXCOUNT_USER       = "remotesearch.maxcount";
     public static final String REMOTESEARCH_MAXTIME_USER        = "remotesearch.maxtime";
 
+    public static final String REMOTESEARCH_RESULT_STORE        = "remotesearch.result.store"; // add remote results to local index
+
     public static final String FEDERATED_SERVICE_SOLR_INDEXING_ENABLED      = "federated.service.solr.indexing.enabled";
     public static final String FEDERATED_SERVICE_SOLR_INDEXING_URL          = "federated.service.solr.indexing.url";
     public static final String FEDERATED_SERVICE_SOLR_INDEXING_SHARDING     = "federated.service.solr.indexing.sharding";
@@ -554,4 +569,11 @@ public final class SwitchboardConstants {
      * Skins
      */
     public static final String SKINS_PATH_DEFAULT                  = "DATA/SKINS";
+    
+    /*
+     * decorations
+     */
+    public static final String DECORATION_AUDIO                    = "decoration.audio";
+    public static final String DECORATION_GRAFICS_LINKSTRUCTURE    = "decoration.grafics.linkstructure";
+    
 }
