@@ -59,10 +59,13 @@ import net.yacy.cora.util.ByteBuffer;
 import net.yacy.cora.util.ConcurrentLog;
 import net.yacy.cora.util.LookAheadIterator;
 import net.yacy.cora.util.SpaceExceededException;
+import net.yacy.crawler.data.CrawlProfile;
+import net.yacy.crawler.data.Transactions;
 import net.yacy.crawler.retrieval.Response;
 import net.yacy.document.Condenser;
 import net.yacy.document.Document;
 import net.yacy.document.Parser;
+import net.yacy.document.parser.htmlParser;
 import net.yacy.kelondro.data.citation.CitationReference;
 import net.yacy.kelondro.data.citation.CitationReferenceFactory;
 import net.yacy.kelondro.data.word.Word;
@@ -73,6 +76,7 @@ import net.yacy.kelondro.index.RowHandleSet;
 import net.yacy.kelondro.rwi.IndexCell;
 import net.yacy.kelondro.rwi.ReferenceContainer;
 import net.yacy.kelondro.rwi.ReferenceFactory;
+import net.yacy.kelondro.table.IndexTable;
 import net.yacy.kelondro.util.Bitfield;
 import net.yacy.kelondro.util.ISO639;
 import net.yacy.kelondro.util.MemoryControl;
@@ -103,6 +107,7 @@ public class Segment {
     public static final int  writeBufferSize = 4 * 1024 * 1024;
     public static final String termIndexName = "text.index";
     public static final String citationIndexName = "citation.index";
+    public static final String firstseenIndexName = "firstseen.index";
 
     // the reference factory
     public static final ReferenceFactory<WordReference> wordReferenceFactory = new WordReferenceFactory();
@@ -114,15 +119,17 @@ public class Segment {
     protected final Fulltext                       fulltext;
     protected       IndexCell<WordReference>       termIndex;
     protected       IndexCell<CitationReference>   urlCitationIndex;
+    protected       IndexTable                     firstSeenIndex;
 
     /**
      * create a new Segment
      * @param log
      * @param segmentPath that should be the path ponting to the directory "SEGMENT"
      * @param collectionSchema
+     * @throws IOException 
      */
     public Segment(final ConcurrentLog log, final File segmentPath, final File archivePath,
-            final CollectionConfiguration collectionConfiguration, final WebgraphConfiguration webgraphConfiguration) {
+            final CollectionConfiguration collectionConfiguration, final WebgraphConfiguration webgraphConfiguration) throws IOException {
         log.info("Initializing Segment '" + segmentPath + ".");
         this.log = log;
         this.segmentPath = segmentPath;
@@ -132,6 +139,7 @@ public class Segment {
         this.fulltext = new Fulltext(segmentPath, archivePath, collectionConfiguration, webgraphConfiguration);
         this.termIndex = null;
         this.urlCitationIndex = null;
+        this.firstSeenIndex = new IndexTable(new File(segmentPath, firstseenIndexName), 12, 8, false, false);
     }
     
     public boolean connectedRWI() {
@@ -202,6 +210,10 @@ public class Segment {
         return this.urlCitationIndex;
     }
     
+    public IndexTable firstSeen() {
+        return this.firstSeenIndex;
+    }
+    
     public ReferenceReportCache getReferenceReportCache()  {
         return new ReferenceReportCache();
     }
@@ -266,7 +278,7 @@ public class Segment {
             if ((internalIDs.size() == 0 || !connectedCitation()) && Segment.this.fulltext.useWebgraph()) {
                 // reqd the references from the webgraph
                 SolrConnector webgraph = Segment.this.fulltext.getWebgraphConnector();
-                BlockingQueue<SolrDocument> docs = webgraph.concurrentDocumentsByQuery("{!raw f=" + WebgraphSchema.target_id_s.getSolrFieldName() + "}" + ASCII.String(id), WebgraphSchema.source_chars_i.getSolrFieldName() + " asc", 0, 10000000, Long.MAX_VALUE, 100, 1, WebgraphSchema.source_id_s.getSolrFieldName());
+                BlockingQueue<SolrDocument> docs = webgraph.concurrentDocumentsByQuery("{!cache=false raw f=" + WebgraphSchema.target_id_s.getSolrFieldName() + "}" + ASCII.String(id), WebgraphSchema.source_chars_i.getSolrFieldName() + " asc", 0, 10000000, Long.MAX_VALUE, 100, 1, false, WebgraphSchema.source_id_s.getSolrFieldName());
                 SolrDocument doc;
                 try {
                     while ((doc = docs.take()) != AbstractSolrConnector.POISON_DOCUMENT) {
@@ -350,6 +362,26 @@ public class Segment {
             return 0;
         }
     }
+    
+    public void setFirstSeenTime(final byte[] urlhash, long time) {
+        if (urlhash == null || time <= 0) return;
+        try {
+            if (this.firstSeenIndex.has(urlhash)) return; // NEVER overwrite, that is the purpose of this index.
+            this.firstSeenIndex.put(urlhash, time);
+        } catch (IOException e) {
+            ConcurrentLog.logException(e);
+        }
+    }
+    
+    public long getFirstSeenTime(final byte[] urlhash) {
+        if (urlhash == null) return -1;
+        try {
+            return this.firstSeenIndex.get(urlhash);
+        } catch (IOException e) {
+            ConcurrentLog.logException(e);
+            return -1;
+        }
+    }
 
     /**
      * get the load time of a resource.
@@ -369,7 +401,7 @@ public class Segment {
         final BlockingQueue<SolrDocument> docQueue;
         final String urlstub;
         if (stub == null) {
-            docQueue = this.fulltext.getDefaultConnector().concurrentDocumentsByQuery(AbstractSolrConnector.CATCHALL_QUERY, CollectionSchema.url_chars_i.getSolrFieldName() + " asc", 0, Integer.MAX_VALUE, maxtime, maxcount, 1, CollectionSchema.id.getSolrFieldName(), CollectionSchema.sku.getSolrFieldName());
+            docQueue = this.fulltext.getDefaultConnector().concurrentDocumentsByQuery(AbstractSolrConnector.CATCHALL_QUERY, CollectionSchema.url_chars_i.getSolrFieldName() + " asc", 0, Integer.MAX_VALUE, maxtime, maxcount, 1, false, CollectionSchema.id.getSolrFieldName(), CollectionSchema.sku.getSolrFieldName());
             urlstub = null;
         } else {
             final String host = stub.getHost();
@@ -379,7 +411,7 @@ public class Segment {
             } catch (MalformedURLException e) {
                 ConcurrentLog.logException(e);
             }
-            docQueue = hh == null ? new ArrayBlockingQueue<SolrDocument>(0) : this.fulltext.getDefaultConnector().concurrentDocumentsByQuery(CollectionSchema.host_id_s + ":\"" + hh + "\"", CollectionSchema.url_chars_i.getSolrFieldName() + " asc", 0, Integer.MAX_VALUE, maxtime, maxcount, 1, CollectionSchema.id.getSolrFieldName(), CollectionSchema.sku.getSolrFieldName());
+            docQueue = hh == null ? new ArrayBlockingQueue<SolrDocument>(0) : this.fulltext.getDefaultConnector().concurrentDocumentsByQuery(CollectionSchema.host_id_s + ":\"" + hh + "\"", CollectionSchema.url_chars_i.getSolrFieldName() + " asc", 0, Integer.MAX_VALUE, maxtime, maxcount, 1, false, CollectionSchema.id.getSolrFieldName(), CollectionSchema.sku.getSolrFieldName());
             urlstub = stub.toNormalform(true);
         }
 
@@ -435,6 +467,7 @@ public class Segment {
     	if (this.termIndex != null) this.termIndex.close();
         if (this.fulltext != null) this.fulltext.close();
         if (this.urlCitationIndex != null) this.urlCitationIndex.close();
+        if (this.firstSeenIndex != null) this.firstSeenIndex.close();
     }
 
     private static String votedLanguage(
@@ -507,17 +540,19 @@ public class Segment {
             final DigestURL url,
             final DigestURL referrerURL,
             final Map<String, Pattern> collections,
+            final CrawlProfile crawlProfile,
             final ResponseHeader responseHeader,
             final Document document,
             final Condenser condenser,
             final SearchEvent searchEvent,
             final String sourceName, // contains the crawl profile hash if this comes from a web crawl
-            final boolean storeToRWI
+            final boolean storeToRWI,
+            final String proxy,
+            final String acceptLanguage
             ) {
         final long startTime = System.currentTimeMillis();
         
         // CREATE INDEX
-
         // load some document metadata
         final Date loadDate = new Date();
         final String id = ASCII.String(url.hash());
@@ -533,15 +568,26 @@ public class Segment {
         
         // CREATE SOLR DOCUMENT
         final CollectionConfiguration collectionConfig = this.fulltext.getDefaultConfiguration();
-        final CollectionConfiguration.SolrVector vector = collectionConfig.yacy2solr(collections, responseHeader, document, condenser, referrerURL, language, this.fulltext().useWebgraph() ? this.fulltext.getWebgraphConfiguration() : null, sourceName);
+        final CollectionConfiguration.SolrVector vector = collectionConfig.yacy2solr(this, collections, responseHeader, document, condenser, referrerURL, language, crawlProfile.isPushCrawlProfile(), this.fulltext().useWebgraph() ? this.fulltext.getWebgraphConfiguration() : null, sourceName);
         
         // ENRICH DOCUMENT WITH RANKING INFORMATION
         this.fulltext.getDefaultConfiguration().postprocessing_references(this.getReferenceReportCache(), vector, url, null);
         
+        // CREATE SNAPSHOT
+        if ((url.getProtocol().equals("http") || url.getProtocol().equals("https")) &&
+                crawlProfile != null && document.getDepth() <= crawlProfile.snapshotMaxdepth()) {
+            // load pdf in case that is wanted. This can later be used to compute a web page preview in the search results
+            String ext = MultiProtocolURL.getFileExtension(url.getFile()).toLowerCase();
+            if (ext.length() == 0 || url.getFile().length() <= 1 || htmlParser.htmlExtensionsSet.contains(ext)) {
+                // STORE IMAGE AND METADATA
+                Transactions.store(vector, true, crawlProfile.snapshotLoadImage(), crawlProfile.snapshotReplaceold(), proxy, acceptLanguage);
+            }
+        }
+        
         // STORE TO SOLR
-        String error = null;
         this.putDocument(vector);
         List<SolrInputDocument> webgraph = vector.getWebgraphDocuments();
+        String error = null;
         if (webgraph != null && webgraph.size() > 0) {
             
             // write the edges to the webgraph solr index
@@ -563,6 +609,8 @@ public class Segment {
         
         }
         
+        // REMEMBER FIRST SEEN
+        setFirstSeenTime(url.hash(), Math.min(document.getLastModified().getTime(), System.currentTimeMillis())); // should exist already in the index at this time, but just to make sure
 
         // write the edges to the citation reference index
         if (this.connectedCitation()) try {
@@ -670,7 +718,7 @@ public class Segment {
         final long indexingEndTime = System.currentTimeMillis();
 
         if (this.log.isInfo()) {
-            this.log.info("*Indexed " + condenser.words().size() + " words in URL " + url +
+            this.log.info("*Indexed " + condenser.words().size() + " words in URL " + url.toNormalform(true) +
                     " [" + id + "]" +
                     "\n\tDescription:  " + dc_title +
                     "\n\tMimeType: "  + document.dc_format() + " | Charset: " + document.getCharset() + " | " +
@@ -713,7 +761,7 @@ public class Segment {
             }
             // get the word set
             Set<String> words = null;
-            words = new Condenser(document, true, true, null, null, false).words().keySet();
+            words = new Condenser(document, true, true, null, false, false).words().keySet();
 
             // delete all word references
             int count = 0;
