@@ -125,7 +125,6 @@ public final class QueryParams {
     public Seed remotepeer;
     public final long starttime; // the time when the query started, how long it should take and the time when the timeout is reached (milliseconds)
     protected final long maxtime;
-    private final long timeout;
     // values that are set after a search:
     public int transmitcount; // number of results that had been shown to the user
     public long searchtime, urlretrievaltime, snippetcomputationtime; // time to perform the search, to get all the urls, and to compute the snippets
@@ -213,7 +212,6 @@ public final class QueryParams {
         this.remotepeer = null;
         this.starttime = Long.valueOf(System.currentTimeMillis());
         this.maxtime = 10000;
-        this.timeout = this.starttime + this.timeout;
         this.indexSegment = indexSegment;
         this.userAgent = userAgent;
         this.transmitcount = 0;
@@ -232,7 +230,11 @@ public final class QueryParams {
             // handle special field, authors_sxt (add to facet w/o contains check, as authors_sxt is not enabled (is copyfield))
             if (f != null && (solrSchema.contains(f) || f.name().equals("author_sxt"))) this.facetfields.add(f.getSolrFieldName());
         }
-        for (Tagging v: LibraryProvider.autotagging.getVocabularies()) this.facetfields.add(CollectionSchema.VOCABULARY_PREFIX + v.getName() + CollectionSchema.VOCABULARY_SUFFIX);
+        if (LibraryProvider.autotagging != null) for (Tagging v: LibraryProvider.autotagging.getVocabularies()) {
+            if (v.isFacet()) {
+                this.facetfields.add(CollectionSchema.VOCABULARY_PREFIX + v.getName() + CollectionSchema.VOCABULARY_TERMS_SUFFIX);
+            }
+        }
         this.maxfacets = defaultmaxfacets;
         this.cachedQuery = null;
     }
@@ -460,7 +462,7 @@ public final class QueryParams {
         // add vocabulary facets
         if (this.metatags != null) {
             for (Tagging.Metatag tag : this.metatags) {
-                fq.append(" AND ").append(CollectionSchema.VOCABULARY_PREFIX).append(tag.getVocabularyName()).append(CollectionSchema.VOCABULARY_SUFFIX).append(":\"").append(tag.getObject()).append('\"');
+                fq.append(" AND ").append(CollectionSchema.VOCABULARY_PREFIX).append(tag.getVocabularyName()).append(CollectionSchema.VOCABULARY_TERMS_SUFFIX).append(":\"").append(tag.getObject()).append('\"');
             }
         }
 
@@ -479,6 +481,10 @@ public final class QueryParams {
             fq.append(" AND ").append(QueryModifier.parseCollectionExpression(this.modifier.collection));
         }
         
+        if (this.modifier.on != null && this.modifier.on.length() > 0 && this.solrSchema.contains(CollectionSchema.dates_in_content_sxt)) {
+            fq.append(" AND ").append(QueryModifier.parseOnExpression(this.modifier.on));
+        }
+        
         if (this.modifier.protocol != null) {
             fq.append(" AND {!tag=").append(CollectionSchema.url_protocol_s.getSolrFieldName()).append("}").append(CollectionSchema.url_protocol_s.getSolrFieldName()).append(':').append(this.modifier.protocol);
         }
@@ -586,6 +592,7 @@ public final class QueryParams {
             context.append(this.modifier.toString()).append(asterisk);
             context.append(this.siteexcludes).append(asterisk);
             context.append(this.targetlang).append(asterisk);
+            context.append(this.domType).append(asterisk);
             context.append(this.constraint).append(asterisk);
             context.append(this.maxDistance).append(asterisk);
             context.append(this.tld).append(asterisk);
