@@ -37,6 +37,7 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.SortedMap;
+import java.util.SortedSet;
 import java.util.TreeMap;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.ConcurrentHashMap;
@@ -131,7 +132,7 @@ public final class SearchEvent {
     public final List<RemoteSearch> primarySearchThreadsL;
     public final List<Thread> nodeSearchThreads;
     public Thread[] secondarySearchThreads;
-    public final SortedMap<byte[], String> preselectedPeerHashes;
+    public final SortedSet<byte[]> preselectedPeerHashes;
     private final SortedMap<byte[], Integer> IACount;
     private final SortedMap<byte[], String> IAResults;
     private final SortedMap<byte[], HeuristicResult> heuristics;
@@ -157,6 +158,7 @@ public final class SearchEvent {
     private long                                          snippetComputationAllTime;
     private ConcurrentHashMap<String, LinkedHashSet<String>> snippets;
     private final boolean remote;
+    public final boolean addResultsToLocalIndex; // add received results to local index (defult=true)
     private SortedMap<byte[], ReferenceContainer<WordReference>> localSearchInclusion;
     private final ScoreMap<String> ref; // reference score computation for the commonSense heuristic
     private final long maxtime;
@@ -198,12 +200,13 @@ public final class SearchEvent {
         final QueryParams query,
         final SeedDB peers,
         final WorkTables workTables,
-        final SortedMap<byte[], String> preselectedPeerHashes,
+        final SortedSet<byte[]> preselectedPeerHashes,
         final boolean generateAbstracts,
         final LoaderDispatcher loader,
         final int remote_maxcount,
         final long remote_maxtime,
-        final boolean deleteIfSnippetFail) {
+        final boolean deleteIfSnippetFail,
+        final boolean addResultsToLocalIdx) {
 
         long ab = MemoryControl.available();
         if (ab < 1024 * 1024 * 200) {
@@ -242,7 +245,7 @@ public final class SearchEvent {
         this.filetypeNavigator = navcfg.contains("filetype") ? new ConcurrentScoreMap<String>() : null;
         this.topicNavigatorCount = navcfg.contains("topics") ? MAX_TOPWORDS : 0;
         this.languageNavigator = navcfg.contains("language") ? new ConcurrentScoreMap<String>() : null;
-        this.vocabularyNavigator = new ConcurrentHashMap<String, ScoreMap<String>>();
+        this.vocabularyNavigator = new TreeMap<String, ScoreMap<String>>();
         this.snippets = new ConcurrentHashMap<String, LinkedHashSet<String>>(); 
         this.secondarySearchSuperviser = (this.query.getQueryGoal().getIncludeHashes().size() > 1) ? new SecondarySearchSuperviser(this) : null; // generate abstracts only for combined searches
         if (this.secondarySearchSuperviser != null) this.secondarySearchSuperviser.start();
@@ -254,6 +257,7 @@ public final class SearchEvent {
         this.IAmaxcounthash = null;
         this.IAneardhthash = null;
         this.remote = (peers != null && peers.sizeConnected() > 0) && (this.query.domType == QueryParams.Searchdom.CLUSTER || (this.query.domType == QueryParams.Searchdom.GLOBAL && Switchboard.getSwitchboard().getConfigBool(SwitchboardConstants.INDEX_RECEIVE_ALLOW_SEARCH, false)));
+        this.addResultsToLocalIndex = addResultsToLocalIdx;
         this.local_rwi_available  = new AtomicInteger(0); // the number of results in the local peer after filtering
         this.local_rwi_stored     = new AtomicInteger(0);
         this.local_solr_available = new AtomicInteger(0);
@@ -303,7 +307,7 @@ public final class SearchEvent {
         this.rwiProcess = null;
         if (query.getSegment().connectedRWI() && !Switchboard.getSwitchboard().getConfigBool(SwitchboardConstants.DEBUG_SEARCH_LOCAL_DHT_OFF, false)) {
             // we start the local search only if this peer is doing a remote search or when it is doing a local search and the peer is old
-            rwiProcess = new RWIProcess();
+            rwiProcess = new RWIProcess(this.localsolrsearch);
             rwiProcess.start();
         }
 
@@ -432,8 +436,11 @@ public final class SearchEvent {
 
     private class RWIProcess extends Thread {
     
-        public RWIProcess() {
+        final Thread waitForThread;
+        
+        public RWIProcess(final Thread waitForThread) {
             super();
+            this.waitForThread = waitForThread;
         }
         
         @Override
@@ -461,6 +468,12 @@ public final class SearchEvent {
                 SearchEvent.this.localSearchInclusion = search.inclusion();
                 ReferenceContainer<WordReference> index = search.joined();
                 if ( !index.isEmpty() ) {
+                    // in case that another thread has priority for their results, wait until this is finished
+                    if (this.waitForThread != null && this.waitForThread.isAlive()) {
+                        this.waitForThread.join();
+                    }
+                    
+                    // add the index to the result
                     int successcount = addRWIs(index, true, "local index: " + SearchEvent.this.query.getSegment().getLocation(), index.size(), SearchEvent.this.maxtime);
                     if (successcount == 0 &&
                         SearchEvent.this.query.getQueryGoal().getIncludeHashes().has(Segment.catchallHash) &&
@@ -863,7 +876,7 @@ public final class SearchEvent {
         
         // get the vocabulary navigation
         for (Tagging v: LibraryProvider.autotagging.getVocabularies()) {
-            fcts = facets.get(CollectionSchema.VOCABULARY_PREFIX + v.getName() + CollectionSchema.VOCABULARY_SUFFIX);
+            fcts = facets.get(CollectionSchema.VOCABULARY_PREFIX + v.getName() + CollectionSchema.VOCABULARY_TERMS_SUFFIX);
             if (fcts != null) {
                 ScoreMap<String> vocNav = this.vocabularyNavigator.get(v.getName());
                 if (vocNav == null) {
@@ -1071,7 +1084,12 @@ public final class SearchEvent {
                 //Log.logWarning("SearchEvent", "bestEntry == null (2)");
                 return null;
             }
-            URIMetadataNode node = this.query.getSegment().fulltext().getMetadata(bestEntry);
+            URIMetadataNode node = null;
+            try {
+                node = this.query.getSegment().fulltext().getMetadata(bestEntry);
+            } catch (Throwable e) {
+                ConcurrentLog.logException(e);
+            }
             if (node == null) {
                 if (bestEntry.getElement().local()) this.local_rwi_available.decrementAndGet(); else this.remote_rwi_available.decrementAndGet();
                 if (log.isFine()) log.fine("dropped RWI: hash not in metadata");
@@ -1221,7 +1239,7 @@ public final class SearchEvent {
                 tagloop: for (Tagging.Metatag tag : this.query.metatags) {
                     SolrDocument sdoc = page;
                     if (sdoc != null) {
-                        Collection<Object> tagvalues = sdoc.getFieldValues(CollectionSchema.VOCABULARY_PREFIX + tag.getVocabularyName() + CollectionSchema.VOCABULARY_SUFFIX);
+                        Collection<Object> tagvalues = sdoc.getFieldValues(CollectionSchema.VOCABULARY_PREFIX + tag.getVocabularyName() + CollectionSchema.VOCABULARY_TERMS_SUFFIX);
                         if (tagvalues != null && tagvalues.contains(tag.getObject())) {
                             continue tagloop; // metatag exists check next tag (filter may consist of several tags)                            
                         } 
@@ -1567,8 +1585,8 @@ public final class SearchEvent {
                 List<String> prt = CollectionConfiguration.indexedList2protocolList(doc.getFieldValues(CollectionSchema.images_protocol_sxt.getSolrFieldName()), img.size());
                 Collection<Object> heightO = doc.getFieldValues(CollectionSchema.images_height_val.getSolrFieldName());
                 Collection<Object> widthO = doc.getFieldValues(CollectionSchema.images_width_val.getSolrFieldName());
-                List<Object> height = heightO == null ? new ArrayList<Object>(img.size()) : (List<Object>) heightO;
-                List<Object> width = widthO == null ? new ArrayList<Object>(img.size()) : (List<Object>) widthO;
+                List<Object> height = heightO == null ? null : (List<Object>) heightO;
+                List<Object> width = widthO == null ? null : (List<Object>) widthO;
                 for (int c = 0; c < img.size(); c++) {
                     String image_urlstub =  (String) img.get(c);
                     if (image_urlstub.endsWith(".ico")) continue; // we don't want favicons, makes the result look idiotic
@@ -1576,8 +1594,8 @@ public final class SearchEvent {
                     boolean match = (query.getQueryGoal().matches(image_urlstub) || query.getQueryGoal().matches(image_alt));
                     try {
                         DigestURL imageUrl = new DigestURL((prt != null && prt.size() > c ? prt.get(c) : "http") + "://" + image_urlstub);
-                        Integer h = (Integer) height.get(c);
-                        Integer w = (Integer) width.get(c);
+                        Integer h = height == null ? null : (Integer) height.get(c);
+                        Integer w = width == null ? null : (Integer) width.get(c);
                         boolean sizeok = h != null && w != null && h.intValue() > 16 && w.intValue() > 16;
                         String id = ASCII.String(imageUrl.hash());
                         if (!imageViewed.containsKey(id) && !containsSpare(id)) {
@@ -1785,7 +1803,7 @@ public final class SearchEvent {
     protected void addTopics(final ResultEntry resultEntry) {
         // take out relevant information for reference computation
         if ((resultEntry.url() == null) || (resultEntry.title() == null)) return;
-        final String[] descrcomps = MultiProtocolURL.splitpattern.split(resultEntry.title().toLowerCase()); // words in the description
+        final String[] descrcomps = MultiProtocolURL.splitpattern.split(resultEntry.title()); // words in the description
 
         // add references
         addTopic(descrcomps);
