@@ -35,6 +35,10 @@ public enum CollectionSchema implements SchemaDeclaration {
     sku(SolrType.string, true, true, false, true, true, "url of document"), // a 'sku' is a stock-keeping unit, a unique identifier and a default field in unmodified solr.
     //sku(SolrType.text_en_splitting_tight, true, true, false, true, true, "url of document"), // a 'sku' is a stock-keeping unit, a unique identifier and a default field in unmodified solr.
     last_modified(SolrType.date, true, true, false, false, false, "last-modified from http header"),
+    dates_in_content_sxt(SolrType.string, true, true, true, false, true, "if date expressions can be found in the content, these dates are listed here in order of the appearances"),
+    dates_in_content_count_i(SolrType.num_integer, true, true, false, false, false, "the number of entries in dates_in_content_sxt"),
+    date_in_content_min_dt(SolrType.date, true, true, false, false, false, "if dates_in_content_sxt is filled, this contains the oldest date from the list of available dates"),
+    date_in_content_max_dt(SolrType.date, true, true, false, false, false, "if dates_in_content_sxt is filled, this contains the youngest date from the list of available dates, that may also be possibly in the future"),
     content_type(SolrType.string, true, true, true, false, false, "mime-type of document"),
     http_unique_b(SolrType.bool, true, true, false, false, false, "unique-field which is true when an url appears the first time. If the same url which was http then appears as https (or vice versa) then the field is false"),
     www_unique_b(SolrType.bool, true, true, false, false, false, "unique-field which is true when an url appears the first time. If the same url within the subdomain www then appears without that subdomain (or vice versa) then the field is false"),
@@ -54,7 +58,7 @@ public enum CollectionSchema implements SchemaDeclaration {
     failreason_s(SolrType.string, true, true, false, false, false, "fail reason if a page was not loaded. if the page was loaded then this field is empty"),
     failtype_s(SolrType.string, true, true, false, false, false, "fail type if a page was not loaded. This field is either empty, 'excl' or 'fail'"),
     httpstatus_i(SolrType.num_integer, true, true, false, false, false, "html status return code (i.e. \"200\" for ok), -1 if not loaded"),
-    httpstatus_redirect_s(SolrType.num_integer, true, true, false, false, false, "html status return code (i.e. \"200\" for ok), -1 if not loaded"),
+/**/httpstatus_redirect_s(SolrType.string, true, true, false, false, false, "redirect url if the error code is 299 < httpstatus_i < 310"), // TODO: delete candidate, not used so far (2014-12-26)
     references_i(SolrType.num_integer, true, true, false, false, false, "number of unique http references, should be equal to references_internal_i + references_external_i"),
     references_internal_i(SolrType.num_integer, true, true, false, false, false, "number of unique http references from same host to referenced url"),
     references_external_i(SolrType.num_integer, true, true, false, false, false, "number of unique http references from external hosts"),
@@ -111,15 +115,21 @@ public enum CollectionSchema implements SchemaDeclaration {
     scripts_sxt(SolrType.string, true, true, true, false, false, "normalized urls within a scripts tag"),
     scriptscount_i(SolrType.num_integer, true, true, false, false, false, "number of entries in scripts_sxt"),
     // encoded as binary value into an integer:
-    // bit  0: "all" contained in html header meta
-    // bit  1: "index" contained in html header meta
-    // bit  2: "noindex" contained in html header meta
-    // bit  3: "nofollow" contained in html header meta
-    // bit  8: "noarchive" contained in http header properties
-    // bit  9: "nosnippet" contained in http header properties
-    // bit 10: "noindex" contained in http header properties
-    // bit 11: "nofollow" contained in http header properties
-    // bit 12: "unavailable_after" contained in http header properties
+            // bit  0: "all" contained in html header meta
+            // bit  1: "index" contained in html header meta
+            // bit  2: "follow" contained in html header meta
+            // bit  3: "noindex" contained in html header meta
+            // bit  4: "nofollow" contained in html header meta
+            // bit  5: "noarchive" contained in html header meta
+            // bit  8: "all" contained in http header X-Robots-Tag
+            // bit  9: "noindex" contained in http header X-Robots-Tag
+            // bit 10: "nofollow" contained in http header X-Robots-Tag
+            // bit 11: "noarchive" contained in http header X-Robots-Tag
+            // bit 12: "nosnippet" contained in http header X-Robots-Tag
+            // bit 13: "noodp" contained in http header X-Robots-Tag
+            // bit 14: "notranslate" contained in http header X-Robots-Tag
+            // bit 15: "noimageindex" contained in http header X-Robots-Tag
+            // bit 16: "unavailable_after" contained in http header X-Robots-Tag
     robots_i(SolrType.num_integer, true, true, false, false, false, "content of <meta name=\"robots\" content=#content#> tag and the \"X-Robots-Tag\" HTTP property"),
     metagenerator_t(SolrType.text_general, true, true, false, false, false, "content of <meta name=\"generator\" content=#content#> tag"),
     inboundlinks_protocol_sxt(SolrType.string, true, true, true, false, false, "internal links, only the protocol"),
@@ -165,6 +175,7 @@ public enum CollectionSchema implements SchemaDeclaration {
     url_file_name_s(SolrType.string, true, true, false, false, true, "the file name (which is the string after the last '/' and before the query part from '?' on) without the file extension"),
     url_file_name_tokens_t(SolrType.text_general, true, true, false, false, true, "tokens generated from url_file_name_s which can be used for better matching and result boosting"),
     url_file_ext_s(SolrType.string, true, true, false, false, true, "the file name extension"),
+    url_paths_count_i(SolrType.num_integer, true, true, false, false, false, "number of all path elements in the url hpath (see: http://www.ietf.org/rfc/rfc1738.txt) without the file name"),
     url_paths_sxt(SolrType.string, true, true, true, false, true, "all path elements in the url hpath (see: http://www.ietf.org/rfc/rfc1738.txt) without the file name"),
     url_parameter_i(SolrType.num_integer, true, true, false, false, false, "number of key-value pairs in search part of the url"),
     url_parameter_key_sxt(SolrType.string, true, true, true, false, false, "the keys from key-value pairs in the search part of the url"),
@@ -222,12 +233,16 @@ public enum CollectionSchema implements SchemaDeclaration {
     ext_tracker_txt(SolrType.text_general, true, true, true, false, false, "names of tracker server"),
     ext_tracker_val(SolrType.num_integer, true, true, true, false, false, "number of attribute counts in ext_tracker_txt"),
     ext_title_txt(SolrType.text_general, true, true, true, false, false, "names matching title expressions"),
-    ext_title_val(SolrType.num_integer, true, true, true, false, false, "number of matching title expressions");
-
-    public final static String CORE_NAME = "collection1"; // this was the default core name up to Solr 4.4.0. This default name was stored in CoreContainer.DEFAULT_DEFAULT_CORE_NAME but was removed in Solr 4.5.0
+    ext_title_val(SolrType.num_integer, true, true, true, false, false, "number of matching title expressions"),
+    vocabularies_sxt(SolrType.string, true, true, true, false, false, "collection of all vocabulary names that have a matcher in the document - use this to boost with vocabularies");
     
-    public final static String VOCABULARY_PREFIX = "vocabulary_";
-    public final static String VOCABULARY_SUFFIX = "_sxt";
+    public final static String CORE_NAME = "collection1"; // this was the default core name up to Solr 4.4.0. This default name was stored in CoreContainer.DEFAULT_DEFAULT_CORE_NAME but was removed in Solr 4.5.0
+
+    public final static String VOCABULARY_PREFIX = "vocabulary_"; // collects all terms that appear for each vocabulary
+    public final static String VOCABULARY_TERMS_SUFFIX = "_sxt"; // suffix for the term collector that start with VOCABULARY_PREFIX - middle part is vocabulary name
+    public final static String VOCABULARY_COUNT_SUFFIX = "_i"; // suffix for the term counter (>=1) that start with VOCABULARY_PREFIX - middle part is vocabulary name
+    public final static String VOCABULARY_LOGCOUNT_SUFFIX = "_log_i"; // log2(VOCABULARY_COUNT)] -- can be used for ranking boosts based on the number of occurrences
+    public final static String VOCABULARY_LOGCOUNTS_SUFFIX = "_log_val"; // all integers from [0 to log2(VOCABULARY_COUNT)] -- can be used for ranking boosts based on the number of occurrences
     
     private String solrFieldName = null; // solr field name in custom solr schema, defaults to solcell schema field name (= same as this.name() )
     private final SolrType type;
