@@ -26,7 +26,6 @@ package net.yacy.search.snippet;
 
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.Comparator;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -48,7 +47,6 @@ import net.yacy.crawler.retrieval.Request;
 import net.yacy.crawler.retrieval.Response;
 import net.yacy.document.Document;
 import net.yacy.document.Parser;
-import net.yacy.document.SentenceReader;
 import net.yacy.document.SnippetExtractor;
 import net.yacy.document.WordTokenizer;
 import net.yacy.document.parser.html.CharacterCoding;
@@ -537,7 +535,7 @@ public class TextSnippet implements Comparable<TextSnippet>, Comparator<TextSnip
 
     private static void removeMatchingHashes(final String sentence, final HandleSet queryhashes) {
         if (queryhashes.size() == 0) return;
-        final Set<byte[]> m = WordTokenizer.hashSentence(sentence, null, 100).keySet();
+        final Set<byte[]> m = WordTokenizer.hashSentence(sentence, 100).keySet();
         //for (byte[] b: m) System.out.println("sentence hash: " + ASCII.String(b));
         //for (byte[] b: queryhashes) System.out.println("queryhash: " + ASCII.String(b));
         ArrayList<byte[]> o = new ArrayList<byte[]>(queryhashes.size());
