@@ -66,6 +66,7 @@ import java.util.logging.FileHandler;
 import java.util.logging.Level;
 import java.util.logging.LogManager;
 import java.util.logging.Logger;
+import javax.servlet.http.HttpServletResponse;
 
 import net.yacy.cora.document.id.DigestURL;
 import net.yacy.cora.protocol.ClientIdentification;
@@ -79,14 +80,11 @@ import net.yacy.crawler.data.Cache;
 import net.yacy.crawler.retrieval.Request;
 import net.yacy.crawler.retrieval.Response;
 import net.yacy.document.TextParser;
-import net.yacy.document.parser.html.ContentTransformer;
-import net.yacy.document.parser.html.Transformer;
 import net.yacy.kelondro.io.ByteCountOutputStream;
 import net.yacy.kelondro.util.FileUtils;
 import net.yacy.peers.operation.yacyBuildProperties;
 import net.yacy.repository.Blacklist.BlacklistType;
 import net.yacy.search.Switchboard;
-import net.yacy.search.SwitchboardConstants;
 import net.yacy.server.serverObjects;
 
 public final class HTTPDProxyHandler {
@@ -104,8 +102,6 @@ public final class HTTPDProxyHandler {
     private static PrintWriter redirectorWriter = null;
     private static BufferedReader redirectorReader = null;
 
-    private static Transformer transformer = null;
-
     //private Properties connectionProperties = null;
     // creating a logger
     private static final ConcurrentLog log = new ConcurrentLog("PROXY");
@@ -168,10 +164,6 @@ public final class HTTPDProxyHandler {
             log.severe("Unable to configure proxy access logging.",e);
         }
 
-        // load a transformer
-        transformer = new ContentTransformer();
-        transformer.init(new File(sb.getAppPath(), sb.getConfig(SwitchboardConstants.LIST_BLUE, "")).toString());
-
         // load the yellow-list
         final String f = sb.getConfig("proxyYellowList", null);
         if (f != null) {
@@ -366,8 +358,6 @@ public final class HTTPDProxyHandler {
                         "",
                         cachedResponseHeader.lastModified(),
                         sb.crawler.defaultProxyProfile.handle(),
-                        0,
-                        0,
                         0);
                 final Response response = new Response(
                 		request,
@@ -423,13 +413,8 @@ public final class HTTPDProxyHandler {
             final String ip =      (String) conProp.get(HeaderFramework.CONNECTION_PROP_CLIENTIP); // the ip from the connecting peer
             final String httpVer = (String) conProp.get(HeaderFramework.CONNECTION_PROP_HTTP_VER); // the ip from the connecting peer
 
-            int port, pos;
-            if ((pos = host.indexOf(':')) < 0) {
-                port = 80;
-            } else {
-                port = Integer.parseInt(host.substring(pos + 1));
-                host = host.substring(0, pos);
-            }
+            int port = Domains.stripToPort(host);
+            host = Domains.stripToHostName(host);
 
             // resolve yacy and yacyh domains
             String yAddress = resolveYacyDomains(host);
@@ -438,10 +423,10 @@ public final class HTTPDProxyHandler {
             final String remotePath = (args == null) ? path : (path + "?" + args); // with leading '/'
 
             // remove yacy-subdomain-path, when accessing /env
-            if ( (yAddress != null)
+            if ((yAddress != null)
             		&& (remotePath.startsWith("/env"))
-            		&& ((pos = yAddress.indexOf('/')) != -1)
-            ) yAddress = yAddress.substring(0, yAddress.indexOf('/'));
+            		&& (yAddress.indexOf('/') != -1)
+               ) yAddress = yAddress.substring(0, yAddress.indexOf('/'));
 
             modifyProxyHeaders(requestHeader, httpVer);
 
@@ -488,8 +473,6 @@ public final class HTTPDProxyHandler {
                         "",
                         responseHeader.lastModified(),
                         sb.crawler.defaultProxyProfile.handle(),
-                        0,
-                        0,
                         0);
 
 
@@ -590,8 +573,9 @@ public final class HTTPDProxyHandler {
                                 " StoreHTCache=" + storeHTCache +
                                 " SupportError=" + supportError);
 
-//                        FileUtils.copy(res.getDataAsStream(), outStream);
-                        client.writeTo(outStream);
+                        if (statusCode == HttpServletResponse.SC_OK) { // continue to serve header to client e.g. HttpStatus = 302 (while skiping content)
+                            client.writeTo(outStream); // may throw exception on httpStatus=302 while gzip encoded inputstream
+                        }
 
                         conProp.put(HeaderFramework.CONNECTION_PROP_PROXY_RESPOND_CODE,"TCP_MISS");
                     }
@@ -1050,11 +1034,8 @@ public final class HTTPDProxyHandler {
         String orgHostName = (String) conProp.get(HeaderFramework.CONNECTION_PROP_HOST);
         if (orgHostName == null) orgHostName = "unknown";
         orgHostName = orgHostName.toLowerCase();
-        int pos = orgHostName.indexOf(':');
-        if (pos != -1) {
-            orgHostPort = orgHostName.substring(pos+1);
-            orgHostName = orgHostName.substring(0,pos);
-        }
+        orgHostPort = Integer.toString(Domains.stripToPort(orgHostName));
+        orgHostName = Domains.stripToHostName(orgHostName);
         String orgHostPath = (String) conProp.get(HeaderFramework.CONNECTION_PROP_PATH); if (orgHostPath == null) orgHostPath = "";
         String orgHostArgs = (String) conProp.get(HeaderFramework.CONNECTION_PROP_ARGS); if (orgHostArgs == null) orgHostArgs = "";
         if (orgHostArgs.length() > 0) orgHostArgs = "?" + orgHostArgs;
@@ -1070,22 +1051,22 @@ public final class HTTPDProxyHandler {
         } else if (orgHostName.startsWith("www.")) {
             testHostName = orgHostName.substring(4);
             final InetAddress addr = Domains.dnsResolve(testHostName);
-            if (addr != null) if (addr != null) testHostNames.add(testHostName);
+            if (addr != null) testHostNames.add(testHostName);
         }
         if (orgHostName.length()>4 && orgHostName.startsWith("www") && (orgHostName.charAt(3) != '.')) {
             testHostName = orgHostName.substring(0,3) + "." + orgHostName.substring(3);
             final InetAddress addr = Domains.dnsResolve(testHostName);
-            if (addr != null) if (addr != null) testHostNames.add(testHostName);
+            if (addr != null) testHostNames.add(testHostName);
         }
 
-        pos = orgHostName.lastIndexOf('.');
+        int pos = orgHostName.lastIndexOf('.');
         if (pos != -1) {
             final Iterator<String> iter = topLevelDomains.iterator();
             while (iter.hasNext()) {
                 final String topLevelDomain = iter.next();
                 testHostName = orgHostName.substring(0,pos) + "." + topLevelDomain;
                 final InetAddress addr = Domains.dnsResolve(testHostName);
-                if (addr != null) if (addr != null) testHostNames.add(testHostName);
+                if (addr != null) testHostNames.add(testHostName);
             }
         }
 
