@@ -135,8 +135,23 @@ public final class yacy {
             // check java version
             try {
                 "a".isEmpty(); // needs at least Java 1.6
+
+                // check java version string (required min 1.7)
+                final String javaVersion = System.getProperty("java.version");
+                if (javaVersion != null) { // unknown property !?
+                    int pos = javaVersion.indexOf('.');
+                    int count = 1;
+                    for (; pos < javaVersion.length() && count < 2; pos++) {
+                        if (javaVersion.charAt(pos + 1) == '.') count++;
+                    }
+                    Double dVersion = Double.parseDouble(javaVersion.substring(0, pos));
+                    if (dVersion < 1.7) { // required min java 1.7
+                        System.err.println("STARTUP: Java Version too low. You need at least Java 1.7 to run YaCy");
+                        System.exit(-1);
+                    }
+                }
             } catch (final NoSuchMethodError e) {
-                System.err.println("STARTUP: Java Version too low. You need at least Java 1.6 to run YaCy");
+                System.err.println("STARTUP: Java Version too low. You need at least Java 1.7 to run YaCy");
                 System.exit(-1);
             }
 
@@ -202,7 +217,7 @@ public final class yacy {
             sb.setConfig("memoryTotalAfterStartup", startupMemTotal);
 
             // start gui if wanted
-            if (gui) YaCyApp.start("localhost", (int) sb.getConfigLong("port", 8090));
+            if (gui) YaCyApp.start("localhost", sb.getLocalPort("port", 8090));
 
             // hardcoded, forced, temporary value-migration
             sb.setConfig("htTemplatePath", "htroot/env/templates");
@@ -277,7 +292,7 @@ public final class yacy {
             HTTPClient.setDefaultUserAgent(ClientIdentification.yacyInternetCrawlerAgent.userAgent);
 
             // start main threads
-            final int port = sb.getConfigInt("port", 8090);
+            final int port = sb.getLocalPort("port", 8090);
             try {
                 // start http server
             	YaCyHttpServer httpServer;
@@ -530,7 +545,7 @@ public final class yacy {
                 p.load(fis);
                 fis.close();
                 // Test for server access restriction (is implemented using Jetty IPaccessHandler which does not support IPv6
-                // try to disavle IPv6 
+                // try to disable IPv6 
                 String teststr = p.getProperty("serverClient", "*");
                 if (!teststr.equals("*")) {
                     // testing on Win-8 showed this property has to be set befor Switchboard starts 
@@ -559,15 +574,16 @@ public final class yacy {
                         delete(lockFile);
                     }                                
                 }
-            } catch (Throwable ex) {
+            } catch (IOException ex) {
+                System.err.println("ERROR: config file seems to be corrupt");
+                System.err.println("ERROR: if problem persists, delete file");
+                System.err.println(configFile.getAbsolutePath());
                 ConcurrentLog.logException(ex);
-                ConcurrentLog.severe("Startup", "cannot read " + configFile.toString() + ", removing old file");
-                configFile.delete();
+                ConcurrentLog.severe("Startup", "cannot read " + configFile.toString() + ", please delete the corrupted file if problem persits");
             }
         }
     }     
 
-    
     /**
      * Main-method which is started by java. Checks for special arguments or
      * starts up the application.
@@ -578,6 +594,7 @@ public final class yacy {
     public static void main(String args[]) {
 
     	try {
+    	    System.setProperty("jsse.enableSNIExtension", "false"); // fix a ssl problem in Java 1.7, see http://teknosrc.com/javax-net-ssl-sslprotocolexception-handshake-alert-unrecognized_name-solved/
 
 	        // check assertion status
 	        //ClassLoader.getSystemClassLoader().setDefaultAssertionStatus(true);
@@ -599,8 +616,7 @@ public final class yacy {
 	        if (OS.isWindows) headless = false;
 	        if (args.length >= 1 && args[0].toLowerCase().equals("-gui")) headless = false;
 	        System.setProperty("java.awt.headless", headless ? "true" : "false");
-            // System.setProperty("java.net.preferIPv4Stack", "true"); // DO NOT PREFER IPv6, i.e. freifunk uses ipv6 only and host resolving does not work
-           
+            
 	        String s = ""; for (final String a: args) s += a + " ";
 	        yacyRelease.startParameter = s.trim();
 
